#
# External Code Sets (created 31 May 2023 - 1Q 2023)
# https://www.iso20022.org/external_code_list.page
#
# This file is part of the Python Fintech Package
# https://www.joonis.de/fintech/
#
# Copyright (c) 2023 joonis new media
# Author: Thimo Kraemer <thimo.kraemer@joonis.de>


# ExternalAcceptedReason1Code
ACCEPTED_REASON = {
    'ADEA': 'Received after the servicer\'s deadline. Processed on best effort basis',
    'NSTP': 'Instruction was not straight through processing and had to be processed manually',
    'SMPG': 'Instruction is accepted but does not comply with the market practice rule published for the concerned market or process',
}

# ExternalAccountIdentification1Code
ACCOUNT_IDENTIFICATION = {
    'AIIN': 'Issuer Identification Number (IIN) - identifies a card issuing institution in an international interchange environment. Issued by ABA (American Bankers Association)',
    'BBAN': 'Basic Bank Account Number (BBAN) - identifier used nationally by financial institutions, ie, in individual countries, generally as part of a National Account Numbering Scheme(s), to uniquely identify the account of a customer',
    'CUID': '(United States) Clearing House Interbank Payments System (CHIPS) Universal Identification (UID) - identifies entities that own accounts at CHIPS participating financial institutions, through which CHIPS payments are effected. The CHIPS UID is assigned by the New York Clearing House',
    'UPIC': 'Universal Payment Identification Code (UPIC) - identifier used by the New York Clearing House to mask confidential data, such as bank accounts and bank routing numbers. UPIC numbers remain with business customers, regardless of banking relationship changes',
}

# ExternalAgentInstruction1Code
AGENT_INSTRUCTION = {
    'CHQB': '(Ultimate) creditor must be paid by cheque',
    'HOLD': 'Amount of money must be held for the (ultimate) creditor, who will call. Pay on identification',
    'INQR': 'Additional Information to an inquiry reason must be provided',
    'PBEN': '(Ultimate) creditor to be paid only after verification of identity',
    'PHOA': 'Please advise/contact next agent by phone',
    'PHOB': 'Please advise/contact (ultimate) creditor/claimant by phone',
    'TELA': 'Please advise/contact next agent by the most efficient means of telecommunication',
    'TELB': 'Please advise/contact (ultimate) creditor/claimant by the most efficient means of telecommunication',
    'TFRO': 'Payment instruction will be valid and eligible for execution from the date and time stipulated',
    'TTIL': 'Payment instruction is valid and eligible for execution until the date and time stipulated. Otherwise, the payment instruction will be rejected',
}

# ExternalAgreementType1Code
AGREEMENT_TYPE = {
    'AUSL': 'Australian Masters Securities Lending Agreement (AMSLA)',
    'BIAG': 'Bilateral agreement',
    'CARA': 'Investment Industry Regulatory Organization of Canada (IIROC) Repurchase/Reverse Repurchase Transaction Agreement',
    'CDEA': 'FIA-ISDA Cleared Derivatives Execution Agreement',
    'CHMA': 'Swiss Master Agreement',
    'CHRA': 'Swiss Master Repurchase Agreement',
    'CMOP': 'Contrato Marco de Operaciones Financieras',
    'CNBR': 'China Bond Repurchase Master Agreement',
    'CSDA': 'CSD bilateral agreement',
    'DEMA': 'German Master Agreement',
    'DERD': 'Deutscher Rahmenvertrag für Wertpapierdarlehen',
    'DERP': 'Deutscher Rahmenvertrag für Wertpapierpensionsgeschäfte ',
    'DERV': 'Deutscher Rahmenvertrag für Finanztermingeschäfte (DRV)',
    'EFMA': 'EFET Master Agreement',
    'ESRA': 'Contrato Marco de compraventa y Reporto de valores',
    'EUMA': 'European Master Agreement',
    'FMAT': 'FBF Master Agreement related to transactions on forward financial instruments',
    'FPCA': 'FOA Professional Client Agreement',
    'FRFB': 'Convention-Cadre Relative aux Operations de Pensions Livrees',
    'GESL': 'Gilt Edged Stock Lending Agreement (GESLA)',
    'GMRA': 'Global Master Repurchase Agreement',
    'GMSL': 'Global Master Securities Lending Agreement',
    'IDMA': 'Islamic Derivative Master Agreement',
    'ISDA': 'International Swaps and Derivatives Association Agreement',
    'JPBL': 'Japanese Master Agreement on Lending Transaction of Bonds',
    'JPBR': 'Japanese Master Agreement on the Transaction with Repurchase Agreement of the Bonds',
    'JPSL': 'Japanese Master Agreement on the Borrowing and Lending Transactions of Share Certificates',
    'KRRA': 'Korea Financial Investment Association (KOFIA) Standard Repurchase Agreement',
    'KRSL': 'Korean Securities Lending Agreement (KOSLA)',
    'MEFI': 'Master Equity and Fixed Interest Stock Lending Agreement (MEFISLA)',
    'MRAA': 'Master Repurchase Agreement',
    'MSLA': 'Master Securities Loan Agreement',
    'OSLA': 'Overseas Securities Lending Agreement',
    'OTHR': 'Other type of master agreement',
}

# ExternalAuthenticationChannel1Code
AUTHENTICATION_CHANNEL = {
    'ATMA': 'Authentication provided through ATM',
    'CARD': 'Authentication provided through Card',
    'INBA': 'Authentication provided through Internet Banking',
    'MOBI': 'Authentication provided through Mobile',
}

# ExternalAuthorityExchangeReason1Code
AUTHORITY_EXCHANGE_REASON = {
    'ADHR': 'Ad hoc request',
    'CABB': 'Competent Authority for Buyer Branch',
    'CABC': 'Competent Authority for Basket Constituant',
    'CABT': 'Competent Authority for Buyer Transmitting Firm',
    'CADB': 'Competent Authority for Decision Making Branch',
    'CADU': 'Competent Authority for Direct Underlying',
    'CAEB': 'Competent Authority for Executing Branch',
    'CAFI': 'Competent Authority for Instrument',
    'CAIX': 'Competent Authority for Index',
    'CAMB': 'Competent Authority for Membership Branch',
    'CASB': 'Competent Authority for Seller Branch',
    'CAST': 'Competent Authority for Seller Transmitting Firm',
    'CATV': 'Competent Authority for Trading Venue',
}

# ExternalAuthorityIdentification1Code
AUTHORITY_IDENTIFICATION = {
    'AUAS': 'Australian Securities and Investments Commission (ASIC)',
    'ATFM': 'Austrian Financial Market Authority (FMA)',
    'BEFS': 'Financial Services and Markets Authority (FSMA)',
    'BENB': 'National Bank of Belgium',
    'BGFS': 'Financial Supervision Commission (FSC)',
    'CACS': 'Canadian Securities Transition Office (CSTO)',
    'CYAS': 'Authority for the Supervision and Development of Cooperative Societies',
    'CYCB': 'Central Bank of Cyprus (CBC)',
    'CYCY': 'Cyprus Securities and Exchange Commission (CySEC)',
    'CZCN': 'Czech National Bank (CNB)',
    'DEBA': 'Federal Financial Supervisory Authority (BaFin)',
    'DKFI': 'Finanstilsynet',
    'EEEF': 'Estonian Financial Supervision Authority (EFSA)',
    'EUES': 'European Securities and Markets Authority (ESMA)',
    'ESBD': 'Bank of Spain (BDE)',
    'ESCN': 'Comisión Nacional del Mercado de Valores (CNMV)',
    'FIFS': 'Finanssivalvonta (FSA)',
    'FRAC': 'Autorité de Contrôle Prudentiel et de Résolution (ACPR)',
    'FRAM': 'Autorité des Marchés Financiers (AMF)',
    'GBFS': 'Financial Services Authority (FSA)',
    'GBFC': 'Financial Conduct Authority (FCA)',
    'GBPR': 'Prudential Regulation Authority (PRA)',
    'GIFS': 'Gibraltar FSC (FSC)',
    'USCF': 'US Commodity Futures Trading Commission (CFTC)',
    'GRBO': 'Bank of Greece (BOG)',
    'GRHC': 'Hellenic Capital Market Commission (HCMC)',
    'HRHA': 'Croatian Financial Services Supervisory Agency (HANFA)',
    'HUPS': 'Hungarian Financial Supervisory Authority (PSZAF)',
    'IECB': 'Central Bank of Ireland (CBI)',
    'ISFM': 'Iceland Financial Supervisory Authority (FME)',
    'ITBD': 'BANCA D\'ITALIA (BDI)',
    'ITCO': 'Commissione Nazionale per le Societa e la Borsa (CONSOB)',
    'LIFM': 'Financial Market Authority (FMA)',
    'LTLS': 'Bank of Lithuania (LSC)',
    'LUCS': 'Commission de Surveillance du Secteur Financier (CSSF)',
    'LVFK': 'Financial & Capital Market Commission (FKTK)',
    'MTMF': 'Malta Financial Services Authority (MFSA)',
    'NLAF': 'Netherlands Authority for the Financial Markets (AFM)',
    'NLDN': 'Nederlandse Bank (DNB)',
    'NOFI': 'Norwegian Financial Supervisory Authority (Finanstilsynet)',
    'PLKN': 'Polish Financial Supervisory Commission (KNF)',
    'PTBP': 'Banco de Portugal (BP)',
    'PTCM': 'Comissão do Mercado de Valores Mobiliários (CMVM)',
    'ROAS': 'Romanian Financial Supervisory Authority (ASF)',
    'SEFI': 'Finansinspektionen (FI)',
    'SIAT': 'Securities Market Agency (ATVP)',
    'SKNB': 'National Bank of Slovakia (NBS)',
}

# ExternalBalanceSubType1Code
BALANCE_SUB_TYPE = {
    'ADJT': 'Balance to be held in the settlement account in order to comply with the average reserve due, in the event that the bank\'s balance is equal to the reserve due during the remaining days of the maintenance period',
    'BCUR': 'Balance representing the amount in the domestic or base accounting currency',
    'BLCK': 'Balance representing the regulatory reserve that a financial institution must have with the account servicing institution, eg, the minimum credit balance a financial institution is to keep with its Central Bank for mandatory reserve purposes. In some countries, a blocked balance is known as a \'reserve\' balance',
    'BLKD': 'Balance representing funds that cannot be touched by the account owner',
    'DLOD': 'Balance representing the intra day overdraft granted by the Central Bank to financial institutions participating in a RTGS system. This balance may vary over time and shall be offset at the end of the day',
    'EAST': 'Balance representing the potential loan a Central Bank would make in cash if the collateral is pledged, eg, securities available and eligible as collateral with the Central Bank',
    'FCOL': 'Balance representing the forecast of the cash-equivalent resulting from evaluation of existing holdings at CSD that are qualified to serve as collateral',
    'FCOU': 'Balance representing the cash equivalent resulting from evaluation of existing holdings at CSD that are qualified to serve as collateral and have been used as collateral',
    'FORC': 'Balance representing the total of all balance types representing the forecast of transactions to settle, blocked items, custody transactions and corporate actions cash disbursements',
    'FUND': 'Balance representing the net amount to be funded resulting from the difference between the total of all transactions with a cash impact and the existing cash coverage',
    'INTM': 'Balance representing an intermediate amount such as the opening or closing balance incrementally carried forward from one page to the next in a multi-page statement or report',
    'LCUR': 'Balance representing the amount in the local market currency for which the asset is held',
    'LRLD': 'Balance of a specific limit value, eg, a bilateral balance is calculated in relation to a given bilateral limit',
    'NOTE': 'Balance representing the amount that a financial institution has set aside for a specific reason and which is therefore not available. In the context of CSDs, reservation of liquidity made to meet settlement obligations',
    'PDNG': 'Balance of securities pending delivery, such as orders to sell securities have been executed but settlement of the open transactions has not been confirmed',
    'PIPO': 'Balance representing the fictive amount of automated direct debits or payment based on standing arrangements between the CSD and the user. Usage: Pay-Ins and Pay-Outs can be different based on individual payment instructions or available funds',
    'PRAV': 'Average of the daily balances on the account used to fulfil the reserve requirements calculated from the beginning of the maintenance period',
    'RESV': 'Balance representing the regulatory reserve that a financial institution must have with the account servicing institution, eg, the minimum credit balance a financial institution is to keep with its Central Bank for mandatory reserve purposes',
    'SCOL': 'Balance representing the forecast of the cash-equivalent resulting from evaluation of the net incoming balance of securities qualified to serve as collateral for which settlement instructions are held at',
    'SCOU': 'Balance representing the cash-equivalent resulting from evaluation of incoming securities, qualified to serve as collateral and actually used as collateral, which have been settled during the settlement process',
    'THRE': 'Balance representing the amount that will be destined for investment. Difference between available balance and threshold for investment limit',
}

# ExternalBalanceType1Code
BALANCE_TYPE = {
    'CLAV': 'Closing balance of amount of money that is at the disposal of the account owner on the date specified',
    'CLBD': 'Balance of the account at the end of the pre-agreed account reporting period. It is the sum of the opening booked balance at the beginning of the period and all entries booked to the account during the pre-agreed account reporting period',
    'FWAV': 'Forward available balance of money that is at the disposal of the account owner on the date specified',
    'INFO': 'Balance for informational purposes',
    'ITAV': 'Available balance calculated in the course of the account servicer\'s business day, at the time specified, and subject to further changes during the business day. The interim balance is calculated on the basis of booked credit and debit items during the calculation time/period specified',
    'ITBD': 'Balance calculated in the course of the account servicer\'s business day, at the time specified, and subject to further changes during the business day. The interim balance is calculated on the basis of booked credit and debit items during the calculation time/period specified',
    'OPAV': 'Opening balance of amount of money that is at the disposal of the account owner on the date specified',
    'OPBD': 'Book balance of the account at the beginning of the account reporting period. It always equals the closing book balance from the previous report',
    'PRCD': 'Balance of the account at the previously closed account reporting period. The opening booked balance for the new period has to be equal to this balance. Usage: the previously booked closing balance should equal (inclusive date) the booked closing balance of the date it references and equal the actual booked opening balance of the current date',
    'XPCD': 'Balance, composed of booked entries and pending items known at the time of calculation, which projects the end of day balance if everything is booked on the account and no other entry is posted',
}

# ExternalBenchmarkCurveName1Code
BENCHMARK_CURVE_NAME = {
    'MAAA': 'Benchmark curve used for municipals based on the best credit rating for municipal market debt',
    'FUSW': 'Portion of a synthetic curve that is composed of Eurodollar or Treasury or similar Futures and Swap rates. The term usually begins at 3 months to 2 years for the futures strip component with the Swaps filling in the points to 10 years and beyond',
    'LIBI': 'Rate at which major international banks are willing to take deposits from one another, is normally 1/8 percent below LIBOR._x000D_ _x000D_ London InterBank Bid Rate, the rate bid by banks on Eurocurrency deposits; the international rate that banks lend to other banks',
    'LIBO': 'London Interbank Offered Rate, the interest rate that major international banks in London charge each other for borrowing',
    'SWAP': 'In curve construction, Swap is the long portion of the curve constituting about 3 years to 30 years term. The exchange of one security, currency or interest rate for another to change the maturity (bonds), or quality of issues (stocks or bonds), or because investment objectives have changed',
    'TREA': 'Treasury benchmark that comes in three types: the yield curve, the par curve, and the spot curve. All curves also have a constituent time series',
    'EURI': 'Euro Interbank Offer Rate is the rate at which Euro inter-bank term deposits within the Euro zone are offered by one prime bank to another prime bank',
    'PFAN': 'Pfandbriefe security is a collateralised bullet bond backed by either mortgage loans or loans to the public sector. Pfandbriefe differ from traditional asset-backed securities in significant ways. The most important difference is that Pfandbriefe carry no pre-payment risk since they remain on the balance sheet of the issuing institution. Therefore, their spreads over sovereign bonds are attributable to liquidity and credit quality alone. New indices have been created and existing indices have been modified in response to the growing importance of the Pfandbriefe market. The Deutsche Borse has three synthetic indices called REX, JEX, and PEX. The Pfandbriefe curve is used as a reference for credit as well as mortgage market',
    'EONA': 'Euro OverNight Index Average rate',
    'EONS': 'Euro OverNight Index Average swap rate',
    'EUUS': 'Rate for the eurodollars, time deposits denominated in U.S. dollars at banks outside the United States, and thus are not under the jurisdiction of the Federal Reserve',
    'EUCH': 'Swiss Franc LIBOR rate',
    'TIBO': 'Tokyo Interbank Offered Rate',
    'ISDA': 'Worldwide common reference rate value for fixed interest rate swap rates, as defined by the International Swaps and Derivatives Association (ISDA)',
    'GCFR': 'GCF Repo Index, the Depository Trust & Clearing Corporation (DTCC) general collateral finance repurchase agreements index',
    'STBO': 'Stockholm Interbank Offered Rate',
    'BBSW': 'Australian Financial Markets Association (AFMA) Bank-Bill Reference Rate (BBSW)',
    'JIBA': 'Johannesburg Interbank Agreed Rate',
    'BUBO': 'Budapest Interbank Offered Rate',
    'CDOR': 'Canadian Dollar Offered Rate',
    'CIBO': 'Copenhagen Interbank Offered Rate',
    'MOSP': 'Moscow Prime Offered Rate',
    'NIBO': 'Norwegian Interbank Offered Rate',
    'PRBO': 'Czech Fixing of Interest Rates on Interbank Deposits',
    'TLBO': 'Tel Aviv Interbank Offered Rate',
    'WIBO': 'Warsaw Interbank Offered Rate',
    'ESTR': 'Euro Short Term Rate',
    'SOFR': 'Secured Overnight Financing Rate',
    'SONA': 'Sterling Over Night Index Average',
    'RCTR': 'RBA Cash Rate Target (RBATCTR)',
    'CORA': 'Canadian Overnight Repo Rate Average (CAONREPO)',
    'BCOL': 'Bank of Canada Overnight Lending Rate (CABROVER)',
    'HKIO': 'Hong Kong Interbank Offered Rate (HIHD01M)',
    'BJUO': 'Bank of Japan Uncollateralized Overnight Call Rate (MUTSCALM)',
    'ETIO': 'Euroyen Tokyo Interbank Offered Rate (EUYN03M)',
    'EFFR': 'Effective Federal Funds Rate (FEDL01)',
    'OBFR': 'Overnight Bank Funding Rate (OBFR01)',
    'CZNA': 'Czech National Bank Reference Interest Rate',
    'TONA': 'Tokyo Overnight Average Rate:_x000D_ Interest rate benchmark - also known as a reference rate or a benchmark rate. It is a measure of the cost of borrowing in the Japanese yen unsecured overnight money market and is the near risk-free rate (RFR) for Japanese yen markets, administered and published by the Bank of Japan. It is sometimes referred to as “TONAR”',
    'TORF': 'Tokyo Term Risk Free Rate:_x000D_ Interest rate Benchmark based on the uncollateralized overnight call rate which involves almost no credit risk of financial institutions, based on the Japanese Yen "Risk-Free-Rate" (RFR), administered and published by QUICK Benchmarks, Inc',
    'SIBO': 'Singapore Interbank Offered Rate._x000D_',
    'SSOR': 'Singapore Dollar Swap Offer Rate',
    'SORA': 'Singapore Overnight Rate Average',
}

# ExternalBillingBalanceType1Code
BILLING_BALANCE_TYPE = {
    'ABRR': 'The difference between the excess/(deficit) investable balance and the excess/(deficit) collected balance due to the reserve requirement. This balance is not used if the account’s Earnings Credit Rate is net of reserves. This may be used when the earnings allowance rate is not adjusted for reserves. It may be that reserves have been subtracted from the collected balance to determine the investable balance. Therefore, they must be added back to the excess/(deficit) investable balance to determine the collected balance position. The presentation of this calculation is optional. AFP code=00 04 21',
    'BEQU': 'Balance required to offset the current analysis period’s balance compensable service charges. The balance equivalent can be calculated in two different ways. The first simply multiplies the balance compensable service charge total by the multiplier. The second calculation incorporates all of the elements of the multiplier calculation. Note that this calculation may result in a slightly different value due to the decimal precision and rounding used in the calculation: AFP code=00 04 00',
    'CBAM': 'The sum of only the daily ending NEGATIVE collected balances divided by the number of days in the statement period. The average negative balance, if present, is always positively signed. Balances are net of current period adjustments. Note that a NEGATIVE balance is equal to the POSITIVE balance less the NET balance. Note that a NEGATIVE Collected Balance Interest Rate can be applied to this balance to develop an OD interest charge. AFP code=00 00 13',
    'CBAN': 'The sum of the daily ending collected balances (both positive and negative) divided by the number of days in the statement period. A negative-signed value indicates a negative average NET balance. If a reserve-adjusted earnings allowance/credit rate is used, this balance may be the same as the investable balance (00 00 40). Balances are net of current period adjustments. Collected balances represent deposit money that has been collected and excludes any money in float. Note that a NET balance is equal to the POSITIVE balance less the NEGATIVE balance. Note that a NET Collected Balance OD Interest Rate (00 01 43) can be applied to this balance, if negative, to develop an OD interest charge. AFP code=00 00 10',
    'CBAP': 'The sum of only the daily ending POSITIVE collected balances divided by the number of days in the statement period. Balances are net of current period adjustments. Collected balances represent deposit money that has been collected and excludes any money in float. Note that a POSITIVE balance is equal to the NET balance plus the NEGATIVE balance. AFP code=00 00 11',
    'DABR': 'That portion of the demand deposit account balance that must be set aside by the bank to meet reserve requirements. AFP code=00 04 20',
    'EDCB': 'Collected balance remaining after the balance required to offset the current analysis period’s balance compensable service charges has been deducted. If negative (deficit), this represents the additional collected balance required to fully offset balance compensable service charges for the current period. If positive (excess), this represents the collected balance surplus after offsetting balance compensable service charges for the current period. AFP code=00 04 12',
    'EDIB': 'Investable balance remaining after the balance required to offset the current analysis period’s balance compensable service charges has been deducted. If negative (deficit), this represents the additional investable balance required to fully offset balance compensable service charges for the current period. If positive (excess), this represents the investable balance surplus after offsetting balance compensable service charges for the current period. Depending on the type of underlying account, a hard interest rate may be applied to a balance excess resulting in a hard interest credit to the underlying account. AFP code=00 04 10',
    'FDIC': 'That account balance used to calculate the FDIC assessment charge. AFP code=00 00 50',
    'FLBA': 'The sum of the daily dollar amount of items in the process of collection divided by the number of days in the statement period. AFP code=00 00 30',
    'FLPP': 'Sum of the adjustments to the average float in a prior period(s). A negative-signed value indicates a balance reduction. This balance can also be used to adjust the average collected balances since money in float has a direct effect on collected balances. AFP code=00 00 61',
    'IBAL': 'Balance on which the earnings allowance/credit rate is applied. This value can be signed either positive or negative. A negative-signed balance indicates a shortage of investable funds.and may result in a charge. AFP code=00 00 40',
    'IBIB': 'The average investable balance that can be used to show the base balance for the calculation of a hard interest credited. This is a hard interest credit as opposed to an earnings credit. AFP code=00 00 75',
    'IBLB': 'The average ledger balance that can be used to show the base balance for the calculation of a hard interest credited. This is a hard interest credit as opposed to an earnings credit. AFP code=00 00 70',
    'IBNC': 'The average net collected balance that can be used to show the base balance for the calculation of a hard interest credited. This is a hard interest credit as opposed to an earnings credit. AFP code=00 00 71',
    'IBNG': 'The average negatve collected balance that can be used to show the base balance for the calculation of a hard interest debit. This is a hard interest debit as opposed to an earnings credit debit. AFP code=00 00 73',
    'IBPC': 'The average positive collected balance that can be used to show the base balance for the calculation of a hard interest credited. This is a hard interest credit as opposed to an earnings credit. AFP code=00 00 72',
    'IBRR': 'The average reserve requirement balance that can be used to show the base balance for the calculation of a hard interest credited. This is a hard interest credit as opposed to an earnings credit. AFP code=00 00 74',
    'LBAN': 'The sum of the daily ending ledger balances (both positive and negative) divided by the number of days in the statement period. A negative-signed value indicates a negative average NET balance. Balances are net of current period adjustments. The ledger balance includes any deposit money that has not been collected, ie, money in float.Note that a NET balance is equal to the POSITIVE balance less the NEGATIVE balance.Note that a NET Ledger Balance OD Interest Rate can be applied to this balance, if negative, to develop an OD interest charge. AFP code=00 00 00',
    'LBAP': 'The sum of only the daily ending POSITIVE ledger balances divided by the number of days in the statement period. Balances are net of current period adjustments. The ledger balance includes any deposit money that has not been collected, ie, money in float. Note that a POSITIVE balance is equal to the NET balance plus the NEGATIVE balance. AFP code=00 00 01',
    'LBME': 'Value of the book or ledger balance at the end of the calendar month. AFP code=00 00 05',
    'LBNM': 'The sum of only the daily ending NEGATIVE ledger balances divided by the number of days in the statement period. The average negative balance, if present, is always positively signed. Balances are net of current period adjustments. Note that a NEGATIVE balance is equal to the POSITIVE balance less the NET balance. Note that a NEGATIVE Ledger Balance Interest Rate can be applied to this balance to develop an OD interest charge. AFP code=00 00 03',
    'UCFU': 'That portion of the balance that is the difference between the average negative collected balance and the average negative ledger balance. This is used to isolate that portion of the negative collected balance that represents the use of uncollected funds. Balances are net of current period adjustments. Note that the Uncollected Funds Usage Rate can be applied to this balance to develop an Uncollected Funds OD interest charge. AFP code=00 00 15',
}

# ExternalBillingCompensationType1Code
BILLING_COMPENSATION_TYPE = {
    'BACS': 'Total amount of service charges that can be offset by an earnings allowance credit. Such services carry a Payment Method code of ”Balance Compensable”. This amount is included in SettleChargeTtl-Current Period (AFP code 00 03 00). This value must be sent if the bank is providing an earnings credit based on deposit balances. AFP code=00 03 31',
    'CTND': 'Amount due to the bank for the settlement period, after all adjustments and deductions. Includes both service and tax charges. If nothing is due this value must be sent as zero. AFP code=00 03 14',
    'DEAD': 'Amount due to the bank for balance compensable service charges which exceed the earnings allowance for the settlement period. This amount should be equal to the absolute value of the ExcessDeficitEarningsAllowance-Adjusted (AFP code 00 02 44). This value must be sent if the bank is providing an earnings credit based on deposit balances. AFP code=00 02 47',
    'EALL': 'Value of balances maintained during the statement period which can be used to offset balance compensable service charges. This value must be sent if the bank is providing an earnings credit based on deposit balances. AFP code=00 02 40',
    'EANA': 'Net value of balance and/or rate adjustments for prior periods to be applied to the current excess/(deficit) allowance. AFP code=00 02 43',
    'EDAA': 'Excess/(deficit) earnings allowance for the analysis period plus or minus any net earnings allowance and/or balance compensable service charge adjustments. Note that in the absence of any EarningsAllowance-NetAdjust (AFP code 00 02 43) this balance is preferred instead of the ExcessDeficitEarningsAllowance (AFP code 00 02 41). This value must be sent if the bank is providing an earnings credit based on deposit balances. AFP code=00 02 44',
    'EDAL': 'The difference between the earnings allowance and the balance compensable service charges. Excess allowance occurs when the earnings allowance exceeds the total balance compensable service charges. A Deficit allowance occurs when the total balance compensable service charges exceed the earnings allowance. Excess allowances may be carried forward into future statement periods at the bank’s discretion. Deficit allowances are typically reflected as charges due to the bank in the form of DeficitEarningsAllowanceDueThisStmt (AFP code 00 02 47). This value must be sent if the bank is providing an earnings credit based on deposit balances. AFP code=00 02 41',
    'FESS': 'Charges from a prior billing period which have been paid. AFP code=00 03 22',
    'FREE': 'Total amount of service charges as listed in the Service Sections that are provided free of charge. Such services carry a Payment Method code of "FREE" (Free). This amount is included in SettleChargetTL-Current Period (AFP code 00 03 00). Should be sent if there are any “Free” service charges in the Service Sections. It is assumed that “waived” and “free” services are not taxed. AFP code=00 03 36',
    'NBCS': 'Total amount of service charges due as of this statement that are not eligible to be offset by an earnings allowance credit. Such services carry a Payment Method code of “FLAT" (HardCharge). This amount is included in SettleChargeTtl-CurrentPeriod (AFP code 00 03 00 ). AFP code=00 03 00',
    'PVCS': 'Total amount of service charges as listed in the Service Sections but assessed previously and which, therefore, are not due. Such services carry a Payment Method code of "PVCH" (PreviouslyCharged). This amount is included in SettleChargetTL-CurrentPeriod (AFP code 00 03 00). Should be sent if there are any "Previously Charged" services in the Service Sections. AFP code=00 03 35',
    'SCAB': 'Net value of adjustments to balance compensable service charges for a prior period(s) to be applied to the current excess/(deficit) allowance. AFP cod=00 03 32',
    'SCAN': 'Total of all service charge adjustments that are not eligible to be offset by an earnings allowance credit. This can be a positive-signed or negative-signed number. AFP code=00 03 33',
    'SCBT': 'The total amount of service charges due exclusive of taxes due. AFP code=00 03 11',
    'SCCP': 'Total charges before credit for services provided during the current statement period. This total is the arithmetic sum of all charges listed in the Settlement Amount element of the Service Sections in the statement regardless of the Payment Method code . It includes all Balance Compensable charges, Hard charges, Previously Charged charges, Waived charges and Free charges. It does not include any tax charges related to the services. AFP code=00 03 00',
    'SCDB': 'Amount of ChargesAndTaxes-NetDueThisStmt (AFP code 00 03 14 ) that are directly debited from the customer’s account. AFP code=00 03 50',
    'SCDI': 'The total amount of any service charge discount. AFP code=00 03 41',
    'SCIN': 'Amount of ChargesAndTaxes-NetDueThisStmt (AFP code 00 03 14 ) that are invoiced. AFP code=00 03 A0',
    'TICD': 'Total amount of hard interest credited to a designated account. The amount of hard interest credited, if any, is calculated by applying the Interest Credited rate against a negative balance as reported in the Balance Section with a Balance Identifier of ExcessDeficitCollectedBal (AFP code 00 04 12). AFP code=00 00 76',
    'TXSC': 'The total amount of service charges that were subject to taxes. AFP code=00 03 13',
    'TXTS': 'The Sum of all the individual tax values as contained in either the individual Service Sections or Tax Sections. AFP code=00 03 60',
    'WAIV': 'Amount of service charges otherwise due that are waived on this statement. Such services carry a Payment Method code of “WVED" (Waived). Note that this amount does not include line item free services (AFP code 00 03 36). This amount is included in SettleChargetTL-Current Period (AFP code 00 03 00). Any such line item waivers or free services are not brought forward into the Compensation calculations. It is assumed that “waived” and “free” services are not taxed. afp CODE=00 03 40',
}

# ExternalBillingRateIdentification1Code
BILLING_RATE_IDENTIFICATION = {
    'AEAR': 'Per annum earnings rate, adjusted for reserves, applied to the current analysis period’s investable balance for calculation of the earnings allowance credit. The ECR, Net of Reserves, is calculated as:  ECR, Net of Reserves = ECR, Not Net (00 01 22) * (1 – Reserve Rate)',
    'ANXE': 'The anticpated earnings allowance rate, as adjusted, to be used next month in the calculation of the earnings allowance. See AEAR AdjustedEarningsAllowance Rate',
    'CDRA': 'The current CD (Certificate of Deposit) rate as published by the bank',
    'DINR': 'The per annum rate used to calculate the Deficiency Interest amount to be paid to the bank',
    'DSCR': 'The per annum rate used to calculate a surcharge based on the Deficiency Interest amount to be paid to the bank',
    'EALR': 'Per annum earnings rate applied to the current statement period’s investable balance for calculation of the earnings allowance credit. The earnings allowance credit is used to offset the charges for balance compensable services. This rate has NOT been adjusted for reserves. The ECR, Not Net of Reserves, is calculated as:  ECR, Not Net = ECR, Net of Reserves (00 01 20) / (1 – Reserve Rate)',
    'FDIC': 'The current FDIC rate used in the US to calculate the Federal Deposit Insurance premium paid by the banks to the FDIC',
    'ICDR': 'Per annum interest rate used to calculate the interest amount credited to a designated account. The amount of interest credited, if any, is reported in a Compensation Section with a Compensation Identifier of TtlInterestCredited',
    'MULT': 'The collected balance required to offset $1.00 of balance compensable service charges. This factor can be used to calculate the balance equivalent of balance compensable service charges. The multiplier is calculated in one of three different ways depending on whether the Earnings Allowance Rate (ECR) is adjusted for reserves or not (net of reserves or not) and, in the case where the ECR is not adjusted for reserves, whether the multiplier is adjusted for reserves or not',
    'NCBO': 'Per annum interest rate used to calculate overdraft compensation on an average net collected balance which is negative (AFP balance 00 00 10). An average NET balance is negative when the sum of the daily ending POSITIVE and NEGATIVE balances is negative',
    'NGCO': 'Per annum interest rate applied to NEGATIVE collected balances (AFP balance 00 00 13) for calculation of overdraft compensation',
    'NGLO': 'Per annum interest rate applied to NEGATIVE ledger balances (AFP balance 00 00 03) for calculation of overdraft compensation',
    'NLBO': 'Per annum interest rate used to calculate overdraft compensation on an average net ledger balance which is negative (AFP balance 00 00 00). An average NET balance is negative when the sum of the daily ending POSITIVE and NEGATIVE balances is negative',
    'NXME': 'The anticpated earnings allowance rate to be used next month in the calculation of the earnings allowance. See EALR EarningsAllowance Rate',
    'NXMU': 'The anticipated Multiplier to be used next month. See MULT Multiplier',
    'PRIR': 'The current per annum Prime rate as published by the bank',
    'RRQR': 'The per annum reserve rate as applied to non demand deposit accounts such as time deposit or CD accounts',
    'RSRV': 'Per annum interest rate used to calculate that portion of the CollectedBal-AvgPositive that US banks must keep on deposit at the US Federal Reserve',
    'UFUR': 'Per annum interest rate assessed on that portion of the account balance which is the difference between the average negative ledger and the average negative collected balance (AFP balance 00 00 15). This rate is used to assess compensation on the portion of the negative collected balance that represents the use of uncollected funds',
}

# ExternalCancellationReason1Code
CANCELLATION_REASON = {
    'AC03': 'Wrong account number in Credit Transfer',
    'AGNT': 'Agent in the payment workflow is incorrect',
    'AM09': 'Amount is not the amount agreed or expected',
    'BE16': 'Debtor or Ultimate Debtor identification code missing or invalid',
    'COVR': 'Cover payments has either been returned or cancelled',
    'CURR': 'Currency of the payment is incorrect',
    'CUST': 'Cancellation requested by the Debtor',
    'CUTA': 'Cancellation requested because an investigation request has been received and no remediation is possible',
    'DS24': 'Cancellation requested because the original payment order expired due to time-out',
    'DT01': 'Invalid date (for example, wrong or missing settlement date)',
    'DUPL': 'Payment is a duplicate of another payment',
    'FRAD': 'Cancellation requested following a transaction that was originated fraudulently. The use of the FraudulentOrigin code should be governed by jurisdictions',
    'FRNA': 'To complement a rejection response, suggesting the request for cancelation should be forwarded to the next agent in the payment transaction chain',
    'FRTR': 'Direct Debit Tracking recalled as Mandate Cancelled',
    'INDM': 'To express the wish to establish a bilateral indemnity agreement',
    'MODT': 'The underlying transaction in relation to an RTP was modified',
    'PAID': 'The underlying transaction in relation to an RTP was already paid (via other means)',
    'SVNR': 'The payment is cancelled since a cash amount rendered was not correct or goods or a service was not rendered to the customer, e.g. in an e-commerce situation',
    'SYAD': 'Cancellation requested by System Member to Settlement System Administrator to indicate that the cancellation request must not be forwarded further in the chain',
    'TECH': 'Cancellation requested following technical problems resulting in an erroneous transaction',
    'UPAY': 'Payment is not justified',
    'ENUE': 'Cancellation or request for return requested by the Debtor specifically due to one or more errors by debtor in the original Credit Transfer. Usage: This code can be used for any error in the original Credit Transfer made by the Debtor. Can also be used if multiple errors were made in the original Credit Transfer',
    'UAPA': 'The Debtor is requesting a return of the payment because the payment was not properly authorized._x000D_ Usage: This code can be used in the case where a Credit Transfer was made without proper authorization from the Debtor. This could be due to compromised end user credentials',
    'NARR': 'Reason is provided as narrative information in the additional reason information',
    'AC02': 'Debtor account number invalid or missing',
    'BIAS': 'Process a cancellation request but batch already settled',
    'INCR': 'Process a cancellation request with incorrect reference to original batch',
    'DRTP': 'Duplication of a request-to-pay message',
}

# ExternalCashAccountType1Code
CASH_ACCOUNT_TYPE = {
    'CACC': 'Account used to post debits and credits when no specific account has been nominated',
    'CARD': 'Account used for credit card payments',
    'CASH': 'Account used for the payment of cash',
    'CHAR': 'Account used for charges if different from the account for payment',
    'CISH': 'Account used for payment of income if different from the current cash account',
    'COMM': 'Account used for commission if different from the account for payment',
    'CPAC': 'Account used to post settlement debit and credit entries on behalf of a designated Clearing Participant',
    'LLSV': 'Account used for savings with special interest and withdrawal terms',
    'LOAN': 'Account used for loans',
    'MGLD': 'Account used for a marginal lending facility',
    'MOMA': 'Account used for money markets if different from the cash account',
    'NREX': 'Account used for non-resident external',
    'ODFT': 'Account is used for overdrafts',
    'ONDP': 'Account used for overnight deposits',
    'OTHR': 'Account not otherwise specified',
    'SACC': 'Account used to post debit and credit entries, as a result of transactions cleared and settled through a specific clearing and settlement system',
    'SLRY': 'Accounts used for salary payments',
    'SVGS': 'Account used for savings',
    'TAXE': 'Account used for taxes if different from the account for payment',
    'TRAN': 'A transacting account is the most basic type of bank account that you can get. The main difference between transaction and cheque accounts is that you usually do not get a cheque book with your transacting account and neither are you offered an overdraft facility',
    'TRAS': 'Account used for trading if different from the current cash account',
    'VACC': 'Account created virtually to facilitate collection and reconciliation',
    'NFCA': 'Non-Resident Individual / Entity Foreign Current held domestically',
}

# ExternalCashClearingSystem1Code
CASH_CLEARING_SYSTEM = {
    'ABE': 'EBA Euro1/Step1',
    'ACH': 'Automated Clearing House. Payment system that clears cash transfers and settles the proceeds in a lump sum, usually on a multilateral netting basis',
    'ACS': 'Canadian Dollar (CAD) - Automated Clearing Settlement System (ACSS)',
    'AIP': 'AL (Albania) - Albania Interbank Payment System',
    'ART': 'AT (Austria) - Austrian RTGS',
    'AVP': 'NZ (New Zealand) - New Zealand Assured Value Payments',
    'AZM': 'AZ (Azerbaijan) - Azerbaijan Interbank Payment System (AZIPS)',
    'BAP': 'BA (Bosnia and Herzegovina)',
    'BCC': 'SE (Sweden) - Sweden BGC Clearing CUG',
    'BCE': 'EC (Ecuador) - Ecuadorian Central Payment System (Sistema Central de Pagos Ecuatoriano)',
    'BDS': 'BB (Barbados) - Barbados RTGS (CBRTGS)',
    'BEL': 'BE (Belgium) - Belgium RTGS (ELLIPS)',
    'BGN': 'BG (Bulgaria) - Bulgaria RTGS',
    'BHS': 'BS (Bahamas) - Bahamas RTGS',
    'BIS': 'BW (Botswana) - Botswana Interbank Settlement System',
    'BOF': 'FI (Finland) - RTGS (BOF)',
    'BOJ': 'the Bank of Japan clearing system',
    'BRL': 'IT (Italy) - Italy RTGS (BIREL)',
    'BSP': 'PH (Philippines) - Philippines Payment System',
    'CAD': 'CA (Canada) - Canadian Large Value Transfer System (LVTS)',
    'CAM': 'ES (Spain)',
    'CBA': 'AW (Aruba) - Central Bank of Aruba CSM',
    'CBC': 'CW (Curaçao), SX (Sint Maarten) Central Bank of Curaçao and Sint  Maarten CSM',
    'CBJ': 'IE (Ireland) - Irish RTGS (IRIS)',
    'CCE': 'Real-Time Payment System Peru',
    'CHI': 'US - The Clearing House CHIPS',
    'CHP': 'GB (UK) - British Euro RTGS (CHAPS)',
    'CIP': 'Cross-border Interbank Payment System (CIPS)',
    'CIS': 'Central Interoperability Service of the EACHA Clearing Cooperative, for exchanging SEPA payments between Automated Clearing Houses in the EEA',
    'COE': 'CO (Columbia) - Colombian Electronic Cheque System named CEDEC (Compensación Electrónica De Cheques)',
    'COI': 'CO (Columbia) - Colombian Central Bank´s ACH named CENIT (Compensación Electrónica Nacional Interbancaria)',
    'COU': 'CO (Columbia) - Colombian RTGS System named CUD (Cuentas de Depósito)',
    'DDK': 'DK (Denmark) - Danish Krone RTGS (KRONOS)',
    'DKC': 'DK (Denmark) - Danish Euro RTGS (KRONOS)',
    'EBA': 'EBA Euro1',
    'ELS': 'DE (Germany)',
    'EMZ': 'Elektronischer Massenzahlungsverkehr (EMZ) DE (Germany) – retail payment system operated by the Deutsche Bundesbank',
    'EPM': 'ECB (European Central Bank) - ECB Payment Mechanism',
    'EPN': 'US - The Clearing House EPN',
    'ERP': 'EBA step 1 (members)',
    'FDA': 'US (United States) - Federal Reserve Banks Automated Clearing House Service',
    'FDN': 'US (United States) - Federal Reserve Banks FedNow Service',
    'FDW': 'US (United States) - Federal Reserve Banks Fedwire Funds Service',
    'FEY': 'JP (Japan) the Foreign Exchange Yen Clearing system (FEYCS). It is the Japanese electronic interbank system for sending guaranteed and unconditional yen payments of FX deals for same day settlement from one settlement bank, on behalf of itself or its customers, to another settlement bank',
    'FPS': 'Faster Payments Service in UK',
    'GIS': 'GH (Ghana) - Ghana Interbank Settlement System (GISS)',
    'HKL': 'Hong Kong Clearing House Automated Transfer System (CHATS)',
    'HKS': 'Hong Kong Faster Payment System or FPS. A system owned and operated by the HKICL, to provide instant clearing and settlement payment services',
    'HRK': 'HR (Croatia) - HSVP',
    'HRM': 'GR (Greece) - Greek RTGS (HERMES)',
    'HUF': 'HU (Hungary) - VIBER',
    'IBP': 'ES - Spain - Iberpay Instant Payments',
    'INC': 'DE and NL - Equens',
    'IMP': 'India Immediate Payment Service',
    'JOD': 'JO (Jordan) - Jordan RTGS',
    'KPS': 'KE (Kenya) - Kenyan Electronic Payment Settlement System',
    'LGS': 'LU (Luxemburg) - Luxembourg RTGS (LIPS)',
    'LKB': 'LK (Sri Lanka) - Sri Lanka (Lankasettle)',
    'LVL': 'LV (Latvia)',
    'LVT': 'CA (Canada) - Large Value Transfer System (LVTS)',
    'LYX': 'CA (Canada) Lynx High Value Payment System',
    'MEP': 'SG (Singapore) - Singapore RTGS (MEPS+)',
    'MOS': 'ZA (South Africa) - South-African Multiple Option Settlement',
    'MQQ': 'Macao Real Time Gross Settlement System',
    'MRS': 'MT (Malta) - Malta Realtime Interbank Settlement System',
    'MUP': 'MU (Mauritius)',
    'NAM': 'NA (Namibian) - Namibian Interbank Settlement System',
    'NOC': 'NO (Norway)',
    'NOR': 'NICS Real (Norway)',
    'NPP': 'AU (Australia) - New Payments Platform (NPP)',
    'NSS': 'US (United States) - Federal Reserve Banks National Settlement Service',
    'NZE': 'NZ (New Zealand) – New Zealand Dollar RTGS (ESAS)',
    'PCH': 'CH (Switzerland)',
    'PDS': 'AU (Australia)',
    'PEG': 'EG (Egypt)',
    'PNS': 'FR (France)',
    'PSA': 'AT (Austria) – Austrian CSM',
    'PTR': 'AO (Angola) - Angola RTGS',
    'PVE': 'Ve (Venezuela)',
    'ROL': 'RO (Romania) - Romanian Electronic Payment Operations RT',
    'ROS': 'RO (Romania) - Romanian GSRS',
    'RTG': 'Real Time Gross Settlement System. Payment system that simultaneously clears individual transfers and settles them in central bank money',
    'RTP': 'DE (Germany)',
    'RTR': 'CA (Canada) Real Time Rail Payment System',
    'SCL': 'DE – SEPA-Clearer of the Retail Payment System operated by Deutsche Bundesbank',
    'SCP': 'CL (Chile) - Chilean Interbank Payment System',
    'SEC': 'SE (Sweden) - Swedish Euro RTGS (SEC)',
    'SEU': 'CH (Switzerland) – Swiss EUR RTGS named euroSIC',
    'SIC': 'CH (Switzerland) – Swiss CHF RTGS named SIC',
    'SIP': 'CH (Switzerland) – Swiss Instant Payment service in CHF operated by SIX Interbank Clearing',
    'SIT': 'SI (Slovenia)',
    'SLB': 'ES (Spain) - Spanish RTGS (SLBE)',
    'SPG': 'PT (Portugal) - Portuguese RTGS (SPGT)',
    'SSK': 'SE (Sweden) - SEK RTGS (RIX)',
    'ST2': 'EBA Clearing STEP 2',
    'STG': 'UK (United Kingdom) - CHAPS Sterling RTGS',
    'TBF': 'FR (France) - French RTGS (TBF)',
    'TCH': 'US - The Clearing House Real-TimePayment System',
    'TGT': 'Target',
    'THB': 'TH (Thailand) - Thailand Payment System (BAHTNET)',
    'THN': 'TH (Thailand) - National ITMX Payment System',
    'TIS': 'TZ (Tanzania) - Tanzania Interbank Settlement System (TISS)',
    'TOP': 'NL (Netherlands) - Dutch RTGS (TOP)',
    'TTD': 'TT (Trinidad and Tobago ) - Trinidad and Tobago SAFE-TT',
    'UBE': 'United States Dollar (USD) – US Bulk Exchange Clearing System (USBE)',
    'UIS': 'UG (Uganda) - Uganda National Interbank Settlement System',
    'UPI': 'India Unified Payments Interface',
    'VCS': 'VocaLink Clearing System',
    'XCT': 'EBA step 2',
    'ZEN': 'JP (Japan) the Zengin system. The electronic payment system for domestic third party transfers managed by the Tokyo Bankers Association',
    'ZET': 'ZW (Zimbabwe) - Zimbabwe Electronic Transfer & Settlement System',
    'ZIS': 'ZM (Zambia) - Zambian Interbank Payment &Settlement System',
    'ISG': 'IS (Iceland) – Icelandic krona RTGS (MBK)',
    'NBO': 'NO - Norway NOK RTGS Norges Bank',
    'ISW': 'NG (Nigeria) - Interswitch',
    'I27': 'P27 Clearing – Instant Payment Platform',
    'B27': 'P27 Clearing – Batch Payment Platform',
    'UKD': 'UK (United Kingdom) – Pay.UK Sterling Domestic',
    'SCR': 'SG (Singapore) - Singapore RTGS (SCRIPS)',
    'RIX': 'SE (Sweden) – SEK RTGS (RIX)',
    'MOC': 'Banco de Mocambique RTGS system',
    'BOK': 'KR (South Korea) – Korean Won RTGS (BOK-Wire+)',
}

# ExternalCategoryPurpose1Code
CATEGORY_PURPOSE = {
    'BONU': 'Transaction is the payment of a bonus',
    'CASH': 'Transaction is a general cash management instruction',
    'CBLK': 'A service that is settling money for a bulk of card transactions, while referring to a specific transaction file or other information like terminal ID, card acceptor ID or other transaction details',
    'CCRD': 'Transaction is related to a payment of credit card',
    'CORT': 'Transaction is related to settlement of a trade, eg a foreign exchange deal or a securities transaction',
    'DCRD': 'Transaction is related to a payment of debit card',
    'DIVI': 'Transaction is the payment of dividends',
    'DVPM': 'Code used to pre-advise the account servicer of a forthcoming deliver against payment instruction',
    'EPAY': 'Transaction is related to ePayment',
    'FCIN': 'Transaction is related to the payment of a fee and interest',
    'FCOL': 'A service that is settling card transaction related fees between two parties',
    'GP2P': 'General Person-to-Person Payment. Debtor and Creditor are natural persons',
    'GOVT': 'Transaction is a payment to or from a government department',
    'HEDG': 'Transaction is related to the payment of a hedging operation',
    'ICCP': 'Transaction is reimbursement of credit card payment',
    'IDCP': 'Transaction is reimbursement of debit card payment',
    'INTC': 'Transaction is an intra-company payment, ie, a payment between two companies belonging to the same group',
    'INTE': 'Transaction is the payment of interest',
    'LBOX': 'Transaction is related to identify cash handling via Night Safe or Lockbox by bank or vendor on behalf of a physical store',
    'LOAN': 'Transaction is related to the transfer of a loan to a borrower',
    'MP2B': 'Mobile P2B Payment',
    'MP2P': 'Mobile P2P Payment',
    'OTHR': 'Other payment purpose',
    'PENS': 'Transaction is the payment of pension',
    'RPRE': 'Collection used to re-present previously reversed or returned direct debit transactions',
    'RRCT': 'Transaction is related to a reimbursement for commercial reasons of a correctly received credit transfer',
    'RVPM': 'Code used to pre-advise the account servicer of a forthcoming receive against payment instruction',
    'SALA': 'Transaction is the payment of salaries',
    'SECU': 'Transaction is the payment of securities',
    'SSBE': 'Transaction is a social security benefit, ie payment made by a government to support individuals',
    'SUPP': 'Transaction is related to a payment to a supplier',
    'TAXS': 'Transaction is the payment of taxes',
    'TRAD': 'Transaction is related to the payment of a trade finance transaction',
    'TREA': 'Transaction is related to treasury operations. E.g. financial contract settlement',
    'VATX': 'Transaction is the payment of value added tax',
    'WHLD': 'Transaction is the payment of withholding tax',
    'SWEP': 'Classification: Cash Management. Transaction relates to a cash management instruction, requesting a sweep of the account of the Debtor above an agreed floor amount, up to a target or zero balance._x000D_ The purpose is to move the funds from multiple accounts to a single bank account. Funds can move domestically or across border and more than one bank can be used',
    'TOPG': 'Classification: Cash Management. Transaction relates to a cash management instruction, requesting to top the account of the Creditor above a certain floor amount, up to a target or zero balance. _x000D_ The floor amount, if not pre-agreed by the parties involved, may be specified',
    'ZABA': 'Transaction relates to a cash management instruction, requesting to zero balance the account of the Debtor._x000D_ Zero Balance Accounts empty or fill the balances in accounts at the same bank, in the same country into or out of a main account each day',
    'VOST': 'Transaction to be processed as a domestic payment instruction originated from a foreign bank',
    'FCDT': 'Foreign Currency Transaction that is processed between two domestic financial institutions',
    'CIPC': 'Transaction is a direct debit for a cash order of notes and/or coins',
    'CONC': 'Transaction is a direct debit for a cash order of notes and/or coins',
    'CGWV': 'Transaction is a payment towards a Party for the collection of cash by the Cash in Transit company',
}

# ExternalChannel1Code
CHANNEL = {
    'COUR': 'Delivery by courier',
    'EMAL': 'Transmission by e-mail',
    'FAXI': 'Transmission by fax',
    'MESS': 'Delivery by messenger',
    'POST': 'Delivery by postal service',
    'REGM': 'Delivery by registered mail services',
    'SEMA': 'Transfer via secure e-mail',
    'SWFA': 'Transmission by SWIFTNet FileAct',
    'SWIA': 'Transmission by SWIFTNet InterAct',
    'SWMT': 'Transmission by SWIFT (FIN)',
    'SWMX': 'Transmission by SWIFTNet',
    'TELE': 'Transmission by telecommunications service',
    'WEBM': 'Available via Web upload/download',
}

# ExternalChargeType1Code
CHARGE_TYPE = {
    'BRKF': 'Fee paid to a broker for services provided',
    'BTCH': 'Fee paid for processing a batch of transactions',
    'COMM': 'Fee paid for services provided',
    'SUMM': 'Summation of individual fees',
}

# ExternalClaimNonReceiptRejection1Code
CLAIM_NON_RECEIPT_REJECTION = {
    'NOOR': 'Original credit transfer never received',
    'RNPR': 'Original credit transfer was received but is not processable',
    'ARJT': 'Already rejected original SCT (SEPA Credit Transfer)',
    'ARDT': 'Already returned original SCT (SEPA Credit Transfer)',
    'RR04': 'Regulatory reason',
}

# ExternalClearingSystemIdentification1Code
CLEARING_SYSTEM_IDENTIFICATION = {
    'ATBLZ': 'Bank Branch code used in Austria',
    'AUBSB': 'Bank Branch code used in Australia',
    'CACPA': 'Bank Branch code used in Canada',
    'CHBCC': 'Financial Institution Identification (IID) used in Switzerland, without check digit',
    'CHSIC': 'Financial Institution Identification (IID) used in Switzerland, including check digit',
    'CNAPS': 'Bank Branch code used in China',
    'DEBLZ': 'Bank Branch code used in Germany',
    'ESNCC': 'Bank Branch code used in Spain',
    'GBDSC': 'Bank Branch code used in the UK',
    'GRBIC': 'Bank Branch code used in Greece',
    'HKNCC': 'Bank Branch code used in Hong Kong',
    'IENCC': 'Bank Branch code used in Ireland',
    'INFSC': 'Bank Branch code used in India',
    'ITNCC': 'Bank Branch code used in Italy',
    'JPZGN': 'Bank Branch code used in Japan',
    'NZNCC': 'Bank Branch code used in New Zealand',
    'PLKNR': 'Bank Branch code used in Poland',
    'PTNCC': 'Bank Branch code used in Portugal',
    'RUCBC': 'Bank Branch code used in Russia',
    'SESBA': 'Bank Branch code used in Sweden',
    'SGIBG': 'Bank Branch code used in Singapore',
    'THCBC': 'Bank Identification code used in Thailand',
    'TWNCC': 'Bank Branch code used in Taiwan',
    'USABA': 'Routing Transit number assigned by the ABA for US financial institutons',
    'USPID': 'Bank identifier used by CHIPs in the US',
    'ZANCC': 'Bank Branch code used in South Africa',
    'NZRSA': 'RTGS settlement account used in New Zealand',
    'MZBMO': 'Banco de Mocambique RTGS system',
    'CNCIP': 'Chinese Cross-border Interbank Payment System (CIPS) Identifier',
    'KRBOK': 'Participant Institution code used by BOK-Wire+ in South Korea',
}

# ExternalContractBalanceType1Code
CONTRACT_BALANCE_TYPE = {
    'EXPC': 'Revolver loan current utilisation (applicable on loan contracts types)',
    'EXPT': 'Total loan utilisation for loans with total loan limit (applicable on loan contracts types)',
}

# ExternalContractClosureReason1Code
CONTRACT_CLOSURE_REASON = {
    'PCED': 'The parties have fulfilled all liabilities under the contract (loan agreement), including fulfillment of the liabilities by a resident third party (by another resident party)',
    'POTR': 'If the liabilities under the contract (loan agreement) are fulfilled (stopped) on other grounds, not mentioned in the currency control regulation',
    'PRNR': 'At the termination of the grounds (under the regulation) require the registered contract to be issued, including the cases resulting from making the appropriate changes and (or) additions to the contract (loan agreement), or if the registered contract has been wrongly issued in the absence in the contract (loan agreement) of any grounds for its issuance',
    'PSBT': 'The resident cedes a claim under the contract (loan agreement) to another resident party, or transfers a debt under the contract (loan agreement) to another resident party',
    'PSNR': 'The resident cedes a claim under the contract (loan agreement) to a non-resident',
    'PTAA': 'The registered contract has been transferred from the bank together with the transfer of the underlying contract (loan agreement) for servicing to another authorised bank (to another affiliate of this authorised bank, from the head office to an affiliate of this authorised bank, or from an affiliate to the head office of this authorised bank), as well as if the resident closes all settlement accounts in the bank of the registered contract',
    'RACC': 'All customer\'s accounts are closed: In the case the resident closes all settlement accounts at the bank where the contract was registered without closing the registered contract according to the regulation, the bank shall be entitled to independently close the registered contract after the expiration of 30 working days following the date of closing of the settlement account (last settlement account) of the resident',
    'RCED': 'If the bank has all information available for the closing of the registered contract, and all liabilities under the contract (loan agreement) have been fulfilled (terminated), while the resident has not filled an application for closing the registered contract',
    'REXP': 'In case of failure (on the basis of the information available in the registered contracts data base at the bank) of all obligations under the contract (loan agreement), and failure to provide by a resident of the documents and information (under the regulation), based on which the registered agent conducts a statement of banking supervision, within 180 calendar days following the date specified in the specified section (for example column 6 of Section 3 for Russia) of the registered contract. In the case referred to in this paragraph, the bank informs (at its discretion) the resident about the closure of the registered contract not later than in two working days after the date of its closure',
}

# ExternalCreditorAgentInstruction1Code
CREDITOR_AGENT_INSTRUCTION = {
    'CHQB': '(Ultimate) creditor must be paid by cheque',
    'HOLD': 'Amount of money must be held for the (ultimate) creditor, who will call. Pay on identification',
    'PHOB': 'Please advise/contact (ultimate) creditor/claimant by phone',
    'PRTK': 'Indicates that a payer token is requested/used',
    'RECI': 'Further information regarding the intended recipient',
    'TELB': 'Please advise/contact (ultimate) creditor/claimant by the most efficient means of telecommunication',
    'TKCM': 'Token found with counterparty mismatch',
    'TKSG': 'Single Use Token already used',
    'TKSP': 'Token found with suspended status',
    'TKVE': 'Token found with value limit rule violation',
    'TKXP': 'Token expired',
    'TOKN': 'Token information',
    'VLTK': 'Additional validation information to be used in conjunction with the token',
}

# ExternalCreditorEnrolmentAmendmentReason1Code
CREDITOR_ENROLMENT_AMENDMENT_REASON = {
    'AM05': 'Duplication',
    'RF01': 'Reference is not unique',
    'RR04': 'Regulatory Reason',
    'TRJT': 'Technical rejection',
    'UCRD': 'Unknown creditor',
}

# ExternalCreditorEnrolmentCancellationReason1Code
CREDITOR_ENROLMENT_CANCELLATION_REASON = {
    'AM05': 'Duplication',
    'RF01': 'Reference is not unique',
    'RR04': 'Regulatory Reason',
    'TRJT': 'Technical rejection',
    'UCRD': 'Unknown creditor',
}

# ExternalCreditorEnrolmentStatusReason1Code
CREDITOR_ENROLMENT_STATUS_REASON = {
    'ACRD': 'Already existing creditor',
    'AM05': 'Duplication',
    'FF01': 'Invalid file format',
    'RF01': 'Reference is not unique',
    'RR04': 'Regulatory Reason',
    'RR10': 'Invalid character set',
    'TRJT': 'Technical rejection',
}

# ExternalDateFrequency1Code
DATE_FREQUENCY = {
    'MNTH': 'Frequency is monthly',
    'QUTR': 'Frequency is quarterly (every three months)',
    'SEMI': 'Frequency is semi-annual (every six months)',
    'TOMN': 'Frequency is two-monthly (every two months)',
    'YEAR': 'Frequency is annual',
}

# ExternalDebtorActivationAmendmentReason1Code
DEBTOR_ACTIVATION_AMENDMENT_REASON = {
    'AM05': 'Duplication',
    'RF01': 'Reference is not unique',
    'RR04': 'Regulatory Reason',
    'TRJT': 'Technical rejection',
    'UCRD': 'Unknown creditor',
}

# ExternalDebtorActivationCancellationReason1Code
DEBTOR_ACTIVATION_CANCELLATION_REASON = {
    'AM05': 'Duplication',
    'RF01': 'Reference is not unique',
    'RR04': 'Regulatory Reason',
    'TRJT': 'Technical rejection',
    'UCRD': 'Unknown creditor',
}

# ExternalDebtorActivationStatusReason1Code
DEBTOR_ACTIVATION_STATUS_REASON = {
    'ACRD': 'Already existing creditor',
    'AM05': 'Duplication',
    'FF01': 'Invalid file format',
    'RF01': 'Reference is not unique',
    'RR04': 'Regulatory Reason',
    'RR10': 'Invalid character set',
    'TRJT': 'Technical rejection',
}

# ExternalDiscountAmountType1Code
DISCOUNT_AMOUNT_TYPE = {
    'APDS': 'Addition discount based on third-party agreed business promotional activity, i.e., extra 10 percent discount for 15 days)',
    'STDS': 'Discount based on volume purchased',
    'TMDS': 'Discount based on terms negotiated for payment within a specified time period, i.e., 2/10 Net 30 (2 percent discount if paid in 10 days; otherwise, net amount is due in 30 days)',
}

# ExternalDocumentFormat1Code
DOCUMENT_FORMAT = {
    'DPDF': 'Document format is PDF',
    'DXML': 'Document format is XML',
    'SDSH': 'Document format is a spreadsheet',
    'WORD': 'Document format is Word',
    'XSLT': 'Document format is XSLT',
}

# ExternalDocumentLineType1Code
DOCUMENT_LINE_TYPE = {
    'ADPI': 'Line item reference is an additional product identification assigned by the manufacturer',
    'AISB': 'Line item reference is an alternate International Standard Book Number (ISBN)',
    'ASNB': 'Line item reference is an asset number',
    'CTNB': 'Line item reference is a catalog number',
    'DBSP': 'Line item reference is Dun & Bradstreet Standard Product and Service code',
    'EANN': 'Line item reference is an European Article Number (EAN)',
    'EINB': 'Line item reference is an equipment identification number',
    'GSNB': 'Line item reference is a general specification number',
    'HIBC': 'Line item reference is a Health Care Industry Bar Code (HIBC)',
    'ISBN': 'Line item reference is an International Standard Book Number (ISBN)',
    'LTNB': 'Line item reference is a lot number',
    'MDNB': 'Line item reference is a model number',
    'PRNB': 'Line item reference is a part reference number',
    'PTCD': 'Line item reference is a product type code',
    'SKNB': 'Line item reference is a stock number',
    'STNB': 'Line item reference is a style number',
    'TONB': 'Line item reference is a technical order number',
    'UPCC': 'Line item reference is an UPC consumer package code',
    'UPNB': 'Line item reference is an Universal Product Number',
}

# ExternalDocumentPurpose1Code
DOCUMENT_PURPOSE = {
    'CONF': 'The document represents a document that has been confirmed, for example an invoice that has been confirmed by the buyer for payment',
    'FINV': 'The document represents an invoice submitted under a factoring arrangment',
}

# ExternalDocumentType1Code
DOCUMENT_TYPE = {
    'CINV': 'Document is an invoice',
    'CNFA': 'Document is a credit note for the final amount settled for a commercial transaction',
    'CONT': 'Document is a contract evidencing an agreement between the seller and buyer for the supply of goods and/or services',
    'CREN': 'Document is a credit note',
    'DEBN': 'Document is a debit note',
    'DISP': 'Document is an advice of despatch of the goods',
    'DNFA': 'Document is a debit note for the final amount settled for a commercial transaction',
    'HIRI': 'Document is an invoice for the hiring of human resources or renting goods or equipment',
    'INVS': 'Document is a signed invoice',
    'MSIN': 'Document is an invoice claiming payment for the supply of metered services, eg. Gas or electricity, supplied to a fixed meter',
    'PROF': 'In trade transactions, a pro forma invoice is a document that states a commitment from the seller to sell goods to the buyer at specified prices and terms. It is used to declare the value of the trade. It is not a true invoice, because it is not used to record accounts receivable for the seller and accounts payable for the buyer',
    'PUOR': 'Document is a purchase order',
    'QUOT': 'Document is a quotation setting out the conditions under which the goods and/or services are offered',
    'SBIN': 'Document is a statement of the transactions posted to the debtor\'s account at the supplier',
    'SPRR': 'Document is a document presented by the seller in support of the procurement of goods and/or services',
    'TISH': 'Document is a timesheet recording times for the provision of services and/or delivery of goods',
    'USAR': 'Document is a usage report indicating the consumption pattern for designated goods and/or services',
}

# ExternalEffectiveDateParameter1Code
EFFECTIVE_DATE_PARAMETER = {
    'SETT': 'Relates to the settlement date',
    'TRAD': 'Relates to the trade date',
}

# ExternalEncryptedElementIdentification1Code
ENCRYPTED_ELEMENT_IDENTIFICATION = {
    '8A': 'Primary Account Number',
    '8C': 'Track1',
    '8D': 'Track2',
    '8E': 'Track3',
    '8F': 'Visible Card Security Code',
    '89': 'Pre-agreed structure for encrypting data. Permits combination of data elements as per bilateral agreement',
    '90': 'Expiry Date',
    '91': 'Payment Account Reference (PAR)',
    '92': 'Payer Customer Identification',
    '93': 'Payer Customer Name',
    '94': 'Payer Customer Address',
    '95': 'Payer Customer Credentials Alien Registration Number',
    '96': 'Payer Customer Credentials Driver Licence Identification',
    '97': 'Payer Customer Credentials National Identifier',
    '98': 'Payer Customer Credentials Passport Number',
    '99': 'Payer Customer Credentials Social Security Number',
    '9A': 'Payee Customer Identification',
    '9B': 'Payee Customer Name',
    '9C': 'Payee Customer Address',
    '9D': 'Payee Customer Credentials Alien Registration Number',
    '9E': 'Payee Customer Credentials Driver Licence Identification',
    '9F1F': 'Payee Customer Credentials National Identifier',
    '9F20': 'Payee Customer Credentials Passport Number',
    '9F21': 'Payee Customer Credentials Social Security Number',
    '9F22': 'Customer Device Identification',
    '9F23': 'Customer Device Location',
    '9F24': 'Customer Device Internet Protocol Address',
    '9F25': 'Customer Device E-mail',
    '9F26': 'Token Payment Token',
    '9F27': 'Token Token Requestor Identification',
    '9F28': 'Cardholder Name',
    '9F29': 'Cardholder Identification Customer Identification',
    '9F2A': 'Cardholder Identification Alien Registration Number',
    '9F2B': 'Cardholder Identification Driver Licence Identification',
    '9F2C': 'Cardholder Identification Email',
    '9F2D': 'Cardholder Identification NatinalIdentifier',
    '9F2E': 'Cardholder Identification Passport Number',
    '9F2F': 'Cardholder Identification PhoneNumber',
    '9F30': 'Cardholder Identification Social Security Number',
    '9F31': 'Cardholder Identification Address',
    '9F32': 'Cardholder Contact Information Name',
    '9F33': 'Cardholder Contact Information Home Phone Number',
    '9F34': 'Cardholder Contact Information Business Phone Number',
    '9F35': 'Cardholder Contact Information Mobile Phone Number',
    '9F36': 'Cardholder Contact Information Other Phone Number',
    '9F37': 'Cardholder Contact Information Personal Email Address',
    '9F38': 'Cardholder Contact Information Business Email Address',
    '9F39': 'Cardholder Contact Information Other Email Address',
    '9F3A': 'Cardholder Address Digits',
    '9F3B': 'Cardholder Billing Address',
    '9F3C': 'Cardholder Birth Date',
    '9F3D': 'Cardholder Place Of Birth',
    '9F3E': 'Cardholder Employee Identification Number',
    '9F3F': 'Cardholder Employer Identification Number',
    '9F40': 'Cardholder Password',
    '9F41': 'Cardholder Postal Code',
    '9F42': 'Cardholder Shipping Address',
    '9F43': 'Cardholder Shipping Address From',
    '9F44': 'Cardholder Shipping Address To',
    '9F45': 'Cardholder Tax Identification Number',
    '9F46': 'Account From Account Identification',
    '9F47': 'Account To Account Identification',
}

# ExternalEnquiryRequestType1Code
ENQUIRY_REQUEST_TYPE = {
    'RT11': 'Type is an enquiry on the bank\'s position',
    'RT12': 'Type is an enquiry on a specific transaction',
    'RT13': 'Type is an enquiry on a queued transaction',
    'RT14': 'Type is an enquiry on a suspicious transaction',
    'RT16': 'Type is an enquiry on the system date and/or time',
    'RT15': 'Type is an enquiry on pending inward credits',
}

# ExternalEntryStatus1Code
ENTRY_STATUS = {
    'BOOK': 'Booked means that the transfer of money has been completed between account servicer and account owner. Usage: Status Booked does not necessarily imply finality of money as this depends on other factors such as the payment system used, the completion of the end-to-end transaction and the terms agreed between account servicer and owner. Status Booked is the only status that can be reversed',
    'FUTR': 'Entry is on the books of the account servicer and value will be applied to the account owner at a future date and time',
    'INFO': 'Entry is only provided for information, and no booking on the account owner\'s account in the account servicer\'s ledger has been performed',
    'PDNG': 'Booking on the account owner\'s account in the account servicer\'s ledger has not been completed. Usage: this can be used for expected items, or for items for which some conditions still need to be fulfilled before they can be booked. If booking takes place, the entry will be included with status Booked in subsequent account report or statement. Status Pending cannot be reversed',
}

# ExternalFinancialInstrumentIdentificationType1Code
FINANCIAL_INSTRUMENT_IDENTIFICATION_TYPE = {
    'BELC': 'National securities identification number for BE issued by the National Numbering Association SIX Telekurs Belgium',
    'BLOM': 'Ticker-like code assigned by Bloomberg to identify financial instruments',
    'CCCD': 'National Securities Identification Number issued by the National Numbering Association for a country for which no specific financial instrument identification type code already yet. The first two letters of the code represents the country code (for example, EGDC for Egyptian NSIN). To be used only until the code is added to the ISO ExternalFinancialInstrumentIdentificationType1Code list',
    'CMED': 'Ticker-like code assigned by the Chicago Mercantile Exchange to identify listed-derivatives instruments',
    'COMM': 'National securities identification number for ICSDs issued by the National Numbering Association Clearstream and Euroclear',
    'CTAC': 'Ticker-like code assigned by the Consolidated Tape Association to identify financial instruments',
    'CUSP': 'National securities identification number for US and CA issued by the National Numbering Association Standard & Poor´s - CUSIP Global Services',
    'FIGC': 'A Financial Instrument Global Identifier Composite (FIGC) is a unique, persistent twelve character string that serves to identify financial instruments across asset classes at the composite level, is associated with one or more FIGI venue level ID’s and a single Share Class level ID',
    'FIGG': 'A Financial Instrument Global Identifier Share Class (FIGG) is a unique, persistent twelve character string that serves to identify financial instruments across asset classes at the global share class level, and is associated with one or more Composite level ID’s',
    'FIGI': 'A Financial Instrument Global Identifier (FIGI) is a unique, persistent twelve character string that serves to identify financial instruments across asset classes at the venue level. It is associated with one Composite ID',
    'ISDU': 'URL in Description to identify OTC derivatives instruments',
    'ISDX': 'XML in Description to identify OTC derivatives instruments',
    'LCHD': 'Ticker-like code assigned by LCH to identify listed-derivatives instruments',
    'OCCS': 'Ticker-like code assigned by the Options Clearing Corporation to identify financial instruments',
    'OPRA': 'Ticker-like code assigned by the Options Price Reporting Authority to identify financial instruments',
    'RCMD': 'Ticker-like code assigned by Markit to identify listed-derivatives instruments',
    'RICC': 'Ticker-like code assigned by Thomson Reuters to identify financial instruments',
    'SEDL': 'National securities identification number for GB issued by the National Numbering Association London Stock Exchange',
    'SICC': 'National securities identification number for JP issued by the National Numbering Association 6 Stock Exchanges and JASDEC (Securities Identification Ticker-like code Committee)',
    'TIKR': 'Ticker Code assigned by an exchange to identify financial instruments',
    'VALO': 'National securities identification number for CH and LI issued by the National Numbering Association SIX Telekurs Ltd',
    'WKNR': 'National securities identification number for DE issued by the National Numbering Association WM Datenservice',
    'CCDC': 'National Bond identification number for China issued by CHINA CENTRAL DEPOSITORY & CLEARING CO., Limited',
    'DTID': 'Digital Token Identifier, as defined in ISO 24165',
}

# ExternalGarnishmentType1Code
GARNISHMENT_TYPE = {
    'GNCS': 'Garnishment from a third party payer for Child Support',
    'GNDP': 'Garnishment from a direct payer for Child Support',
    'GTPP': 'Garnishment from a third party payer to taxing agency',
}

# ExternalIncoterms1Code
INCOTERMS = {
    'CFR': 'Cost and Freight (sea and inland waterway transport) - Incoterms 2010',
    'CIF': 'Cost, Insurance and Freight (sea and inland waterway transport) - Incoterms 2010',
    'CIP': 'Carriage and Insurance Paid To (any mode of transport, including multimodal) - Incoterms 2010',
    'CPT': 'Carriage Paid To (any mode of transport, including multimodal) - Incoterms 2010',
    'DAP': 'Delivered at Place (any mode of transport, including multimodal) - Incoterms 2010',
    'DAT': 'Delivered at Terminal (any mode of transport, including multimodal) - Incoterms 2010',
    'DDP': 'Delivered Duty Paid (any mode of transport, including multimodal) - Incoterms 2010',
    'EXW': 'Ex Works (any mode of transport, including multimodal) - Incoterms 2010',
    'FAS': 'Free Alongside Ship (sea and inland waterway transport) - Incoterms 2010',
    'FCA': 'Free Carrier (any mode of transport, including multimodal) - Incoterms 2010',
    'FOB': 'Free On Board (sea and inland waterway transport) - Incoterms 2010',
}

# ExternalInformationType1Code
INFORMATION_TYPE = {
    'INST': 'Instructions used to ease automatic request processing',
    'OTHR': 'Additional information not otherwise specified',
    'RELY': 'Instructions used to ease automatic request relay',
    'SHPG': 'Additional shipping information not otherwise specified',
    'SHPM': 'Information concerning the letters, numbers or other symbols placed on the outside of cargo to facilitate identification',
    'SLDC': 'Information concerning the domicile location of the seller',
}

# ExternalInvestigationExecutionConfirmation1Code
INVESTIGATION_EXECUTION_CONFIRMATION = {
    'ACDA': 'Used when a creditor accepts the debit authorisation',
    'ACNR': 'The claim for non-receipt of a payment instruction is accepted',
    'ACVA': 'The claim for value date correction is accepted',
    'CHRG': 'Further charges details are provided to resolve the case',
    'CNCL': 'Used when a requested cancellation is successful',
    'CONF': 'Used when a payment has been checked and was correctly executed without any intervention',
    'CVAA': 'The original value date was correct',
    'CWFW': 'Used when a payment will be cancelled to solve an investigation case',
    'FTNA': 'The cancellation request has been forwarded to the next agent for execution. Usage: This code should only be utilised where a Case Id is not present',
    'ICOV': 'Used when a transfer of funds has been initiated (a cover payment) to resolve a case',
    'IDUP': 'Used when the requested check for a possible duplicate instruction is confirmed',
    'IPAY': 'Used when the result of an investigation is, or will be, the initiation of a payment instruction',
    'IPYI': 'Used when a payment instruction (eg. MT103) has been initiated to resolve a case',
    'MCOV': 'Used when a transfer of funds has been modified (a cover payment) to resolve a case',
    'MODI': 'Used when a requested modification is successful',
    'MWFW': 'Used when the payment will be modified to solve an investigation case',
    'PDCR': 'Used when a requested cancellation is pending',
    'PECR': 'Used when a requested cancellation has been partially executed',
    'PURP': 'Further purpose details are provided to resolve the case',
    'RJCR': 'Used when a requested cancellation has been rejected',
    'RJNR': 'The claim for non-receipt of a payment instruction is rejected',
    'RJVA': 'The claim for value date correction is rejected',
    'SMTC': 'Used when the entry in the statement is correct',
    'SMTI': 'Used when the entry in the statement is incorrect and further information is provided with the resolution',
    'UWFW': 'Used when sender wants to respond to an assignment with an Unable To Apply workflow',
    'BIAS': 'Process a cancellation request but batch already settled',
    'IDNE': 'Process a Batch Cancellation "using an incorrect batch sequence number”',
    'IVCR': 'Process a cancellation request with incorrect reference to original batch',
    'INFO': 'Used when additional information has been sent to the beneficiary of a payment',
    'NINF': 'Used when no additional information is available',
    'PDNG': 'Used to inform that a response to an investigation is pending',
}

# ExternalLetterType1Code
LETTER_TYPE = {
    'LFBK': 'Document is a letter from the bank',
    'LTBK': 'Document is a letter to the bank',
    'SUPP': 'Document is a supporting document',
}

# ExternalLocalInstrument1Code
LOCAL_INSTRUMENT = {
    'DDMC': 'Transaction is related to a direct debit instruction authorized under a confirmed electronic mandate',
    'DDMP': 'Transaction is related to a direct debit instruction authorized under a paper based mandate, supported by paper authorization signed by the debtor',
    'DDMU': 'Transaction is related to a direct debit instruction authorized under an unconfirmed electronic mandate requiring confirmation by the debtor',
    'BPA': 'Transaction is related to an Instant Credit Transfer under the rules of the Centrale Bank van Aruba, based on the EPC SCT Inst scheme, with a specific batch time-out delay',
    'IPA': 'Transaction is related to an Instant Credit Transfer under the rules of the Centrale Bank van Aruba, based on the EPC SCT Inst scheme',
    'TRF': 'Transaction is related to credit transfers',
    '82': 'Transaction is related to a direct debit that is not pre authorised (Einzugsermächtigung)',
    '83': 'Transaction is related to a direct debit that is pre authorised (Abbuchungsauftrag)',
    'CPP': 'Transaction is related to cash per post. Transaction to ultimate recipient having no bank account. Primary beneficiary is a postal service provider. Funds are paid out by cash. Additional necessary information for address and delivery options need to be attached',
    'RTR': 'Transaction is related to returned credit transfers',
    'GST': 'Transaction is related to truncated credit transfers. Conversion of physical instrument to electonric form for transmission to the paying bank and where the original paper document does not continue in the clearing process..The original instrument rules are retained throughout the life of the instrument. Transaction triggered by specific marked and populated paper slip. Reconciliation reference is secured by check digits supporting secure optical recognition. All other remittance information is truncated prior transmission',
    'DDT': 'Transaction is related to direct debits',
    'RDD': 'Transaction is related to returned direct debits',
    'CHN': 'Transaction is related to truncated checks. Conversion of physical instrument to electonric form for transmission to the paying bank and where the original paper document does not continue in the clearing process..The original instrument rules are retained throughout the life of the instrument',
    'STR': 'Transaction is related to revoked credit transfers',
    'SDD': 'Transaction is related to revoked direct debits',
    'SRT': 'Transaction is related to revoked returned credit transfers',
    'SRD': 'Transaction is related to revoked returned direct debits',
    'SCN': 'Transaction is related to revoked truncated checks',
    'SGT': 'Transaction is related to revoked truncated credit transfers',
    'CARD': 'Transaction is related to card clearing',
    '05': 'Transaction is related to a direct debit that is not pre authorised (Einzugsermächtigung)',
    '04': 'Transaction is related to a direct debit that is pre authorised (Abbuchungsauftrag)',
    'ISE': 'Transaction is related to the German Image-based Cheque Collection Procedure “Imagegestützter Scheckeinzug - ISE”',
    'BSE': 'Transaction is related to the German Paperless Cheque Collection procedure “Belegloser Scheckeinzug - BSE”',
    '58': 'Transaction is related to a business-to-business direct debit (CSB58)',
    '19': 'Transaction is related to a business-to-customer direct debit (CSB19)',
    'ASTI': 'Indicates that the payment is sent by an authorized third party on behalf of the participant',
    'BACP': 'Indicates that the payment was initiated manually using a GUI (Graphical User Interface)',
    'MANP': 'Indicates that the payment is sent by responsible Central Bank on behalf of the participant in case of contingency',
    'SBTI': 'Indicates that the payment is submitted to move liquidity to the technical account - dedicated to real-time settlement in an external system (for example ancillary system) . The payment is processed in a separate payment queue besides the normal processing',
    '85': 'Transaction is related to an urgent direct debit that is pre authorised (Avis de Prélèvement accéléré)',
    '08': 'Transaction is related to a direct debit that is pre authorised (Avis de Prélèvement)',
    '89': 'Transaction is related to an urgent direct debit that is pre authorised (Avis de Prélèvement vérifié)',
    '60': 'LCR - Lettre de Change Relevé (Recovered Bill of Exchange) and BOR - Billet à Orde Relevé (Promissory Note)',
    'RIBA': 'Transaction is related to a non-pre authorised collection (RIBA)',
    'RIDO': 'Transaction is related to a direct debit that is pre authorised and revocable (RID Ordinario)',
    'RIDV': 'Transaction is related to an urgent direct debit that is pre authorised and revocable (RID Veloce)',
    'IDEAL': 'Transaction is related to payments via internet owned by Currence',
    'INSTNT01': 'The transaction is related to a regular Credit Transfer and will be instantly processed under the Dutch AOS on top of the EPC SCT scheme',
    'INSTTC01': 'The transaction is related to an Instant Credit Transfer under the rules of the Dutch AOS on top of the EPC SCT Inst scheme',
    'INSTIDEAL': 'Transaction is related to payments via internet owned by Currence which uses an Instant Credit Transfer',
    'INSTNT01IDEAL': 'Transaction is related to payments via internet owned by Currence which uses a regular Credit Transfer and will be instantly processed under the Dutch AOS on top of the EPC SCT scheme',
    'INSTTC01IDEAL': 'Transaction is related to payments via internet owned by Currence which uses an Instant Credit Transfer under the rules of the Dutch AOS on top of the EPC SCT Inst scheme',
    'NLDO': 'Transaction is related to a Domestic payment initiated by PAIN.001',
    'NLUP': 'Transaction is related to a Domestic payment initiated by PAIN.001',
    'SDN': 'Transaction is related to payments via a ‘Standaard Digitale Nota’ InvoiceAcceptgiro payment',
    'ACCEPT': 'Transaction is related to payments via Acceptgiro owned by Currence',
    'ICMC': 'Transaction is related to an Incident Management Correction procedure based on the DD infrastructure',
    'NLGOV': 'Transaction is related to direct debit scheme owned by the NVB',
    '0090': 'Transaction is related to mass payment beneficiary',
    '0091': 'Transaction is related to mass payment ours',
    '0092': 'Transaction is related to mass payment shared',
    '0002': 'Transaction is related to standing order',
    '0221': 'Transaction is related to one-off authorisation',
    '0224': 'Transaction is related to one-off authorisation charities',
    '0226': 'Transaction is related to one-off authorisation construction industry',
    '0225': 'Transaction is related to one-off authorisation tuition fees',
    '0222': 'Transaction is related to standing authorisation companies',
    '0227': 'Transaction is related to standing authorisation companies without debtor revocation right',
    '0220': 'Transaction is related to standing authorisation general',
    '0223': 'Transaction is related to standing authorisation lotteries',
    '0001': 'Transaction is related to converted (bank) payment. Conversion of physical instrument to electonric form for transmission to the paying bank and where the original paper document does not continue in the clearing process.The instrument rules change upon conversion',
    '0000': 'Transaction is related to business payment',
    'IN': 'Transaction is related to cross border customer credit transfer',
    'ONCL': 'Transaction is related to overnight clearing',
    'PERI': 'Credit transfer contains Extended Remittance Information (ERI) as defined within the applicable scheme',
    'SDCL': 'Transaction is related to New Zealand High Value Clearing System (HVCS) same day clearing payments',
    'DDNR': 'SEPA Core Direct Debit with ‘no refund’ option',
    'DDFA': 'SEPA Fixed Amount Direct Debit',
    'CORE': 'Transaction is related to SEPA direct debit -core',
    'B2BAMIPM': 'SEPA B2B Direct Debit AMI based on a paper mandate',
    'B2B': 'Transaction is related to SEPA business to business direct debit',
    'CR1AMIPM': 'Optional shorter time cycle (D-1) for SEPA Core Direct Debit AMI based on a paper mandate',
    'CORAMIPM': 'SEPA Core Direct Debit AMI based on a paper mandate',
    'COR1': 'Optional shorter time cycle (D-1) for SEPA Core Direct Debit',
    'FADAMIPM': 'SEPA Fixed Amount Direct Debit AMI based on a paper mandate',
    'CLSCCPERX': 'Transaction is related to the CLSClearedFX service for Eurex.  Usage: The code is mandatory for all pacs.009 payments to this service',
    'CLSCCPLCH': 'Transaction is related to the CLSClearedFX service for London Exchange Clearing House. Usage: The code is mandatory for all pacs.009 payments to this service',
    'INST': 'Transaction is related to an Instant Credit Transfer. Use case example: SEPA Instant Credit Transfer (SCT Inst)',
    'ADD': 'Transaction is authenticated direct debit for domestic use',
    'UDD': 'Transaction is unauthenticated direct debit for domestic use',
    'CCI': 'Transaction is related to an intra-group bank initiated cash management payment',
    'BTR': 'Transaction is related to a bank transfer',
    'CKS': 'Transaction is related to check same day settlement wire',
    'CTR': 'Transaction is related to customer transfer',
    'CTP': 'Transaction is related to a customer transfer, which may include information related to a cover payment or extended remittance information',
    'DEP': 'Transaction is related to deposit to sender\'s account',
    'FFR': 'Transaction is related to Fed funds returned',
    'FFS': 'Transaction is related to Fed funds sold',
    'SVC': 'Transaction is related to non-value service message',
    'DRW': 'Transaction is related to drawdown response (value) to honor a drawdown request',
    'DRB': 'Transaction is related to bank-to-bank drawdown request or response (non-value)',
    'DRC': 'Transaction is related to customer or corporate drawdown request or response (non-value)',
    'IAT': 'Transaction is related to international ACH',
    'CCD': 'Transaction is related to cash concentration or disbursement corporate counterparty',
    'CTX': 'Transaction is related to corporate trade exchange',
    'PPD': 'Transaction is related to prearranged payment or deposit consumer counterparty',
    'CIE': 'A credit entry initiated by or on behalf of the holder of a consumer account',
    'RCK': 'Transaction is related to re-presented check entry',
    'ARC': 'Transaction is related to accounts receivable check',
    'WEB': 'Transaction is related to internet initiated entry',
    'POP': 'Transaction is related to point-of-purchase',
    'POS': 'Transaction is related to point-of-sale',
    'TEL': 'Transaction is related to telephone initiated entry',
    'ITP': 'Request-to-pay preferred payment via Instant Credit Transfer but Credit Transfer is also possible',
    'CRP': 'Request-to-pay preferred payment via Credit Transfer but Instant Credit Transfer is also possible',
    'MDP': 'Type of New Payments Architecture (NPA) payment. Payments are processed over a three-day cycle and available to customers early in the morning of Day 3',
}

# ExternalMandateReason1Code
MANDATE_REASON = {
    'AC01': 'Format of the account number specified is not correct',
    'AC04': 'Account number specified has been closed on the Receiver\'s books',
    'AC06': 'Account specified is blocked, prohibiting posting of transactions against it',
    'AG01': 'Transaction forbidden on this type of account (formerly NoAgreement)',
    'AG02': 'Bank Operation code specified in the message is not valid for receiver',
    'AM02': 'Specific transaction/message amount is greater than allowed maximum',
    'AM03': 'Specified message amount is a non processable currency outside of existing agreement',
    'AM05': 'Duplication',
    'BE01': 'Identification of end customer is not consistent with associated account number. (formerly CreditorConsistency)',
    'BE04': 'Specification of creditor\'s address, which is required for payment, is missing/not correct (formerly IncorrectCreditorAddress)',
    'BE05': 'Party who initiated the message is not recognised by the end customer',
    'BE06': 'End customer specified is not known at associated Sort/National Bank Code or does no longer exist in the books',
    'BE07': 'Specification of debtor\'s address, which is required for payment, is missing/not correct',
    'DT01': 'Invalid date (eg, wrong settlement date)',
    'FF01': 'File format incomplete or invalid',
    'MD01': 'No Mandate',
    'MD02': 'Mandate related information data required by the scheme is missing',
    'MD07': 'End customer is deceased',
    'MD08': 'Receiving agent does not offer specified Mandate services',
    'MD09': 'Account is not open to specified Mandates services',
    'MD10': 'Account is not open to specified Mandates services for this particular creditor',
    'MD11': 'Agent to whom the message needs to be forwarded cannot be located',
    'MD12': 'Mandate identification is not unique to the creditor',
    'MD13': 'There is a problem with the customer authentication',
    'MD14': 'Agent in the payment workflow is incorrect',
    'MD15': 'Currency of the transaction is incorrect',
    'MD16': 'Cancellation/amendment requested by the debtor',
    'MD17': 'Cancellation/amendment requested by the creditor',
    'MD18': 'Cancellation/amendment requested by the creditor and the debtor',
    'MD19': 'Mandate cancellation following early reimbursement of the debit by the debtor',
    'MD20': 'Mandate cancellation following validity expiration',
    'MD21': 'Mandate cancellation due to suspected fraud',
    'MD22': 'Mandate cancellation following mandate initiation cancellation',
    'MD23': 'Mandate cancellation following mandate amendment cancellation',
    'MS02': 'Reason has not been specified by end customer',
    'MS03': 'Reason has not been specified by agent',
    'NARR': 'Reason is provided as narrative information in the additional reason information',
    'RC01': 'Bank Identifier code specified in the message has an incorrect format (formerly IncorrectFormatForRoutingCode)',
    'RF01': 'Transaction reference is not unique within the message',
    'RR01': 'Specification of the debtor’s account or unique identification needed for reasons of regulatory requirements is insufficient or missing',
    'RR02': 'Specification of the debtor’s name and/or address needed for regulatory requirements is insufficient or missing',
    'RR03': 'Specification of the creditor’s name and/or address needed for regulatory requirements is insufficient or missing',
    'RR04': 'Regulatory Reason',
    'SL01': 'Due to specific service offered by the Debtor Agent',
    'SL11': 'Whitelisting service offered by the Debtor Agent; Debtor has not included the Creditor on its “Whitelist” (yet). In the Whitelist the Debtor may list all allowed Creditors to debit Debtor bank account',
    'SL12': 'Blacklisting service offered by the Debtor Agent; Debtor included the Creditor on his “Blacklist”. In the Blacklist the Debtor may list all Creditors not allowed to debit Debtor bank account',
    'SL13': 'Due to Maximum allowed Direct Debit Transactions per period service offered by the Debtor Agent',
    'SL14': 'Due to Maximum allowed Direct Debit Transaction amount service offered by the Debtor Agent',
}

# ExternalMandateStatus1Code
MANDATE_STATUS = {
    'ACTV': 'The mandate is active',
    'CANC': 'The mandate is cancelled',
    'EXPI': 'The mandate has passed the end date',
    'SUSP': 'The mandate is put on hold',
}

# ExternalMandateSuspensionReason1Code
MANDATE_SUSPENSION_REASON = {
    'CTAM': 'Mandate suspended due to amendment of the contract',
    'CTCA': 'Mandate suspended due to cancellation of the contract, requested by the debtor',
    'CTEX': 'Mandate suspended due to the contract that expired',
    'MCFC': 'Mandate suspended as final collection took place',
    'MCOC': 'Mandate suspended as the once off collection took place',
    'MSUC': 'Mandate suspended after 7 consecutive unsuccessful collections',
}

# ExternalMarketArea1Code
MARKET_AREA = {
    'ANYY': 'Any market area',
    'CASH': 'Bank to bank cash movements',
    'COLL': 'Collections',
    'COMM': 'Precious metals and other commodities such as palm oil',
    'COPA': 'Payment in which one of the parties is not a financial institution',
    'DERI': 'Futures contracts, options, forward contracts, swaps, etc',
    'DOCC': 'Documentary credits',
    'FOEX': 'Foreign exchange',
    'GUAR': 'Guarantees',
    'LETT': 'Letters of credit',
    'LOAN': 'Loans and deposits',
    'MMKT': 'Money markets',
    'NDLF': 'FX forward trade for which only balance is settled',
    'OFFS': 'Offshore settlement',
    'ONSH': 'Onshore settlement',
    'OPTI': 'FX Options, swap options, etc',
    'SECU': 'Bonds, equities, futures',
    'TFIN': 'Documentary credits, collections, guarantees, letters of credit',
    'TREA': 'Cash management activities',
}

# ExternalMarketInfrastructure1Code
MARKET_INFRASTRUCTURE = {
    'ABE': 'EBA Euro1/Step1',
    'ACH': 'Automated Clearing House. Payment system that clears cash transfers and settles the proceeds in a lump sum, usually on a multilateral netting basis',
    'ACS': 'Canadian Dollar (CAD) - Automated Clearing Settlement System (ACSS)',
    'AIP': 'AL (Albania) - Albania Interbank Payment System',
    'ART': 'AT (Austria) - Austrian RTGS (ARTIS)',
    'AVP': 'NZ (New Zealand) - New Zealand Assured Value Payments',
    'AZM': 'AZ (Azerbaijan) - Azerbaijan Interbank Payment System (AZIPS)',
    'BAP': 'BA (Bosnia and Herzegovina)',
    'BCC': 'SE (Sweden) - Sweden BGC Clearing CUG',
    'BCE': 'EC (Ecuador) - Ecuadorian Central Payment System (Sistema Central de Pagos Ecuatoriano)',
    'BDS': 'BB (Barbados) - Barbados RTGS (CBRTGS)',
    'BEL': 'BE (Belgium) - Belgium RTGS (ELLIPS)',
    'BGN': 'BG (Bulgaria) - Bulgaria RTGS',
    'BHS': 'BS (Bahamas) - Bahamas RTGS',
    'BIS': 'BW (Botswana) - Botswana Interbank Settlement System',
    'BOF': 'FI (Finland) - RTGS (BOF)',
    'BOJ': 'the Bank of Japan clearing system',
    'BRL': 'IT (Italy) - Italy RTGS (BIREL)',
    'BSP': 'PH (Philippines) - Philippines Payment System',
    'CAD': 'CA (Canada) - Canadian Large Value Transfer System (LVTS)',
    'CAM': 'ES (Spain)',
    'CBA': 'AW (Aruba) - Central Bank of Aruba CSM',
    'CBJ': 'IE (Ireland) - Irish RTGS (IRIS)',
    'CHI': 'US - The Clearing House CHIPS',
    'CHP': 'GB (UK) - British Euro RTGS (CHAPS)',
    'CIS': 'Central Interoperability Service of the EACHA Clearing Cooperative, for exchanging SEPA payments between Automated Clearing Houses in the EEA',
    'CLM': 'Payments and cash management system that settles individual payments and cash transfers in central bank money',
    'COE': 'CO (Columbia) - Colombian Electronic Cheque System named CEDEC (Compensación Electrónica De Cheques)',
    'COI': 'CO (Columbia) - Colombian Central Bank´s ACH named CENIT (Compensación Electrónica Nacional Interbancaria)',
    'COU': 'CO (Columbia) - Colombian RTGS System named CUD (Cuentas de Depósito)',
    'DDK': 'DK (Denmark) - Danish Krone RTGS (KRONOS)',
    'DKC': 'DK (Denmark) - Danish Euro RTGS (KRONOS)',
    'EBA': 'EBA Euro1',
    'ELS': 'DE (Germany)',
    'EMZ': 'Elektronischer Massenzahlungsverkehr (EMZ)',
    'EPM': 'ECB (European Central Bank) - ECB Payment Mechanism',
    'EPN': 'US - The Clearing House EPN',
    'ERP': 'EBA step 1 (members)',
    'FDA': 'US (United States) - FED-ACH',
    'FDN': 'FedNet is a link to a Federal Bank account via the internet. FedNet enables checking of account balance, transactions, take print outs of account statement, transfer funds to third party accounts, E-shopping, BSNL Payments, Deposit opening, Deposit Renewal, Request for Demand Draft, Cheque Book etc',
    'FDW': 'US (United States) – FEDWIRE',
    'FEY': 'JP (Japan) the Foreign Exchange Yen Clearing system (FEYCS). It is the Japanese electronic interbank system for sending guaranteed and unconditional yen payments of FX deals for same day settlement from one settlement bank, on behalf of itself or its customers, to another settlement bank',
    'GIS': 'GH (Ghana) - Ghana Interbank Settlement System (GISS)',
    'HRK': 'HR (Croatia) - HSVP',
    'HRM': 'GR (Greece) - Greek RTGS (HERMES)',
    'HUF': 'HU (Hungary) - VIBER',
    'INC': 'DE and NL - Equens',
    'JOD': 'JO (Jordan) - Jordan RTGS',
    'KPS': 'KE (Kenya) - Kenyan Electronic Payment Settlement System',
    'LGS': 'LU (Luxemburg) - Luxembourg RTGS (LIPS)',
    'LKB': 'LK (Sri Lanka) - Sri Lanka (Lankasettle)',
    'LVL': 'LV (Latvia)',
    'LVT': 'CA (Canada) - Large Value Transfer System (LVTS). Replaces CAD',
    'MEP': 'SG (Singapore) - Singapore RTGS (MEPS+)',
    'MOS': 'ZA (South Africa) - South-African Multiple Option Settlement',
    'MRS': 'MT (Malta) - Malta Realtime Interbank Settlement System',
    'MUP': 'MU (Mauritius)',
    'NAM': 'NA (Namibian) - Namibian Interbank Settlement System',
    'NOC': 'NO (Norway)',
    'NPP': 'AU (Australia) - New Payments Platform (NPP)',
    'PCH': 'CH (Switzerland)',
    'PDS': 'AU (Australia)',
    'PEG': 'EG (Egypt)',
    'PNS': 'FR (France)',
    'PTR': 'AO (Angola) - Angola RTGS',
    'PVE': 'Ve (Venezuela)',
    'ROL': 'RO (Romania) - Romanian Electronic Payment Operations RT',
    'ROS': 'RO (Romania) - Romanian GSRS',
    'RTG': 'Real Time Gross Settlement System. Payment system that simultaneously clears individual transfers and settles them in central bank money',
    'RTP': 'DE (Germany)',
    'SCL': 'DE – SEPA-Clearer of the Retail Payment System operated by Deutsche Bundesbank',
    'SCP': 'CL (Chile) - Chilean Interbank Payment System',
    'SEC': 'SE (Sweden) - Swedish Euro RTGS (SEC)',
    'SEU': 'CH (Switzerland) – Swiss EUR RTGS named euroSIC',
    'SIC': 'CH (Switzerland) – Swiss CHF RTGS named SIC',
    'SIP': 'CH (Switzerland) – Swiss Instant Payment service in CHF operated by SIX Interbank Clearing',
    'SIT': 'SI (Slovenia)',
    'SLB': 'ES (Spain) - Spanish RTGS (SLBE)',
    'SPG': 'PT (Portugal) - Portuguese RTGS (SPGT)',
    'SSK': 'SE (Sweden) - SEK RTGS (RIX)',
    'ST2': 'EBA Clearing STEP 2',
    'STG': 'UK (United Kingdom) - CHAPS Sterling RTGS',
    'T2S': 'T2S',
    'TBF': 'FR (France) - French RTGS (TBF)',
    'TCH': 'US - The Clearing House Real-TimePayment System',
    'TGT': 'Target',
    'THB': 'TH (Thailand) - Thailand Payment System (BAHTNET)',
    'THN': 'TH (Thailand) - National ITMX Payment System',
    'TIS': 'TZ (Tanzania) - Tanzania Interbank Settlement System (TISS)',
    'TOP': 'NL (Netherlands) - Dutch RTGS (TOP)',
    'TTD': 'TT (Trinidad and Tobago ) - Trinidad and Tobago SAFE-TT',
    'UBE': 'United States Dollar (USD)',
    'UIS': 'UG (Uganda) - Uganda National Interbank Settlement System',
    'VCS': 'VocaLink Clearing System',
    'XCT': 'EBA step 2',
    'ZEN': 'JP (Japan) the Zengin system. The electronic payment system for domestic third party transfers managed by the Tokyo Bankers Association',
    'ZET': 'ZW (Zimbabwe) - Zimbabwe Electronic Transfer & Settlement System',
    'ZIS': 'ZM (Zambia) - Zambian Interbank Payment &Settlement System',
}

# ExternalModelFormIdentification1Code
MODEL_FORM_IDENTIFICATION = {
    'ISP1': 'ISP98 model form for standby incorporating annexed form of payment demand with statement',
    'ISP2': 'ISP98 model form or standby providing for extension and incorporating annexed form of payment demand with alternative non-extension statement',
    'ISP3': 'ISP98 model form or standby providing for reduction and incorporating annexed form of reduction demand',
    'ISP4': 'ISP98 model form for standby providing for transfer and incorporating annexed form of transfer demand',
    'ISP5': 'ISP98 model form for simplified demand only standby',
    'ISP6': 'ISP98 model form for counter standby with annexed form of local bank undertaking',
    'ISP7': 'ISP98 model form for standby requiring confirmation',
    'ISP8': 'ISP98 model form for confirmation of standby',
    'UDG1': 'Model form for demand guarantee defined in the latest version of the ICC Uniform Rules For Demand Guarantees (URDG)',
    'UDG2': 'Model form for counter-guarantee defined in the latest version of the ICC Uniform Rules For Demand Guarantees (URDG)',
}

# ExternalNarrativeType1Code
NARRATIVE_TYPE = {
    'ADDI': 'Narrative text describing the additional terms and conditions',
    'CHAR': 'Narrative text describing the charge details',
    'DRAW': 'Narrative text describing the drawing details',
    'PRAS': 'Narrative text describing the assignment of proceeds terms and conditions',
    'TEFF': 'Narrative text describing the terms of effectiveness',
    'TRNF': 'Narrative text describing the transfer terms and conditions',
    'TVAR': 'Narrative text describing the terms of variation',
}

# ExternalOrganisationIdentification1Code
ORGANISATION_IDENTIFICATION = {
    'BANK': 'Unique and unambiguous assignment made by a specific bank or similar financial institution to identify a relationship as defined between the bank and its client',
    'CBID': 'A unique identification number assigned by a central bank to identify an organisation',
    'CHID': 'A unique identification number assigned by a clearing house to identify an organisation',
    'CINC': 'A unique identification number assigned by a designated authority to a certificate of incorporation and used to identify an organisation',
    'COID': 'Country authority given organisation identification (e.g., corporate registration number)',
    'CUST': 'Number assigned by an issuer to identify a customer. Number assigned by a party to identify a creditor or debtor relationship',
    'DUNS': 'A unique identification number provided by Dun & Bradstreet to identify an organisation',
    'EMPL': 'Number assigned by a registration authority to an employer',
    'GS1G': 'Global Location Number. A non-significant reference number used to identify legal entities, functional entities, or physical entities according to GS1 numbering scheme rules.The number is used to retrieve detailed information that is linked to it',
    'SREN': 'The SIREN number is a 9 digit code assigned by INSEE, the French National Institute for Statistics and Economic Studies, to identify an organisation in France',
    'SRET': 'The SIRET number is a 14 digit code assigned by INSEE, the French National Institute for Statistics and Economic Studies, to identify an organisation unit in France. It consists of the SIREN number, followed by a five digit classification number, to identify the local geographical unit of that entity',
    'TXID': 'Number assigned by a tax authority to identify an organisation',
    'BDID': 'Identifier of the business domain in which the organisation is active',
    'BOID': 'Other identification of the organisation',
}

# ExternalPackagingType1Code
PACKAGING_TYPE = {
    'HDPE': 'Packaging is high density polyethylene',
    'LDPE': 'Packaging is low density polyethylene',
    'LLDP': 'Packaging is linear low density polyethylene',
    'OTHR': 'Other packaging type not otherwise specified',
}

# ExternalPaymentCancellationRejection1Code
PAYMENT_CANCELLATION_REJECTION = {
    'AC04': 'Account number specified has been closed on the receiver’s books',
    'ADAC': 'Reported when the cancellation request cannot be processed because customer has not yet provided the debit authority on its account',
    'AGNT': 'Reported when the cancellation cannot be accepted because of an agent refuses to cancel',
    'AM04': 'Amount of funds available to cover specified message amount is insufficient',
    'ARDT': 'Cancellation not accepted as the transaction has already been returned',
    'ARPL': 'Reported when the cancellation request cannot be processed because no reply has been  received yet from the receiver of the request message',
    'CUST': 'Reported when the cancellation cannot be accepted because of a customer decision (Creditor)',
    'LEGL': 'Reported when the cancellation cannot be accepted because of regulatory rules',
    'NARR': 'Reason is provided as narrative information in the additional reason information',
    'NOAS': 'No response from beneficiary (to the cancellation request)',
    'NOOR': 'Original transaction (subject to cancellation) never received',
    'PTNA': 'Reported when the cancellation request cannot be accepted because the payment instruction has been passed to the next agent',
    'RQDA': 'Reported when authority is required by the Creditor to return the payment',
    'WSEQ': 'Reported when the cancellation request cannot be processed because the sequence referred to in the request is not valid',
    'IDMN': 'Complementing a Pending or Reject Status. Payment cancellation request cannot be accepted until an indemnity agreement is established',
    'ACLR': 'Request-to-pay has already been cancelled',
    'AEXR': 'Request-to-pay Expiry Date and Time has already passed',
    'ARFR': 'Request-to-pay has already been refused by the Debtor',
    'ARJR': 'Request-to-pay has already been rejected',
    'PATE': 'Payment related to the request-to-pay has already been transmitted for execution',
    'RR04': 'Regulatory Reason',
    'RCAR': 'Request for cancellation of the request-to-pay has already been rejected',
    'RCNR': 'Request for cancellation of the request-to-pay has never been received',
    'RCPR': 'Request for cancellation of the request-to-pay has already been received and processed',
    'URTP': 'Request-to-pay is unknown',
}

# ExternalPaymentCompensationReason1Code
PAYMENT_COMPENSATION_REASON = {
    'VADA': 'Compensation requested for value date correction',
}

# ExternalPaymentControlRequestType1Code
PAYMENT_CONTROL_REQUEST_TYPE = {
    'RT01': 'Type is a request to release the pending transactions',
    'RT02': 'Type is a request to hold normal transactions',
    'RT03': 'Type is a request to cancel a transaction',
    'RT04': 'Type is a request to change the sequence of the transactions',
    'RT05': 'Type is a request to release the suspicious transactions',
}

# ExternalPaymentGroupStatus1Code
PAYMENT_GROUP_STATUS = {
    'ACCP': 'Preceding check of technical validation was successful. Customer profile check was also successful',
    'ACCC': 'Settlement on the creditor\'s account has been completed',
    'ACSC': 'Settlement on the debtor\'s account has been completed. Usage : this can be used by the first agent to report to the debtor that the transaction has been completed. Warning : this status is provided for transaction status reasons, not for financial information. It can only be used after bilateral agreement',
    'ACSP': 'All preceding checks such as technical validation and customer profile were successful and therefore the payment initiation has been accepted for execution',
    'ACTC': 'Authentication and syntactical and semantical validation are successful',
    'ACWC': 'Instruction is accepted but a change will be made, such as date or remittance not sent',
    'PART': 'A number of transactions have been accepted, whereas another number of transactions have not yet achieved \'accepted\' status',
    'PDNG': 'Payment initiation or individual transaction included in the payment initiation is pending. Further checks and status update will be performed',
    'RCVD': 'Payment initiation has been received by the receiving agent',
    'RJCT': 'Payment initiation or individual transaction included in the payment initiation has been rejected',
}

# ExternalPaymentModificationRejection1Code
PAYMENT_MODIFICATION_REJECTION = {
    'UM01': 'Related transaction reference cannot be modified',
    'UM02': 'Service level element of payment type cannot be modified(former UnableToModifyBankOperationCode)',
    'UM03': 'Category purpose element of payment type cannot be modified (former UnableToModifyInstructionCode)',
    'UM04': 'RequestedExecutionDate cannot be modified',
    'UM05': 'InterbankSettlementDate cannot be modified (former UnableToModifyValueDate)',
    'UM06': 'SettlementAccount cannot be modified (former UnableToModifyInterbankSettlementAccount)',
    'UM07': 'Debtor cannot be modified',
    'UM08': 'DebtorAccount cannot be modified',
    'UM09': 'InstructedReimbursementAgent cannot be modified (former UnableToModifyReceiverCorrespondent)',
    'UM10': 'ThirdReimbursementAgent cannot be modified (former UnableToModifyThirdReimbursementInstitution)',
    'UM11': 'Clearing Channel element of payment type cannot be modified (former UnableToModifyPaymentScheme)',
    'UM12': 'Creditor agent account cannot be modified (former UnableToModifyAccountOfBeneficiaryInstitution)',
    'UM13': 'Creditor cannot be modified',
    'UM14': 'Creditor account cannot be modified',
    'UM15': 'Remittance information cannot be modified',
    'UM16': 'PaymentPurpose cannot be modified',
    'UM17': 'Charge bearer cannot be modified (former UnableToModifyDetailsOfCharges)',
    'UM18': 'Instruction for next agent cannot be modified (former UnableToModifySenderToReceiver)',
    'UM19': 'Instruction for creditor agent cannot be modified. (former UnableToModifyInstructionForFinalAgent)',
    'UM20': 'Used to inform of cancellation and request a new payment instruction. This should only be used if an agent does not want to modify a pending payment',
    'UM21': 'Modification is not possible and the cancellation is requested',
    'UM22': 'Debtor agent account cannot be modified (applicable for direct debits)',
    'UM23': 'Interbank settlement amount cannot be modified',
    'UM24': 'Instruction for debtor agent cannot be modified (applicable for direct debits)',
    'UM25': 'Requested collection date cannot be modified (applicable for direct debits)',
    'UM26': 'Payment type cannot be modified',
    'UM27': 'Instructed or equivalent amount cannot be modified',
    'UM28': 'Priority of payment message cannot be modified',
}

# ExternalPaymentRole1Code
PAYMENT_ROLE = {
    'BKMG': 'Party responsible for managing the recovery functions related to a system',
    'LMMG': 'Party in a financial institution responsible for the management of the limits. This party is responsible for fixing, modifying, or suspending limits as relevant for the management of counterpart risk or systemic risk containment',
    'LQMG': 'Party in a financial institution responsible for the management of liquidity for the financial institution. This party has access to some functions available on the system, such as the liquidity transfers or management of standing instructions for liquidity control',
    'PYMG': 'Party in a financial institution responsible for the management of payment processing for the financial institution. This includes authorising, recycling, and modification of payment transactions',
    'REDR': 'Party in a financial institution entitled to obtain information from the system, but not act upon/alter this information',
    'STMG': 'Party in a financial institution responsible for the management of settlement processing',
}

# ExternalPaymentTransactionStatus1Code
PAYMENT_TRANSACTION_STATUS = {
    'ACCC': 'Settlement on the creditor\'s account has been completed',
    'ACCP': 'Preceding check of technical validation was successful. Customer profile check was also successful',
    'ACFC': 'Preceding check of technical validation and customer profile was successful and an automatic funds check was positive',
    'ACIS': 'Payment instruction to issue a cheque has been accepted, and the cheque has been issued but not yet been deposited or cleared',
    'ACSC': 'Settlement completed. Usage : this can be used by a Market Infrastructure reporting to Infrastructure Participant or an Account Servicer to Account Owner to report that the transaction account entry has been completed. Warning : this status is provided for transaction status reasons, not for financial information. It can only be used after bilateral agreement',
    'ACSP': 'All preceding checks such as technical validation and customer profile were successful and therefore the payment instruction has been accepted for execution',
    'ACTC': 'Authentication and syntactical and semantical validation are successful',
    'ACWC': 'Instruction is accepted but a change will be made, such as date or remittance not sent',
    'ACWP': 'Payment instruction included in the credit transfer is accepted without being posted to the creditor customer’s account',
    'BLCK': 'Payment transaction previously reported with status \'ACWP\' is blocked, for example, funds will neither be posted to the Creditor\'s account, nor be returned to the Debtor',
    'CANC': 'Payment initiation has been successfully cancelled after having received a request for cancellation. Usage: code to be used in the context of APIs only',
    'CPUC': 'Cash has been picked up by the Creditor',
    'PATC': 'Payment initiation needs multiple authentications, where some but not yet all have been performed. Syntactical and semantical validations are successful',
    'PDNG': 'Payment instruction is pending. Further checks and status update will be performed',
    'PRES': 'Request for Payment has been presented to the Debtor',
    'RCVD': 'Payment instruction has been received',
    'RJCT': 'Payment instruction has been rejected',
    'ACPD': 'Status of transaction released from the Debtor Agent and accepted by the clearing',
}

# ExternalPendingProcessingReason1Code
PENDING_PROCESSING_REASON = {
    'ADEA': 'Received after the servicer\'s deadline. Processed on best effort basis',
    'DISA': 'Exceptional closing of all financial institutions due to natural disaster, for example, earthquake',
    'ESCA': 'Special follow-up is taking place',
    'IAAD': 'Pending reason being investigated',
    'LPRO': 'Longer processing timeframe for this type of SSI',
    'MINF': 'Information, for example, currency is missing',
    'NEWI': 'Financial instrument is a new issue and not yet available/tradable',
    'NEXT': 'Next process is launched. No processing pending problems to be reported',
    'NSTP': 'Instruction was not straight through processing and had to be processed manually',
    'PRSY': 'Transaction was put on hold/frozen by the system',
}

# ExternalPersonIdentification1Code
PERSON_IDENTIFICATION = {
    'ARNU': 'Number assigned by a social security agency to identify a non-resident person',
    'CCPT': 'Number assigned by an authority to identify the passport number of a person',
    'CUST': 'Number assigned by an issuer to identify a customer',
    'DRLC': 'Number assigned by an authority to identify a driver\'s license',
    'EMPL': 'Number assigned by a registration authority to an employee',
    'NIDN': 'Number assigned by an authority to identify the national identity number of a person',
    'SOSE': 'Number assigned by an authority to identify the social security number of a person',
    'TELE': 'Number assigned by a telephone or mobile phone operator to identify a person. A person may have multiple phone numbers',
    'TXID': 'Number assigned by a tax authority to identify a person',
    'POID': 'Commercial identification of the person',
}

# ExternalProxyAccountType1Code
PROXY_ACCOUNT_TYPE = {
    'TELE': 'A telephone number in the format specified by the \'The international public telecommunication numbering plan ITU-T E.164',
    'EMAL': 'Internationalised address of an electronic mail box for internet messages',
    'DNAM': 'Internationalised internet domain name',
    'CINC': 'Corporate Identification issued by a national institution or regulator, used as account proxy. (applied for corporate account proxy)',
    'COTX': 'Unique government-issued tax Identification used as account proxy to identify the corporate (for example for government tax) and typically linked to the corporate bank account (applied for corporate account proxy)',
    'COID': 'Identification issued by a national institution or regulator (different from a national scheme like a clearing provider), used as account proxy (applied for corporate or individual account proxy)',
    'CUST': 'Any other customer identification number issued by a corporate, bank or other organization, used as account proxy. (applied for corporate or individual account proxy)',
    'DRLC': 'Unique government-issued Identification used as account proxy to identify the individual (for example for government charges, road taxes and tolls,vaccination charges) and typically linked to the individual\'s bank account (applied for individual account proxy)',
    'EIDN': 'Government-issued Identification (different from a passport Identification or a national Identification). Used as account proxy to identify the individual (for example for public benefits) and typically linked to the individual\'s bank account (applied for individual account proxy)',
    'EWAL': 'Market-adopted prepaid instruments like e-Wallets, payments to / from e-wallets from / to bank accounts (applied for corporate or individual account proxy)',
    'PVTX': 'Unique government-issued tax Identification used as account proxy to identify the individual for example for government tax) and typically linked to the individual\'s bank account (applied for individual account proxy)',
    'LEIC': 'Legal Entity Identifier used as account proxy (applied for corporate account proxy). Use cases: Can be used by corporates as a "government-issued" Identification for registration with payment schemes as a proxy. The proxy may be further used for payments and collections using the underlying instant payment rails for a variety of corporate use cases',
    'MBNO': 'Mobile phone number in the format specified by the “The international public telecommunication numbering plan ITU- T E 164" (applied for corporate or individual account proxy)',
    'NIDN': 'Unique government-issued Identification used as account proxy to identify the individual or corporate for example for public benefits, government subsidies) and typically linked to the individual\'s / corporate bank account. (applied for corporate or individual account proxy)',
    'CCPT': 'Unique government-issued Identification used as account proxy to identify the individual (for example for government charges, road taxes, vaccination charges) and typically linked to the individual\'s bank account (applied for individual account proxy)',
    'SHID': 'Account proxy issued by a payment scheme (applied for corporate or individual account proxy). Use cases: Any proxies issued by clearing systems, for example VPA (India), FPS Identifier (Hong Kong), Jompay (Malaysia) CCIN (Canada)',
    'SOSE': 'Unique government-issued Identification used as account proxy to identify the individual (for example for public benefits) and typically linked to the individual\'s bank account (applied for individual account proxy)',
    'TOKN': 'Electronic Identification used, for example, to mask an account number as a means of data secrecy. (applied for corporate or individual account proxy)',
    'UBIL': 'Subscriber Identification for utilities and services. As opposed to a biller Identification, this identification is used for the subscriber of the service (applied for corporate or individual account proxy)',
    'VIPN': 'Account proxy for receiving insurance claims, pay insurance premium, road tax payments, traffic tickets etc.(applied for corporate or individual account proxy)',
    'BIID': 'Billers of specific utilities could register for a Biller Identification as supported in the clearing scheme, and use this identification for collections (applied for corporate account proxy)',
}

# ExternalPurpose1Code
PURPOSE = {
    'BKDF': 'Delayed draw funding. Certain issuers may utilize delayed draw loans whereby the lender is committed to fund cash within a specified period once a call is made by the issuer. The lender receives a fee for entering into such a commitment',
    'BKFE': 'Bank loan fees. Cash activity related to specific bank loan fees, including (a) agent / assignment fees; (b) amendment fees; (c) commitment fees; (d) consent fees; (e) cost of carry fees; (f) delayed compensation fees; (g) facility fees; (h) fronting fees; (i) funding fees; (j) letter of credit assignment fees',
    'BKFM': 'Bank loan funding memo. Net cash movement for the loan contract final notification when sent separately from the loan contract final notification instruction',
    'BKIP': 'Accrued interest payments. Specific to bank loans',
    'BKPP': 'Principal paydowns. Specific to bank loans',
    'CBLK': 'A Service that is settling money for a bulk of card transactions, while referring to a specific transaction file or other information like terminal ID, card acceptor ID or other transaction details',
    'CDCB': 'Purchase of Goods and Services with additional Cash disbursement at the POI (Cashback)',
    'CDCD': 'ATM Cash Withdrawal in an unattended or Cash Advance in an attended environment (POI or bank counter)',
    'CDCS': 'ATM Cash Withdrawal in an unattended or Cash Advance in an attended environment (POI or bank counter) with surcharging',
    'CDDP': 'A combined service which enables the card acceptor to perform an authorisation for a temporary amount and a completion for the final amount within a limited time frame. Deferred Payment is only available in the unattended environment. Examples where this service is widely used are unattended petrol pumps and phone booths',
    'CDOC': 'A service which allows the card acceptor to effect a credit to a cardholder\' account. Unlike a Merchant Refund, an Original Credit is not preceded by a card payment. This service is used for example for crediting winnings from gaming',
    'CDQC': 'Purchase of Goods which are equivalent to cash like coupons in casinos',
    'ETUP': 'Transaction is related to a Service that is first reserving money from a card account and then is loading an e-purse application by this amount',
    'FCOL': 'A Service that is settling card transaction related fees between two parties',
    'MTUP': 'A Service that is first reserving money from a card account and then is loading a prepaid mobile phone amount by this amount',
    'ACCT': 'Transaction moves funds between 2 accounts of same account holder at the same bank',
    'CASH': 'Transaction is a general cash management instruction',
    'COLL': 'Transaction is a collection of funds initiated via a credit transfer or direct debit',
    'CSDB': 'Transaction is related to cash disbursement',
    'DEPT': 'Transaction is releted to a payment of deposit',
    'INTC': 'Transaction is an intra-company payment, ie, a payment between two companies belonging to the same group',
    'INTP': 'Transaction is a payment between two accounts belonging to the same party (intra-party payment), where party is a natural person (identified by a private ID, not organisation ID)',
    'LIMA': 'Bank initiated account transfer to support zero target balance management, pooling or sweeping',
    'NETT': 'Transaction is related to a netting operation',
    'BFWD': 'Cash collateral related to any securities traded out beyond 3 days which include treasury notes, JGBs and Gilts',
    'CCIR': 'Cash Collateral related to a Cross Currency Interest Rate Swap, indicating the exchange of fixed interest payments in one currency for those in another',
    'CCPC': 'Cash Collateral associated with an ISDA or Central Clearing Agreement that is covering the initial margin requirements for OTC trades clearing through a CCP',
    'CCPM': 'Cash Collateral associated with an ISDA or Central Clearing Agreement that is covering the variation margin requirements for OTC trades clearing through a CCP',
    'CCSM': 'CCP Segregated initial margin: Initial margin on OTC Derivatives cleared through a CCP that requires segregation',
    'CRDS': 'Cash collateral related to trading of credit default swap',
    'CRPR': 'Cash collateral related to a combination of various types of trades',
    'CRSP': 'Cash collateral related to cash lending/borrowing; letter of Credit; signing of master agreement',
    'CRTL': 'Cash collateral related to opening of a credit line before trading',
    'EQPT': 'Cash collateral related to trading of equity option (Also known as stock options)',
    'EQUS': 'Cash collateral related to equity swap trades where the return of an equity is exchanged for either a fixed or a floating rate of interest',
    'EXPT': 'Cash collateral related to trading of an exotic option for example a non-standard option',
    'EXTD': 'Cash collateral related to trading of exchanged traded derivatives in general (Opposite to Over the Counter (OTC))',
    'FIXI': 'Cash collateral related to a fixed income instrument',
    'FWBC': 'Cash collateral payment against a Master Forward Agreement (MFA) where the cash is held in a segregated account and is not available for use by the client. Includes any instruments with a forward settling date such TBAs, repurchase agreements and bond forwards',
    'FWCC': 'Cash collateral payment against a Master Forward Agreement (MFA) where the cash is owned and may be used by the client when returned. Includes any instruments with a forward settling date such TBAs, repurchase agreements and bond forwards',
    'FWSB': 'Any cash payment related to the collateral for a Master Agreement forward, which is segregated, and not available for use by the client. Example master agreement forwards include TBA, repo and Bond Forwards',
    'FWSC': 'Any cash payment related to the collateral for a Master agreement forward, which is owned by the client and is available for use by the client when it is returned to them from the segregated account. Example master agreement forwards include TBA, repo and Bond Forwards',
    'MARG': 'Daily margin on listed derivatives – not segregated as collateral associated with an FCM agreement. Examples include listed futures and options margin payments; premiums for listed options not covered in the MT54X message',
    'MBSB': 'MBS Broker Owned Segregated (40Act/Dodd Frank) Cash Collateral - Any cash payment related to the collateral for a Mortgage Back Security, which is segregated, and not available for use by the client',
    'MBSC': 'MBS Client Owned Cash Segregated (40Act/Dodd Frank) Cash Collateral - Any cash payment related to the collateral for a Mortgage Back Security, which is owned by the client and is available for use by the client when it is returned to them from the segregated account',
    'MGCC': 'Initial futures margin. Where such payment is owned by the client and is available for use by them on return',
    'MGSC': 'Margin Client Owned Segregated Cash Collateral - Any cash payment related to the collateral for initial futures margin, which is owned by the client and is available for use by the client when it is returned to them from the segregated account',
    'OCCC': 'Client owned collateral identified as eligible for OCC pledging',
    'OPBC': 'Cash collateral payment for OTC options associated with an FCM agreement. Where such payment is segregated and not available for use by the client',
    'OPCC': 'Cash collateral payment for OTC options associated with an FCM agreement. Where such payment is not segregated and is available for use by the client upon return',
    'OPSB': 'Option Broker Owned Segregated Cash Collateral - Any cash payment related to the collateral for an OTC option, which is segregated, and not available for use by the client',
    'OPSC': 'Option Client Owned Cash Segregated Cash Collateral - Any cash payment related to the collateral for an OTC option, which is owned by the client and is available for use by the client when it is returned to them from the segregated account',
    'OPTN': 'Cash collateral related to trading of option on Foreign Exchange',
    'OTCD': 'Cash collateral related to Over-the-counter (OTC) Derivatives in general for example contracts which are traded and privately negotiated',
    'REPO': 'Cash collateral related to a repurchase agreement transaction',
    'RPBC': 'Bi-lateral repo broker owned collateral associated with a repo master agreement – GMRA or MRA Master Repo Agreements',
    'RPCC': 'Repo client owned collateral associated with a repo master agreement – GMRA or MRA Master Repo Agreements',
    'RPSB': 'Bi-lateral repo broker owned segregated cash collateral associated with a repo master agreement',
    'RPSC': 'Repo client owned segregated collateral associated with a repo master agreement',
    'RVPO': 'Cash collateral related to a reverse repurchase agreement transaction',
    'SBSC': 'Cash collateral related to a Securities Buy Sell Sell Buy Back',
    'SCIE': 'Cash collateral related to Exotic single currency interest rate swap',
    'SCIR': 'Cash collateral related to Single Currency Interest Rate Swap',
    'SCRP': 'Cash collateral related to Combination of securities-related exposure types',
    'SHBC': 'Short Sale broker owned collateral associated with a prime broker agreement',
    'SHCC': 'Short Sale client owned collateral associated with a prime brokerage agreement',
    'SHSL': 'Cash Collateral related to a Short Sell',
    'SLEB': 'Cash collateral related to Securities lending and borrowing',
    'SLOA': 'Cash collateral related to a Secured loan',
    'SWBC': 'Cash collateral payment for swaps associated with an ISDA agreement. . Where such payment is segregated and not available for use by the client. Includes any cash collateral payments made under the terms of a CSA agreement for instruments such as swaps and FX forwards',
    'SWCC': 'Cash collateral payment for swaps associated with an ISDA agreement. Where such payment is not segregated and is available for use by the client upon return. Includes any cash collateral payments made under the terms of a CSA agreement for instruments such as swaps and FX forwards',
    'SWPT': 'Cash collateral related to an option on interest rate swap',
    'SWSB': 'Swaps Broker Owned Segregated Cash Collateral - Any cash payment related to the collateral for Swap margin , which is segregated, and not available for use by the client. This includes any collateral identified in a CSA agreement such as Swap or FX Forward collateral',
    'SWSC': 'Swaps Client Owned Segregated Cash Collateral - Any cash payment related to the collateral for Swap margin, which is owned by the client and is available for use by the client when returned from the segregated account. This includes any collateral identified in a CSA agreement such as Swap or FX Forward collateral',
    'TBAS': 'Cash collateral related to a To Be Announced (TBA)',
    'TBBC': 'Cash collateral payment (segregated) for TBA securities associated with a TBA Master Agreement. Where such payment is segregated and not available for use by the client',
    'TBCC': 'Cash collateral payment (for use by client)for TBA securities associated with a TBA Master Agreement. Where such payment is not segregated and is available for use by the client upon return',
    'TRCP': 'Cash collateral related to a combination of treasury-related exposure types',
    'AGRT': 'Transaction is related to the agricultural domain',
    'AREN': 'Transaction is related to a payment associated with an Account Receivable Entry',
    'BEXP': 'Transaction is related to a payment of business expenses',
    'BOCE': 'Transaction is related to a payment associated with a Back Office Conversion Entry',
    'COMC': 'Transaction is related to a payment of commercial credit or debit. (formerly CommercialCredit)',
    'CPYR': 'Transaction is payment of copyright',
    'GDDS': 'Transaction is related to purchase and sale of goods',
    'GDSV': 'Transaction is related to purchase and sale of goods and services',
    'GSCB': 'Transaction is related to purchase and sale of goods and services with cash back',
    'LICF': 'Transaction is payment of a license fee',
    'MP2B': 'A service which enables a user to use an app on its mobile to pay a merchant or other business payees by initiating a payment message. Within this context, the account information or an alias of the payee might be transported through different channels to the app, for example QR Code, NFC, Bluetooth, other Networks',
    'POPE': 'Transaction is related to a payment associated with a Point of Purchase Entry',
    'ROYA': 'Transaction is the payment of royalties',
    'SCVE': 'Transaction is related to purchase and sale of services',
    'SERV': 'Transaction is related to service charges charged by a service provider',
    'SUBS': 'Transaction is related to a payment of information or entertainment services either in printed or electronic form',
    'SUPP': 'Transaction is related to a payment to a supplier',
    'TRAD': 'Transaction is related to a trade services operation',
    'CHAR': 'Transaction is a payment for charity reasons',
    'COMT': 'Transaction is a payment used by a third party who can collect funds to pay on behalf of consumers, ie credit counseling or bill payment companies',
    'MP2P': 'A service which enables a user to use an app on its mobile to initiate moving funds from his/her bank account to another person’s bank account while not using the account number but an alias information like an MSISDN as account addressing information in his/her app',
    'ECPG': 'E-Commerce payment with payment guarantee of the issuing bank',
    'ECPR': 'E-Commerce payment return',
    'ECPU': 'E-Commerce payment without payment guarantee of the issuing bank',
    'EPAY': 'Transaction is related to ePayment',
    'CLPR': 'Transaction is a payment of car loan principal payment',
    'COMP': 'Transaction is related to the payment of a compensation relating to interest loss/value date adjustment and can include fees',
    'DBTC': 'Collection of funds initiated via a debit transfer',
    'GOVI': 'Transaction is related to a payment of government insurance',
    'HLRP': 'Transaction is related to a payment of property loan',
    'HLST': 'Transaction is related to the settlement of a property loan',
    'INPC': 'Transaction is a payment of car insurance premium',
    'INPR': 'Transaction is related to an insurance premium refund',
    'INSC': 'Transaction is related to the payment of an insurance claim',
    'INSU': 'Transaction is payment of an insurance premium',
    'INTE': 'Transaction is payment of interest',
    'LBRI': 'Transaction is a payment of labor insurance',
    'LIFI': 'Transaction is a payment of life insurance',
    'LOAN': 'Transaction is related to transfer of loan to borrower',
    'LOAR': 'Transaction is related to repayment of loan to lender',
    'PENO': 'Payment based on enforcement orders except those arising from judicial alimony decrees',
    'PPTI': 'Transaction is a payment of property insurance',
    'RELG': 'Transaction is for general rental/lease',
    'RINP': 'Transaction is related to a payment of a recurring installment made at regular intervals',
    'TRFD': 'Transaction is related to a payment of a trust fund',
    'FORW': 'FX trades with a value date in the future',
    'FXNT': 'FX netting if cash is moved by separate wire instead of within the closing FX instruction',
    'ADMG': 'Transaction is related to a payment associated with administrative management',
    'ADVA': 'Transaction is an advance payment',
    'BCDM': 'Transaction is the payment of a domestic bearer cheque',
    'BCFG': 'Transaction is the payment of a foreign bearer cheque',
    'BLDM': 'Transaction is related to a payment associated with building maintenance',
    'BNET': 'Bond Forward pair-off cash net movement',
    'CBFF': 'Transaction is related to capital building fringe fortune, ie capital building in general',
    'CBFR': 'Transaction is related to capital building fringe fortune for retirement',
    'CCRD': 'Transaction is related to a payment of credit card account',
    'CDBL': 'Transaction is related to a payment of credit card bill',
    'CFEE': 'Transaction is related to a payment of cancellation fee',
    'CGDD': 'Transaction is related to a direct debit where the mandate was generated by using data from a payment card at the point of sale',
    'CORT': 'Transaction is related to settlement of a trade, e.g. a foreign exchange deal or a securities transaction',
    'COST': 'Transaction is related to payment of costs',
    'CPKC': 'Transaction is related to carpark charges',
    'DCRD': 'Transaction is related to a debit card payment',
    'DSMT': 'Transaction is the payment of a disbursement due to a specific type of printed order for a payment of a specified sum, issued by a bank or a post office (Zahlungsanweisung zur Verrechnung)',
    'DVPM': 'Code used to pre-advise the account servicer of a forthcoming deliver against payment instruction',
    'EDUC': 'Transaction is related to a payment of study/tuition fees',
    'FACT': 'Payment related to a factor update',
    'FAND': 'Financial aid by State authorities for abolition of consequences of natural disasters',
    'FCPM': 'Transaction is the payment for late fees & charges. E.g Credit card charges',
    'FEES': 'Payment of fees/charges',
    'GIFT': 'Payment with no commercial or statutory purpose',
    'GOVT': 'Transaction is a payment to or from a government department',
    'ICCP': 'Transaction is reimbursement of credit card payment',
    'IDCP': 'Transaction is reimbursement of debit card payment',
    'IHRP': 'Transaction is payment for an installment/hire-purchase agreement',
    'INSM': 'Transaction is related to a payment of an installment',
    'IVPT': 'Transaction is the payment for invoices',
    'MCDM': 'Transaction is the payment of a domestic multi-currency cheque',
    'MCFG': 'Transaction is the payment of a foreign multi-currency cheque',
    'MSVC': 'Transaction is related to a payment for multiple service types',
    'NOWS': 'Transaction is related to a payment for type of services not specified elsewhere',
    'OCDM': 'Transaction is the payment of a domestic order cheque',
    'OCFG': 'Transaction is the payment of a foreign order cheque',
    'OFEE': 'Transaction is related to a payment of opening fee',
    'OTHR': 'Other payment purpose',
    'PADD': 'Transaction is related to a pre-authorized debit origination',
    'PTSP': 'Transaction is related to payment terms specifications',
    'RCKE': 'Transaction is related to a payment associated with a re-presented check entry',
    'RCPT': 'Transaction is related to a payment of receipt',
    'REBT': 'Transaction is the payment of a rebate',
    'REFU': 'Transaction is the payment of a refund',
    'RENT': 'Transaction is the payment of rent',
    'REOD': 'Transaction is for account overdraft repayment',
    'RIMB': 'Transaction is related to a reimbursement of a previous erroneous transaction',
    'RPNT': 'Bi-lateral repo interest net/bulk payment at rollover/pair-off or other closing scenarios where applicable',
    'RRBN': 'Cash payment resulting from a Round Robin',
    'RRCT': 'Transaction is related to a reimbursement for commercial reasons of a correctly received credit transfer',
    'RRTP': 'Transaction is related to a Request to Pay',
    'RVPM': 'Code used to pre-advise the account servicer of a forthcoming receive against payment instruction',
    'SLPI': 'Transaction is payment of a well formatted payment slip',
    'SPLT': 'Split payments. To be used when cash and security movements for a security trade settlement are instructed separately',
    'STDY': 'Transaction is related to a payment of study/tuition costs',
    'TBAN': 'TBA pair-off cash wire net movement',
    'TBIL': 'Transaction is related to a payment of telecommunications related bill',
    'TCSC': 'Transaction is related to a payment associated with charges levied by a town council',
    'TELI': 'Transaction is related to a payment initiated via telephone',
    'TMPG': 'Cash payment resulting from a TMPG Claim',
    'TPRI': 'Tri-Party Repo related interest',
    'TPRP': 'Tri-party Repo related net gain/loss cash movement',
    'TRNC': 'Transaction is payment of a beneficiary prefilled payment slip where beneficiary to payer information is truncated',
    'TRVC': 'Transaction is the payment of a travellers cheque',
    'WEBI': 'Transaction is related to a payment initiated via internet',
    'IPAY': 'Transaction in which the amount is available to the payee immediately',
    'IPCA': 'Transaction in which the Return of the amount is fully returned',
    'IPDO': 'Transaction in which the amount is available to the payee immediately, done for donations, with sending the address data of the payer',
    'IPEA': 'Transaction in which the amount is available to the payee immediately, done in E-commerce, without sending the address data of the payer',
    'IPEC': 'Transaction in which the amount is available to the payee immediately, done in E-commerce, with sending the address data of the payer',
    'IPEW': 'Transaction in which the amount is available to the payee immediately, done in E-commerce',
    'IPPS': 'Transaction in which the amount is available to the payee immediately, done at POS',
    'IPRT': 'Transaction in which the Return of the amount is fully or partial returned',
    'IPU2': 'Transaction is made via an unattending vending machine by using 2-factor-authentification',
    'IPUW': 'Transaction is made via an unattending vending machine by without using 2-factor-authentification',
    'ANNI': 'Transaction settles annuity related to credit, insurance, investments, other.n',
    'CAFI': 'Transaction is the payment of custodian account management fee where custodian bank and current account servicing bank coincide',
    'CFDI': 'Transaction is the payment of capital falling due where custodian bank and current account servicing bank coincide',
    'CMDT': 'Transaction is payment of commodities',
    'DERI': 'Transaction is related to a derivatives transaction',
    'DIVD': 'Transaction is payment of dividends',
    'FREX': 'Transaction is related to a foreign exchange operation',
    'HEDG': 'Transaction is related to a hedging operation',
    'INVS': 'Transaction is for the payment of mutual funds, investment products and shares',
    'PRME': 'Transaction is related to a precious metal operation',
    'SAVG': 'Transfer to savings/retirement account',
    'SECU': 'Transaction is the payment of securities',
    'SEPI': 'Transaction is the payment of a purchase of securities where custodian bank and current account servicing bank coincide',
    'TREA': 'Transaction is related to treasury operations',
    'UNIT': 'Transaction is purchase of Unit Trust',
    'FNET': 'Cash associated with a netting of futures payments. Refer to CCPM codeword for netting of initial and variation margin through a CCP',
    'FUTR': 'Cash related to futures trading activity',
    'ANTS': 'Transaction is a payment for anesthesia services',
    'CVCF': 'Transaction is a payment for convalescence care facility services',
    'DMEQ': 'Transaction is a payment is for use of durable medical equipment',
    'DNTS': 'Transaction is a payment for dental services',
    'HLTC': 'Transaction is a payment for home health care services',
    'HLTI': 'Transaction is a payment of health insurance',
    'HSPC': 'Transaction is a payment for hospital care services',
    'ICRF': 'Transaction is a payment for intermediate care facility services',
    'LTCF': 'Transaction is a payment for long-term care facility services',
    'MAFC': 'Transaction is contribution to medical aid fund',
    'MARF': 'Transaction is related to a medical aid refund',
    'MDCS': 'Transaction is a payment for medical care services',
    'VIEW': 'Transaction is a payment for vision care services',
    'CDEP': 'Payment related to a credit default event',
    'SWFP': 'Final payments for a swap contract',
    'SWPP': 'Partial payment for a swap contract',
    'SWRS': 'Reset payment for a swap contract',
    'SWUF': 'Upfront payment for a swap contract',
    'ADCS': 'Payments for donation, sponsorship, advisory, intellectual and other copyright services',
    'AEMP': 'Payment concerning active employment policy',
    'ALLW': 'Transaction is the payment of allowances',
    'ALMY': 'Transaction is the payment of alimony',
    'BBSC': 'Transaction is related to a payment made as incentive to encourage parents to have more children',
    'BECH': 'Transaction is related to a payment made to assist parent/guardian to maintain child',
    'BENE': 'Transaction is related to a payment to a person who is unemployed/disabled',
    'BONU': 'Transaction is related to payment of a bonus',
    'CCHD': 'Payments made by Government institute related to cash compensation, helplessness, disability. These payments are made by the Government institution as a social benefit in addition to regularly paid salary or pension',
    'COMM': 'Transaction is payment of commission',
    'CSLP': 'Transaction is a payment by a company to a bank for financing social loans to employees',
    'GFRP': 'Compensation to unemployed persons during insolvency procedures',
    'GVEA': 'Transaction is payment to category A Austrian government employees',
    'GVEB': 'Transaction is payment to category B Austrian government employees',
    'GVEC': 'Transaction is payment to category C Austrian government employees',
    'GVED': 'Transaction is payment to category D Austrian government employees',
    'GWLT': 'Payment to victims of war violence and to disabled soldiers',
    'HREC': 'Transaction is a contribution by an employer to the housing expenditures (purchase, construction, renovation) of the employees within a tax free fringe benefit system',
    'PAYR': 'Transaction is related to the payment of payroll',
    'PEFC': 'Transaction is contribution to pension fund',
    'PENS': 'Transaction is the payment of pension',
    'PRCP': 'Transaction is related to a payment of a price',
    'RHBS': 'Benefit for the duration of occupational rehabilitation',
    'SALA': 'Transaction is the payment of salaries',
    'SPSP': 'Salary or pension payment for more months in one amount or a delayed payment of salaries or pensions',
    'SSBE': 'Transaction is a social security benefit, ie payment made by a government to support individuals',
    'LBIN': 'Net payment related to a buy-in. When an investment manager is bought in on a sell trade that fails due to a failed securities lending recall, the IM may seize the underlying collateral to pay for the buy-in. Any difference between the value of the collateral and the sell proceeds would be paid or received under this code',
    'LCOL': 'Free movement of cash collateral. Cash collateral paid by the borrower is done separately from the delivery of the shares at loan opening or return of collateral done separately from return of the loaned security. Note: common when the currency of the security is different the currency of the cash collateral',
    'LFEE': 'Fee payments, other than rebates, for securities lending. Includes (a) exclusive fees; (b) transaction fees; (c) custodian fees; (d) minimum balance fees',
    'LMEQ': 'Cash collateral payments resulting from the marked-to-market of a portfolio of loaned equity securities',
    'LMFI': 'Cash collateral payments resulting from the marked-to-market of a portfolio of loaned fixed income securities',
    'LMRK': 'Cash collateral payments resulting from the marked-to-market of a portfolio of loaned securities where the instrument types are not specified',
    'LREB': 'Securities lending rebate payments',
    'LREV': 'Revenue payments made by the lending agent to the client',
    'LSFL': 'Payments made by a borrower to a lending agent to satisfy claims made by the investment manager related to sell fails from late loan recall deliveries',
    'ESTX': 'Transaction is related to a payment of estate tax',
    'FWLV': 'Transaction is related to a payment of Foreign Worker Levy',
    'GSTX': 'Transaction is the payment of Goods & Services Tax',
    'HSTX': 'Transaction is related to a payment of housing tax',
    'INTX': 'Transaction is related to a payment of income tax',
    'NITX': 'Transaction is related to a payment of net income tax',
    'PTXP': 'Transaction is related to a payment of property tax',
    'RDTX': 'Transaction is related to a payment of road tax',
    'TAXS': 'Transaction is the payment of taxes',
    'VATX': 'Transaction is the payment of value added tax',
    'WHLD': 'Transaction is related to a payment of withholding tax',
    'TAXR': 'Transaction is the refund of a tax payment or obligation',
    'B112': 'US mutual fund trailer fee (12b-1) payment',
    'BR12': 'US mutual fund trailer fee (12b-1) rebate payment',
    'TLRF': 'Any non-US mutual fund trailer fee (retrocession) payment (use ISIN to determine onshore versus offshore designation)',
    'TLRR': 'Any non-US mutual fund trailer fee (retrocession) rebate payment (use ISIN to determine onshore versus offshore designation)',
    'AIRB': 'Transaction is a payment for air transport related business',
    'BUSB': 'Transaction is a payment for bus transport related business',
    'FERB': 'Transaction is a payment for ferry related business',
    'RLWY': 'Transaction is a payment for railway transport related business',
    'TRPT': 'Transaction is for the payment to top-up pre-paid card and electronic road pricing for the purpose of transportation',
    'CBTV': 'Transaction is related to a payment of cable TV bill',
    'ELEC': 'Transaction is related to a payment of electricity bill',
    'ENRG': 'Transaction is related to a utility operation',
    'GASB': 'Transaction is related to a payment of gas bill',
    'NWCH': 'Transaction is related to a payment of network charges',
    'NWCM': 'Transaction is related to a payment of network communication',
    'OTLC': 'Transaction is related to a payment of other telecom related bill',
    'PHON': 'Transaction is related to a payment of telephone bill',
    'UBIL': 'Transaction is for the payment to common utility provider that provide gas, water and/or electricity',
    'WTER': 'Transaction is related to a payment of water bill',
    'BOND': 'Securities Lending-Settlement of Bond transaction',
    'CABD': 'Securities Lending-Settlement of Corporate Actions: Bonds transactions',
    'CAEQ': 'Securities Lending-Settlement of Corporate Actions: Equities transactions',
    'CBCR': 'Card Settlement-Settlement of Credit Card transactions',
    'DBCR': 'Card Settlement-Settlement of Debit Card transactions',
    'DICL': 'Card Settlement-Settlement of Diners transactions',
    'EQTS': 'Securities Lending-Settlement of Equities transactions',
    'FLCR': 'Card Settlement-Settlement of Fleet transactions',
    'EFTC': 'Utilities-Settlement of Low value Credit transactions',
    'EFTD': 'Utilities-Settlement of Low value Debit transactions',
    'MOMA': 'Securities Lending-ettlement of Money Market PCH',
    'RAPI': 'Instant Payments-Settlement of Rapid Payment Instruction (RPI) transactions',
    'GAMB': 'General-Payments towards a purchase or winnings received from gambling, betting or other wagering activities',
    'LOTT': 'General-Payment towards a purchase or winnings received from lottery activities',
    'AMEX': 'Card Settlement-Settlement of AMEX transactions',
    'SASW': 'Card Settlement-Settlement of ATM transactions',
    'AUCO': 'Utilities-Settlement of Authenticated Collections transactions',
    'PCOM': 'Final payment to complete the purchase of a property',
    'PDEP': 'Payment of the deposit required towards purchase of a property',
    'PLDS': 'Payment of funds from a lender as part of the issuance of a property loan',
    'PLRF': 'Transfer or extension of a property financing arrangement to a new deal or loan provider, without change of ownership of property',
    'GAFA': 'Salary and Benefits-Allowance from government to support family',
    'GAHO': 'Salary and Benefits-Allowance from government to individuals to support payments of housing',
    'CPEN': 'Cash penalties related to securities transaction, including CSDR Settlement Discipline Regime',
    'DEPD': 'Transaction is related to a payment concerning dependent support, for example child support or support for a person substantially financially dependent on the support provider',
    'RETL': 'Retail payment including e-commerce and online shopping',
}

# ExternalRatesAndTenors1Code
RATES_AND_TENORS = {
    'EURI': 'Euro interbank offered rate (3 months, 6 months and other tenors)',
    'ESOI': 'Euro Overnight Index Swap (ESTROIS) 1 day, 1 week, other tenors',
    'ESTR': 'Euro short-term rate',
    'GBPO': 'Pound sterling London inter-bank offered rate (3 months, 6 months, other tenors) and the respective successor rate',
    'OTHR': 'Other floating rates and tenors',
    'SOFR': 'Secured overnight financing rate (1 months, 3 months, other tenors)',
    'USOI': 'US dollar overnight index swap (1 day, 1 week, other tenors), USDOIS',
    'USPO': 'US dollar London inter-bank offered rate (3 months, 6 months, other tenors) and the respective successor rate',
}

# ExternalReceivedReason1Code
RECEIVED_REASON = {
    'NSTP': 'Instruction was not straight through processing and had to be processed manually',
}

# ExternalRejectedReason1Code
REJECTED_REASON = {
    'ADEA': 'Received after the servicer\'s deadline',
    'BDAY': 'Date is not a business day',
    'CTRC': 'Unrecognised or invalid client',
    'DPRG': 'Request has been rejected because the instruction process is in progress or has been processed',
    'INDT': 'Some message details specified in the instruction/request are inconsistent with those that expected',
    'MISM': 'The request cannot be executed. The message requested is not valid',
    'NAUT': 'Permission to be processed is not granted',
    'NINS': 'Referred instrument does not exist',
    'NOAC': 'Client has no access to the service',
    'TERM': 'Unrecognised or invalid effective date/time',
    'ASBR': 'Acknowledgement of settlement batch received from PSO for settlement',
    'AB15': 'Settlement Instruction with invalid account number or specific settlement type',
    'AB26': 'Invalid batch Settlement Instruction received',
    'AB12': 'Process a Batch Removal Instruction with an incorrect Batch Concurrent Sequence',
    'DT07': 'Process a Batch Removal Instruction with an incorrect "Original Creation Date and Time" for the batch',
    'AB13': 'Invalid routing code send by participant to settlement operator',
    'AB21': 'Processing interbank batch settlement instruction with invalid agreement number for settlement type',
    'ISWS': 'Invalid settlement window for settlement instruction',
    'MISN': 'Missing ISIN on settlement instruction',
    'NOFR': 'Warning messages that is send to participants when settlement account must be funded',
    'RC14': 'Participant is in BCP no settlement instruction for CLS',
    'RC16': 'Originator of the instruction is not an active participant in SADC RTGS',
    'RC15': 'Participant is not an active member of a specific settlement type',
    'RC13': 'Originator of the instruction is not an active participant in RTGS',
    'SBRN': 'Settlement batch removal notification due to batch not funded at window closure by participants',
}

# ExternalRelativeTo1Code
RELATIVE_TO = {
    'GOOD': 'Percentage rate expressed relative to the value of goods',
    'PAYM': 'Percentage rate expressed relative to the payment amount',
    'UNDG': 'Percentage rate expressed relative to the undertaking amount',
}

# ExternalReportingSource1Code
REPORTING_SOURCE = {
    'ACCT': 'Statement or Report is based on accounting data',
    'ARPF': 'An account reconciliation system that provides full reconciliation that usually addresses checks',
    'ARPP': 'An account reconciliation system that provides partial reconciliation that usually addresses checks',
    'CTDB': 'A sub-application that reports presentment totals',
    'CUST': 'Statement or Report is based on custody data',
    'DEPT': 'Cash or deposit accounting system',
    'DPCS': 'Deposit system that reports what has been collected from various financial institutions',
    'LKBX': 'Processing system that captures and reports check data in a lockbox environment',
    'RCPT': 'A system that reports consolidated remittance information obtained from various , i.e., ACH, wires, lockbox, etc',
    'MIBO': 'Transaction submitted directly from PMI (Payment Market Infrastructure back-office system',
    'PFRE': 'Transactions submitted directly from participant / PSO (Payment System Operator) applications',
}

# ExternalRePresentmentReason1Code
RE_PRESENTMENT_REASON = {
    'AMCR': 'Amount corrected due to proof of transaction',
    'CLSD': 'Liability Shift to acquirer due to missing card authentication method denied',
    'CRPI': 'Credit previously issued',
    'OTVA': 'Original transaction was valid',
    'VLSD': 'Liability Shift to acquirer due to missing cardholder verification method denied',
}

# ExternalReservationType1Code
RESERVATION_TYPE = {
    'BLKD': 'Amount blocked or frozen due to external circumstances such as a court order, death of beneficiary or account owner, or bankruptcy',
    'CARE': 'Amount set aside by a participant to reserve liquidity from its own account, exclusively or executing cash withdrawals',
    'HPAR': 'Amount set aside by a participant to reserve liquidity from its own account, exclusively for executing highly urgent payments',
    'NSSR': 'Amount set aside by a participant to reserve liquidity from its own account, exclusively for the settlement of the multilateral cash balance stemming from the Net Security Settlement System',
    'THRE': 'Amount above which funds will be destined for investment',
    'UPAR': 'Amount set aside by a participant to reserve liquidity from its own account, exclusively for executing critical payments called urgent payments',
}

# ExternalReturnReason1Code
RETURN_REASON = {
    'AC01': 'Format of the account number specified is not correct',
    'AC03': 'Wrong IBAN in SCT',
    'AC04': 'Account number specified has been closed on the bank of account\'s books',
    'AC06': 'Account specified is blocked, prohibiting posting of transactions against it',
    'AC13': 'Debtor account type is missing or invalid',
    'AC14': 'An agent in the payment chain is invalid',
    'AC15': 'Account details have changed',
    'AC16': 'Account is in sequestration',
    'AC17': 'Account is in liquidation',
    'AG01': 'Transaction forbidden on this type of account (formerly NoAgreement)',
    'AG02': 'Bank Operation code specified in the message is not valid for receiver',
    'AM01': 'Specified message amount is equal to zero',
    'AM02': 'Specific transaction/message amount is greater than allowed maximum',
    'AM03': 'Specified message amount is an non processable currency outside of existing agreement',
    'AM04': 'Amount of funds available to cover specified message amount is insufficient',
    'AM05': 'Duplication',
    'AM06': 'Specified transaction amount is less than agreed minimum',
    'AM07': 'Amount specified in message has been blocked by regulatory authorities',
    'AM09': 'Amount received is not the amount agreed or expected',
    'AM10': 'Sum of instructed amounts does not equal the control sum',
    'ARDT': 'Already returned original SCT',
    'BE01': 'Identification of end customer is not consistent with associated account number, organisation ID or private ID',
    'BE04': 'Specification of creditor\'s address, which is required for payment, is missing/not correct (formerly IncorrectCreditorAddress)',
    'BE05': 'Party who initiated the message is not recognised by the end customer',
    'BE06': 'End customer specified is not known at associated Sort/National Bank Code or does no longer exist in the books',
    'BE07': 'Specification of debtor\'s address, which is required for payment, is missing/not correct',
    'BE08': 'Returned as a result of a bank error',
    'CN01': 'Authorisation is cancelled',
    'CNOR': 'Creditor bank is not registered under this BIC in the CSM',
    'CNPC': 'Cash not picked up by Creditor or cash could not be delivered to Creditor',
    'CURR': 'Currency of the payment is incorrect',
    'CUST': 'Cancellation requested by the Debtor',
    'DNOR': 'Debtor bank is not registered under this BIC in the CSM',
    'DS28': 'Return following technical problems resulting in erroneous transaction',
    'DT01': 'Invalid date (eg, wrong settlement date)',
    'DT02': 'Cheque has been issued but not deposited and is considered expired',
    'ED01': 'Correspondent bank not possible',
    'ED03': 'Balance of payments complementary info is requested',
    'ED05': 'Settlement of the transaction has failed',
    'EMVL': 'The card payment is fraudulent and was not processed with EMV technology for an EMV card',
    'ERIN': 'The Extended Remittance Information (ERI) option is not supported',
    'FF05': 'Local Instrument code is missing or invalid',
    'FOCR': 'Return following a cancellation request',
    'FR01': 'Returned as a result of fraud',
    'FRTR': 'Final response/tracking is recalled as mandate is cancelled',
    'MD01': 'No Mandate',
    'MD02': 'Mandate related information data required by the scheme is missing',
    'MD06': 'Return of funds requested by end customer',
    'MD07': 'End customer is deceased',
    'MS02': 'Reason has not been specified by end customer',
    'MS03': 'Reason has not been specified by agent',
    'NARR': 'Reason is provided as narrative information in the additional reason information',
    'NOAS': 'No response from Beneficiary',
    'NOCM': 'Customer account is not compliant with regulatory requirements, for example FICA (in South Africa) or any other regulatory requirements which render an account inactive for certain processing',
    'NOOR': 'Original SCT never received',
    'PINL': 'The card payment is fraudulent (lost and stolen fraud) and was processed as EMV transaction without PIN verification',
    'RC01': 'Bank Identifier code specified in the message has an incorrect format (formerly IncorrectFormatForRoutingCode)',
    'RC07': 'Incorrrect BIC of the beneficiary Bank in the SCTR',
    'RF01': 'Transaction reference is not unique within the message',
    'RR01': 'Specification of the debtor’s account or unique identification needed for reasons of regulatory requirements is insufficient or missing',
    'RR02': 'Specification of the debtor’s name and/or address needed for regulatory requirements is insufficient or missing',
    'RR03': 'Specification of the creditor’s name and/or address needed for regulatory requirements is insufficient or missing',
    'RR04': 'Regulatory Reason',
    'RUTA': 'Return following investigation request and no remediation possible',
    'SL01': 'Due to specific service offered by the Debtor Agent',
    'SL02': 'Due to specific service offered by the Creditor Agent',
    'SL11': 'Whitelisting service offered by the Debtor Agent; Debtor has not included the Creditor on its “Whitelist” (yet). In the Whitelist the Debtor may list all allowed Creditors to debit Debtor bank account',
    'SL12': 'Blacklisting service offered by the Debtor Agent; Debtor included the Creditor on his “Blacklist”. In the Blacklist the Debtor may list all Creditors not allowed to debit Debtor bank account',
    'SL13': 'Due to Maximum allowed Direct Debit Transactions per period service offered by the Debtor Agent',
    'SL14': 'Due to Maximum allowed Direct Debit Transaction amount service offered by the Debtor Agent',
    'SP01': 'Payment is stopped by account holder',
    'SP02': 'Previously stopped by means of a stop payment advise',
    'SVNR': 'The card payment is returned since a cash amount rendered was not correct or goods or a service was not rendered to the customer, e.g. in an e-commerce situation',
    'TM01': 'Associated message was received after agreed processing cut-off time',
    'TRAC': 'Return following direct debit being removed from tracking process',
    'UPAY': 'Payment is not justified',
    'AGNT': 'Agent in the payment workflow is incorrect',
    'FF06': 'Category Purpose code is missing or invalid',
    'RC08': 'ClearingSystemMemberidentifier is invalid or missing._x000D_ Generic usage if cannot specify between debit or credit account',
    'BE11': 'Creditor country code is missing or invalid',
    'BE17': 'Creditor or Ultimate Creditor identification code missing or invalid',
    'AC02': 'Debtor account number invalid or missing',
    'RR11': 'Invalid or missing identification of a bank proprietary service',
    'BE10': 'Debtor country code is missing or invalid',
    'BE16': 'Debtor or Ultimate Debtor identification code missing or invalid',
    'RC11': 'Intermediary Agent is invalid or missing',
    'RR12': 'Invalid or missing identification required within a particular country or payment type',
    'FF03': 'Payment Type Information is missing or invalid._x000D_ Generic usage if cannot specify Service Level or Local Instrument code',
    'FF07': 'Purpose is missing or invalid',
    'FF04': 'Service Level code is missing or invalid',
    'RR09': 'Structured creditor reference invalid or missing',
    'RR05': 'Regulatory or Central Bank Reporting information missing, incomplete or invalid',
    'RR07': 'Remittance information structure does not comply with rules for payment type',
    'RR08': 'Remittance information truncated to comply with rules for payment type',
    'RR06': 'Tax information missing, incomplete or invalid',
    'AG07': 'Debtor account cannot be debited for a generic reason._x000D_ Usage: Code value may be used in general purposes and as a replacement for AM04 if debtor bank does not reveal its customer\'s insufficient funds for privacy reasons',
    'G004': 'In a FIToFI Customer Credit Transfer: Credit to the creditor’s account is pending, status Originator is waiting for funds provided via a cover. Update will follow from the Status Originator',
    'MD05': 'Creditor or creditor\'s agent should not have collected the direct debit',
    'AC07': 'Creditor account number closed',
    'DC04': 'Return of Covering Settlement due to the underlying Credit Transfer details not being received',
    'RC04': 'Creditor bank identifier is invalid or missing',
    'DT04': 'Future date not supported',
    'DUPL': 'Payment is a duplicate of another payment',
    'RC03': 'Debtor bank identifier is invalid or missing',
}

# ExternalReversalReason1Code
REVERSAL_REASON = {
    'AC03': 'Wrong IBAN in SCT',
    'AC04': 'Account number specified has been closed on the Receiver\'s books',
    'AG02': 'Bank Operation code specified in the message is not valid for receiver',
    'AM05': 'Duplication',
    'AM09': 'Wrong amount in SCT',
    'MD01': 'No Mandate',
    'MD05': 'Creditor or creditor\'s agent should not have collected the direct debit',
    'MS02': 'Reason has not been specified by end customer',
    'MS03': 'Reason has not been specified by agent',
    'RC07': 'Wrong BIC in SCT',
    'TM01': 'Associated message was received after agreed processing cut-off time',
}

# ExternalSecuritiesPurpose1Code
SECURITIES_PURPOSE = {
    'COLL': 'Relates to collateral management',
    'SECL': 'Relates to securities lending',
    'STMT': 'Relates to settlements',
}

# ExternalServiceLevel1Code
SERVICE_LEVEL = {
    'BKTR': 'Payment through internal book transfer',
    'G001': 'Tracked Customer Credit Transfer',
    'G002': 'Tracked Stop and Recall',
    'G003': 'Tracked Outbound Corporate Transfer',
    'G004': 'Tracked Financial Institution Transfer',
    'NPCA': 'Payments must be executed following the NPC Area Payment scheme',
    'NUGP': 'Payment must be executed as a non-urgent transaction with priority settlement',
    'NURG': 'Payment must be executed as a non-urgent transaction, which is typically identified as an ACH or low value transaction',
    'PRPT': 'Transaction must be processed according to the EBA Priority Service',
    'SDVA': 'Payment must be executed with same day value to the creditor',
    'SEPA': 'Payment must be executed following the Single Euro Payments Area scheme',
    'SVDE': 'Payment execution following the cheque agreement and traveller cheque agreement of the German Banking Industry Committee (Die Deutsche Kreditwirtschaft - DK) and Deutsche Bundesbank – Scheck Verrechnung Deutschland',
    'URGP': 'Payment must be executed as an urgent transaction cleared through a real-time gross settlement system, which is typically identified as a wire or high value transaction',
    'URNS': 'Payment must be executed as an urgent transaction cleared through a real-time net settlement system, which is typically identified as a wire or high value transaction',
    'INST': 'Used for payment initiation to identify that a Payment or Direct Debit initiation must be executed as an instant or real-time payment instrument',
    'SRTP': 'Request to Pay (RTP) transaction refers to an RTP scheme (such as for example the SEPA Request to Pay (SRTP) scheme)',
    'SVAT': 'Scheck Verarbeitung Austria (Cheque Processing)',
    'G006': 'Specifies the service conditions applicable to a tracked exceptions and investigations case',
    'G007': 'Specifies the service level for a tracked inbound customer credit transfer',
    'G005': 'Tracked Instant Customer Credit Transfer._x000D_ _x000D_',
    'G009': 'Specifies the service level for a tracked low-value cross-border customer credit transfer',
    'WFSM': 'Transaction is to be treated as an advice and only applied to the account of the creditor or next agent after settlement of the cover has been confirmed',
    'EOLO': 'Payment is executed following a Euro One-Leg Out Scheme',
}

# ExternalShipmentCondition1Code
SHIPMENT_CONDITION = {
    'ADVN': 'Goods/service delivered after payment',
    'PMNT': 'Goods/service delivered at the same time as payment',
    'TRLN': 'Goods/service delivered before payment',
}

# ExternalStatusReason1Code
STATUS_REASON = {
    'AB01': 'Clearing process aborted due to timeout',
    'AB02': 'Clearing process aborted due to a fatal error',
    'AB03': 'Settlement aborted due to timeout',
    'AB04': 'Settlement process aborted due to a fatal error',
    'AB05': 'Transaction stopped due to timeout at the Creditor Agent',
    'AB06': 'Transaction stopped due to timeout at the Instructed Agent',
    'AB07': 'Agent of message is not online. Generic usage if it cannot be determined who exactly is not online',
    'AB08': 'Creditor Agent is not online',
    'AB09': 'Transaction stopped due to error at the Creditor Agent',
    'AB10': 'Transaction stopped due to error at the Instructed Agent',
    'AB11': 'Transaction stopped due to timeout at the Debtor Agent',
    'AC01': 'Account number is invalid or missing',
    'AC02': 'Debtor account number invalid or missing',
    'AC03': 'Creditor account number invalid or missing',
    'AC04': 'Account number specified has been closed on the bank of account\'s books',
    'AC05': 'Debtor account number closed',
    'AC06': 'Account specified is blocked, prohibiting posting of transactions against it',
    'AC07': 'Creditor account number closed',
    'AC08': 'Branch code is invalid or missing',
    'AC09': 'Account currency is invalid or missing',
    'AC10': 'Debtor account currency is invalid or missing',
    'AC11': 'Creditor account currency is invalid or missing',
    'AC12': 'Account type missing or invalid. Generic usage if cannot specify between group and payment information levels',
    'AC13': 'Debtor account type missing or invalid',
    'AC14': 'Creditor account type missing or invalid',
    'AC15': 'The account details for the counterparty have changed',
    'AC16': 'Credit or debit card number is invalid',
    'AG01': 'Transaction forbidden on this type of account (formerly NoAgreement)',
    'AG02': 'Bank Operation code specified in the message is not valid for receiver',
    'AG03': 'Transaction type not supported/authorized on this account',
    'AG04': 'Agent country code is missing or invalid. Generic usage if cannot specify between group and payment information levels',
    'AG05': 'Debtor agent country code is missing or invalid',
    'AG06': 'Creditor agent country code is missing or invalid',
    'AG07': 'Debtor account cannot be debited for a generic reason. Code value may be used in general purposes and as a replacement for AM04 if debtor bank does not reveal its customer\'s insufficient funds for privacy reasons',
    'AG08': 'Transaction failed due to invalid or missing user or access right',
    'AG09': 'Original payment never received',
    'AG10': 'Agent of message is suspended from the Real Time Payment system. Generic usage if it cannot be determined who exactly is suspended',
    'AG11': 'Creditor Agent of message is suspended from the Real Time Payment system',
    'AG12': 'Payment orders made by transferring funds from one account to another at the same financial institution (bank or payment institution) are not allowed',
    'AG13': 'Returned payments derived from previously returned transactions are not allowed',
    'AGNT': 'Agent in the payment workflow is incorrect',
    'AM01': 'Specified message amount is equal to zero',
    'AM02': 'Specific transaction/message amount is greater than allowed maximum',
    'AM03': 'Specified message amount is an non processable currency outside of existing agreement',
    'AM04': 'Amount of funds available to cover specified message amount is insufficient',
    'AM05': 'Duplication',
    'AM06': 'Specified transaction amount is less than agreed minimum',
    'AM07': 'Amount specified in message has been blocked by regulatory authorities',
    'AM09': 'Amount received is not the amount agreed or expected',
    'AM10': 'Sum of instructed amounts does not equal the control sum',
    'AM11': 'Transaction currency is invalid or missing',
    'AM12': 'Amount is invalid or missing',
    'AM13': 'Transaction amount exceeds limits set by clearing system',
    'AM14': 'Transaction amount exceeds limits agreed between bank and client',
    'AM15': 'Transaction amount below minimum set by clearing system',
    'AM16': 'Control Sum at the Group level is invalid',
    'AM17': 'Control Sum at the Payment Information level is invalid',
    'AM18': 'Number of transactions is invalid or missing. Generic usage if cannot specify between group and payment information levels',
    'AM19': 'Number of transactions at the Group level is invalid or missing',
    'AM20': 'Number of transactions at the Payment Information level is invalid',
    'AM21': 'Transaction amount exceeds limits agreed between bank and client',
    'AM22': 'Unable to apply zero amount to designated account. For example, where the rules of a service allow the use of zero amount payments, however the back-office system is unable to apply the funds to the account. If the rules of a service prohibit the use of zero amount payments, then code AM01 is used to report the error condition',
    'AM23': 'Transaction amount exceeds settlement limit',
    'BE01': 'Identification of end customer is not consistent with associated account number. (formerly CreditorConsistency)',
    'BE04': 'Specification of creditor\'s address, which is required for payment, is missing/not correct (formerly IncorrectCreditorAddress)',
    'BE05': 'Party who initiated the message is not recognised by the end customer',
    'BE06': 'End customer specified is not known at associated Sort/National Bank Code or does no longer exist in the books',
    'BE07': 'Specification of debtor\'s address, which is required for payment, is missing/not correct',
    'BE08': 'Debtor name is missing',
    'BE09': 'Country code is missing or Invalid. Generic usage if cannot specifically identify debtor or creditor',
    'BE10': 'Debtor country code is missing or invalid',
    'BE11': 'Creditor country code is missing or invalid',
    'BE12': 'Country code of residence is missing or Invalid. Generic usage if cannot specifically identify debtor or creditor',
    'BE13': 'Country code of debtor\'s residence is missing or Invalid',
    'BE14': 'Country code of creditor\'s residence is missing or Invalid',
    'BE15': 'Identification code missing or invalid. Generic usage if cannot specifically identify debtor or creditor',
    'BE16': 'Debtor or Ultimate Debtor identification code missing or invalid',
    'BE17': 'Creditor or Ultimate Creditor identification code missing or invalid',
    'BE18': 'Contact details missing or invalid',
    'BE19': 'Charge bearer code for transaction type is invalid',
    'BE20': 'Name length exceeds local rules for payment type',
    'BE21': 'Name missing or invalid. Generic usage if cannot specifically identify debtor or creditor',
    'BE22': 'Creditor name is missing',
    'BE23': 'Phone number or email address, or any other proxy, used as the account proxy is unknown or invalid',
    'CERI': 'Credit transfer is not tagged as an Extended Remittance Information (ERI) transaction but contains ERI',
    'CH03': 'Value in Requested Execution Date or Requested Collection Date is too far in the future',
    'CH04': 'Value in Requested Execution Date or Requested Collection Date is too far in the past',
    'CH07': 'Element is not to be used at B- and C-Level',
    'CH09': 'Mandate changes are not allowed',
    'CH10': 'Information on mandate changes are missing',
    'CH11': 'Value in Creditor Identifier is incorrect',
    'CH12': 'Creditor Identifier is ambiguous at Transaction Level',
    'CH13': 'Original Debtor Account is not to be used',
    'CH14': 'Original Debtor Agent is not to be used',
    'CH15': 'Content Remittance Information/Structured includes more than 140 characters',
    'CH16': 'Content is incorrect',
    'CH17': 'Element is not allowed',
    'CH19': 'Values in Interbank Settlement Date or Requested Collection Date will be set to the next TARGET day',
    'CH20': 'Number of decimal points not compatible with the currency',
    'CH21': 'Mandatory element is missing',
    'CH22': 'SDD CORE and B2B not permitted within one message',
    'CHQC': 'Cheque has been presented in cheque clearing and settled on the creditor’s account',
    'CNOR': 'Creditor bank is not registered under this BIC in the CSM',
    'CURR': 'Currency of the payment is incorrect',
    'CUST': 'Cancellation requested by the Debtor',
    'DNOR': 'Debtor bank is not registered under this BIC in the CSM',
    'DS01': 'The electronic signature(s) is/are correct',
    'DS02': 'An authorized user has cancelled the order',
    'DS03': 'The user’s attempt to cancel the order was not successful',
    'DS04': 'The order was rejected by the bank side (for reasons concerning content)',
    'DS05': 'The order was correct and could be forwarded for postprocessing',
    'DS06': 'The order was transferred to VEU',
    'DS07': 'All actions concerning the order could be done by the EBICS bank server',
    'DS08': 'The decompression of the file was not successful',
    'DS09': 'The decryption of the file was not successful',
    'DS0A': 'Data signature is required',
    'DS0B': 'Data signature for the format is not available or invalid',
    'DS0C': 'The signer certificate is revoked',
    'DS0D': 'The signer certificate is not valid (revoked or not active)',
    'DS0E': 'The signer certificate is not present',
    'DS0F': 'The authority of the signer certification sending the certificate is unknown',
    'DS0G': 'Signer is not allowed to sign this operation type',
    'DS0H': 'Signer is not allowed to sign for this account',
    'DS0K': 'The number of transaction is over the number allowed for this signer',
    'DS10': 'The certificate is revoked for the first signer',
    'DS11': 'The certificate is not valid (revoked or not active) for the first signer',
    'DS12': 'The certificate is not present for the first signer',
    'DS13': 'The authority of signer certification sending the certificate is unknown for the first signer',
    'DS14': 'The user is unknown on the server',
    'DS15': 'The same signature has already been sent to the bank',
    'DS16': 'The public key version is not correct. This code is returned when a customer sends signature files to the financial institution after conversion from an older program version (old ES format) to a new program version (new ES format) without having carried out re-initialisation with regard to a public key change',
    'DS17': 'Order data and signatures don’t match',
    'DS18': 'File cannot be tested, the complete order has to be repeated. This code is returned in the event of a malfunction during the signature check, e.g. not enough storage space',
    'DS19': 'The user’s rights (concerning his signature) are insufficient to execute the order',
    'DS20': 'The certificate is revoked for the second signer',
    'DS21': 'The certificate is not valid (revoked or not active) for the second signer',
    'DS22': 'The certificate is not present for the second signer',
    'DS23': 'The authority of signer certification sending the certificate is unknown for the second signer',
    'DS24': 'Waiting time expired due to incomplete order',
    'DS25': 'The order file was deleted by the bank server (for multiple reasons)',
    'DS26': 'The same user has signed multiple times',
    'DS27': 'The user is not yet activated (technically)',
    'DT01': 'Invalid date (eg, wrong or missing settlement date)',
    'DT02': 'Invalid creation date and time in Group Header (eg, historic date)',
    'DT03': 'Invalid non bank processing date (eg, weekend or local public holiday)',
    'DT04': 'Future date not supported',
    'DT05': 'Associated message, payment information block or transaction was received after agreed processing cut-off date, i.e., date in the past',
    'DT06': 'Execution Date has been modified in order for transaction to be processed',
    'DU01': 'Message Identification is not unique',
    'DU02': 'Payment Information Block is not unique',
    'DU03': 'Transaction is not unique',
    'DU04': 'End To End ID is not unique',
    'DU05': 'Instruction ID is not unique',
    'DUPL': 'Payment is a duplicate of another payment',
    'ED01': 'Correspondent bank not possible',
    'ED03': 'Balance of payments complementary info is requested',
    'ED05': 'Settlement of the transaction has failed',
    'ED06': 'Interbank settlement system not available',
    'ERIN': 'Extended Remittance Information (ERI) option is not supported',
    'FF01': 'File Format incomplete or invalid',
    'FF02': 'Syntax error reason is provided as narrative information in the additional reason information',
    'FF03': 'Payment Type Information is missing or invalid. Generic usage if cannot specify Service Level or Local Instrument code',
    'FF04': 'Service Level code is missing or invalid',
    'FF05': 'Local Instrument code is missing or invalid',
    'FF06': 'Category Purpose code is missing or invalid',
    'FF07': 'Purpose is missing or invalid',
    'FF08': 'End to End Id missing or invalid',
    'FF09': 'Cheque number missing or invalid',
    'FF10': 'File or transaction cannot be processed due to technical issues at the bank side',
    'FF11': 'Clearing request rejected due it being subject to an abort operation',
    'G000': 'In an FI To FI Customer Credit Transfer: The Status Originator transferred the payment to the next Agent or to a Market Infrastructure. The payment transfer is tracked. No further updates will follow from the Status Originator. In a Financial Institution Credit Transfer with cover: The Status Originator performed the account booking and transferred the cover transaction to the next Reimbursement Agent or to a Market Infrastructure. The payment transfer is tracked. No further updates will follow from the Status Originator',
    'G001': 'In an FI To FI Customer Credit Transfer: The Status Originator transferred the payment to the next Agent or to a Market Infrastructure. The payment transfer is not tracked. No further updates will follow from the Status Originator. In a Financial Institution Credit Transfer with cover: The Status Originator performed the account booking and transferred the cover transaction to the next Reimbursement Agent or to a Market Infrastructure. The payment transfer is not tracked. No further updates will follow from the Status Originator',
    'G002': 'In a FIToFI Customer Credit Transfer: Credit to the creditor’s account may not be confirmed same day. Update will follow from the Status Originator. In a Financial Institution Credit Transfer with cover: Debit/credit to nostro account may not be confirmed same day or Financial Institution Credit Transfer may not be transferred same day. Update will follow from the Status Originator',
    'G003': 'In a FIToFI Customer Credit Transfer: Credit to creditor’s account is pending receipt of required documents. The Status Originator has requested creditor to provide additional documentation. Update will follow from the Status Originator. In a Financial Institution Credit Transfer with cover: Status Originator has requested a previous Agent to provide additional information/correct information. Update will follow from the Status Originator',
    'G004': 'In a FIToFI Customer Credit Transfer: Credit to the creditor’s account is pending, status Originator is waiting for funds provided via a cover. Update will follow from the Status Originator',
    'G005': 'Payment has been delivered to creditor agent with service level',
    'G006': 'Payment has been delivered to creditor agent without service level',
    'ID01': 'Signature file was sent to the bank but the corresponding original file has not been sent yet',
    'MD01': 'No Mandate',
    'MD02': 'Mandate related information data required by the scheme is missing',
    'MD05': 'Creditor or creditor\'s agent should not have collected the direct debit',
    'MD06': 'Return of funds requested by end customer',
    'MD07': 'End customer is deceased',
    'MS02': 'Reason has not been specified by end customer',
    'MS03': 'Reason has not been specified by agent',
    'NARR': 'Reason is provided as narrative information in the additional reason information',
    'NERI': 'Credit transfer is tagged as an Extended Remittance Information (ERI) transaction but does not contain ERI',
    'RC01': 'Bank identifier code specified in the message has an incorrect format (formerly IncorrectFormatForRoutingCode)',
    'RC02': 'Bank identifier is invalid or missing. Generic usage if cannot specify between debit or credit account',
    'RC03': 'Debtor bank identifier is invalid or missing',
    'RC04': 'Creditor bank identifier is invalid or missing',
    'RC05': 'BIC identifier is invalid or missing. Generic usage if cannot specify between debit or credit account',
    'RC06': 'Debtor BIC identifier is invalid or missing',
    'RC07': 'Creditor BIC identifier is invalid or missing',
    'RC08': 'ClearingSystemMemberidentifier is invalid or missing. Generic usage if cannot specify between debit or credit account',
    'RC09': 'Debtor ClearingSystemMember identifier is invalid or missing',
    'RC10': 'Creditor ClearingSystemMember identifier is invalid or missing',
    'RC11': 'Intermediary Agent is invalid or missing',
    'RC12': 'Creditor Scheme Id is invalid or missing',
    'RCON': 'Conflict with R-Message',
    'RECI': 'Further information regarding the intended recipient',
    'RF01': 'Transaction reference is not unique within the message',
    'RR01': 'Specification of the debtor’s account or unique identification needed for reasons of regulatory requirements is insufficient or missing',
    'RR02': 'Specification of the debtor’s name and/or address needed for regulatory requirements is insufficient or missing',
    'RR03': 'Specification of the creditor’s name and/or address needed for regulatory requirements is insufficient or missing',
    'RR04': 'Regulatory Reason',
    'RR05': 'Regulatory or Central Bank Reporting information missing, incomplete or invalid',
    'RR06': 'Tax information missing, incomplete or invalid',
    'RR07': 'Remittance information structure does not comply with rules for payment type',
    'RR08': 'Remittance information truncated to comply with rules for payment type',
    'RR09': 'Structured creditor reference invalid or missing',
    'RR10': 'Character set supplied not valid for the country and payment type',
    'RR11': 'Invalid or missing identification of a bank proprietary service',
    'RR12': 'Invalid or missing identification required within a particular country or payment type',
    'S000': 'Request for Cancellation is acknowledged following validation',
    'S001': 'Unique End-to-end Transaction Reference (UETR) relating to a payment has been identified as being associated with a Request for Cancellation',
    'S002': 'Unique End-to-end Transaction Reference (UETR) relating to a payment has been prevent from traveling across a messaging network',
    'S003': 'Request for Cancellation has been forwarded to the payment processing/last payment processing agent',
    'S004': 'Request for Cancellation has been acknowledged as delivered to payment processing/last payment processing agent',
    'SL01': 'Due to specific service offered by the Debtor Agent',
    'SL02': 'Due to specific service offered by the Creditor Agent',
    'SL03': 'Due to a specific service offered by the clearing system',
    'SL11': 'Whitelisting service offered by the Debtor Agent; Debtor has not included the Creditor on its “Whitelist” (yet). In the Whitelist the Debtor may list all allowed Creditors to debit Debtor bank account',
    'SL12': 'Blacklisting service offered by the Debtor Agent; Debtor included the Creditor on his “Blacklist”. In the Blacklist the Debtor may list all Creditors not allowed to debit Debtor bank account',
    'SL13': 'Due to Maximum allowed Direct Debit Transactions per period service offered by the Debtor Agent',
    'SL14': 'Due to Maximum allowed Direct Debit Transaction amount service offered by the Debtor Agent',
    'TA01': 'The transmission of the file was not successful – it had to be aborted (for technical reasons)',
    'TD01': 'There is no data available (for download)',
    'TD02': 'The file cannot be read (e.g. unknown format)',
    'TD03': 'The file format is incomplete or invalid',
    'TK01': 'Token is invalid',
    'TK02': 'Token used for the sender does not exist',
    'TK03': 'Token used for the receiver does not exist',
    'TK09': 'Token required for request is missing',
    'TKCM': 'Token found with counterparty mismatch',
    'TKSG': 'Single Use Token already used',
    'TKSP': 'Token found with suspended status',
    'TKVE': 'Token found with value limit rule violation',
    'TKXP': 'Token expired',
    'TM01': 'Associated message, payment information block, or transaction was received after agreed processing cut-off time',
    'TS01': 'The (technical) transmission of the file was successful',
    'TS04': 'The order was transferred to pass by accompanying note signed by hand',
    'CN01': 'Authorisation is cancelled',
    'FOCR': 'Return following a cancellation request',
    'FR01': 'Returned as a result of fraud',
    'NOCM': 'Customer account is not compliant with regulatory requirements, for example FICA (in South Africa) or any other regulatory requirements which render an account inactive for certain processing',
    'NOAS': 'No response from Beneficiary',
    'RUTA': 'Return following investigation request and no remediation possible',
    'UPAY': 'Payment is not justified',
    'ALAC': 'Request-to-pay has already been accepted by the Debtor',
    'AEXR': 'Request-to-pay Expiry Date and Time has already passed',
    'ARFR': 'Request-to-pay has already been refused by the Debtor',
    'ARJR': 'Request-to-pay has already been rejected',
    'ATNS': 'Attachments to the request-to-pay are not supported',
    'EDTR': 'Expiry date time of the request-to-pay is already reached',
    'EDTL': 'Expiry date time of the request-to-pay is too far in the future',
    'FRAD': 'Cancellation requested following a transaction that was originated fraudulently. The use of the FraudulentOrigin code should be governed by jurisdictions',
    'IEDT': 'Expiry date time of the request-to-pay is incorrect',
    'IRNR': 'No initial request-to-pay has been received',
    'NOAR': 'No existing agreement for receiving request-to-pay messages',
    'NOPG': 'Requested payment guarantee (by Creditor) related to a request-to-pay cannot be provided',
    'NRCH': 'Recipient side of the request-to-pay (payer or its request-to-pay service provider) is not reachable',
    'RTNS': 'Debtor does not support request-to-pay transactions',
    'REPR': 'Request-to-pay has been received and can be processed further',
    'SPII': 'Identifier of the request-to-pay service provider is incorrect',
    'PINS': 'Type of payment requested in the request-to-pay is not supported by the payer',
    'UCRD': 'Unknown Creditor',
    'FF12': 'Original payment is not eligible to be returned given its current status',
    'FF13': 'No record of request for cancellation found',
    'DC02': 'Rejection of a payment due to covering FI settlement not being received',
}

# ExternalSystemBalanceType1Code
SYSTEM_BALANCE_TYPE = {
    'ADJT': 'Average balance to be held in the settlement account at the end of each day in order to fulfil the reserve due. The approximation will be always made rounding up',
    'ADWR': 'Balance represents the available discounted market value for discount window repo',
    'AIDR': 'Balance represents the available discounted market value for intraday repo',
    'AVLB': 'Balance of money or securities that is at the disposal of the account owner on the date specified',
    'BLCK': 'Balance representing the regulatory reserve that a financial institution must have with the account servicing institution, such as the minimum credit balance a financial institution is to keep with its Central Bank for mandatory reserve purposes. In some countries, a blocked balance is known as a \'reserve\' balance',
    'BLOC': 'Balance representing the projected total of all cash legs for trades settling via a central securities depository that have been matched but blocked in order to not settle. These blocked trades are included in the calculation for settlement (for example to avoid overdrafts). Usage rule: Blocking can be done by account owner or its counterparties. Usually this is done to chain transactions or to prioritise other trades. Blocked trades have an indicator that prevents the transactions from settling. Once matched, they can settle whenever the freeze is lifted. In this case they will move to FSET. Lifting the freeze can happen anytime during the day and the transaction will be settling in the next settlement cycle which can be the same day if the (international) central securities depository\'s operates several settlements cycles per day',
    'BOOK': 'Balance that is registered in the books of the account servicer',
    'BSCC': 'Balance represents the total of the bulk settlement and central moneymarkets unit processor credit',
    'BSCD': 'Balance represents the total of the bulk settlement and central moneymarkets unit processor debit',
    'CCPS': 'Balance representing the forecast of the total of all cash legs of transactions traded in exchanges that operate a central counterparty functionality',
    'CLSG': 'Balance of the account at the end of the account servicer\'s business day. It is the sum of the opening balance at the beginning of the day and all entries booked to the account during the account servicer\'s business day',
    'COHB': 'Balance representing the total incoming payments that were put on hold because the credit limit has been exceeded',
    'COLC': 'Balance representing the projected total amount of all payment obligations to the participant (bank), based on their role as main paying agent',
    'CPBL': 'Balance representing the total incoming payments that have been processed and are waiting for settlement',
    'CRDT': 'Balance representing the sum of all credit entries booked to an account',
    'CRRT': 'Balance of the account at a precise moment in time',
    'CUSA': 'Balance representing the actual total of all asset servicing transactions such as dividends, income corporate actions equivalents, tax returns, redemptions, etc',
    'CUST': 'Balance representing the projected total of all asset servicing transactions such as dividends, income corporate actions equivalents, tax returns, etc',
    'DBIT': 'Balance representing the sum of all debit entries booked to an account',
    'DLOD': 'Balance representing the intra day overdraft granted by the central bank to financial institutions participating in a RTGS system. This balance may vary over time and shall be offset at the end of the day',
    'DOHB': 'Balance representing the total outgoing payments that were put on hold because the debit limit has been exceeded',
    'DPBL': 'Balance representing the total outgoing payments that have been processed and are waiting for settlement',
    'DSET': 'Balance representing the cash equivalent of all settled securities transactions',
    'DWRD': 'Balance represents the discount window repo drawings',
    'EAST': 'Balance representing the potential loan a Central Bank would make in cash if the collateral is pledged, such as securities available and eligible as collateral with the central bank',
    'EXRE': 'The code defines the threshold to the value excess reserve exemption balance between the exempt and non-exempt tiers of excess reserve',
    'EXRR': 'The code defines the balance beyond excess reserve exemption threshold within the periodic average balance for minimum reserve. Thus, this part of the excess reserve is still to be remunerated',
    'FCOL': 'Balance representing the forecast of the cash-equivalent resulting from evaluation of existing holdings at central securities depositary that are qualified to serve as collateral',
    'FCOU': 'Balance representing the cash equivalent resulting from evaluation of existing holdings at CSD that are qualified to serve as collateral and have been used as collateral',
    'FORC': 'Balance representing the total of all balance types representing transactions to settle, blocked items and custody transactions',
    'FSET': 'Balance representing the forecast of total of all cash legs for trades that are ready to settle via a central securities depository. Amounts shown are still subject to processing of the securities settlement',
    'FUND': 'Balance representing the net amount to be funded resulting from all transactions which have an impact on the funding requirement',
    'FUTB': 'Balance representing the total of the payments with a processing date in the future',
    'INTM': 'Balance calculated in the course of the account servicer\'s business day, at the time specified, and subject to further changes during the business day. The interim balance is calculated on the basis of booked credit and debit items during the calculation time/period specified',
    'IRDR': 'Balance represents the intraday repo drawings',
    'IRLT': 'Balance represents the intraday repo limit',
    'LACK': 'Balance representing the cash equivalent of transactions with a lack of holdings',
    'LRLD': 'Balance of a specific limit value, such as a bilateral balance is calculated in relation to a given bilateral limit',
    'LTSF': 'Balance composed of the sum of all liquidity transfers made to or from an account',
    'MSTR': 'Balance of the identified account plus the balance of all of its subaccounts',
    'NOTE': 'Balance representing the amount that a financial institution has set aside for a specific reason and which is therefore not available',
    'NSET': 'Balance representing the cash equivalent of all non-settled securities transactions',
    'OPNG': 'Book balance of the account at the beginning of the account servicer\'s business day. It always equals the closing book balance from the previous business day. Note: the available balance at the beginning of the account servicer\'s business day may be different from the closing book balance from the previous business day',
    'OTCC': 'Balance representing the Forecast of the total of all cash-legs of transactions \'over the counter\' (OTC), going through central counter party (CCP) functions',
    'OTCG': 'Balance representing the forecast of the total of all cash legs of transactions traded \'over the counter\' (OTC)',
    'OTCN': 'Balance representing the forecast of the total of all cash legs of transactions traded \'over the counter\' (OTC) not going through central counter party (CCP) functions',
    'OTHB': 'Balance representing the projected total of all cash legs for trades settling via a central securities depository that have been matched but blocked in order to not settle. These blocked transactions are not included in the calculation for settlement',
    'PDNG': 'Balance of securities pending delivery, such as the orders to sell securities have been executed but settlement of the open transactions has not been confirmed',
    'PIPO': 'Balance representing the fictive forecast of automated direct debits or payment based on standing arrangements between a central securities depository and the user.  Usage: Pay-Ins and Pay-Outs can be different based on individual payment instructions or available funds',
    'PRAV': 'Average of the daily balances on the account used to fulfil the reserve requirements calculated from the beginning of the maintenance period',
    'PYMT': 'Balance representing the sum of entries as a result of payments processing. Entries relating to fees, interest, or other movements not a result of payments sent or received by the account owner are not included',
    'REJB': 'Balance representing the total of the payments that have been rejected',
    'REPC': 'Balance represents the total of the central moneymarkets unit processor repo credits',
    'REPD': 'Balance represents the total of the central moneymarkets unit processor repo debits',
    'REST': 'Balance of cash that may only be used under certain conditions. Balance type is used to block securities/cash in the client account for example, when related to specific corporate actions, the holding is under the direct control of the system paying agent, who is the only one who can transfer securities out of this balance type. Also known as the "escrow balance" or "sequestered balance"',
    'SAPC': 'Balance represents the settlement account processor direct credit amount',
    'SAPD': 'Balance represents the settlement account processor direct debit amount',
    'SAPP': 'Balance represents the settlement account processor queue amount',
    'SCOL': 'Balance representing the forecast of the cash-equivalent resulting from evaluation of the net incoming balance of securities qualified to serve as collateral for which settlement instructions are held at',
    'SCOU': 'Balance representing the cash-equivalent resulting from evaluation of incoming securities, qualified to serve as collateral and actually used as collateral, which have been settled during the settlement process',
    'SELF': 'Balance of the account identified (as opposed to Master Balance)',
    'THRE': 'Balance representing the amount that will be destined for investment. Difference between available balance and threshold for investment limit',
    'TOHB': 'Balance representing the total of the payments that were put on hold because the limits have been exceeded',
    'TPBL': 'Balance representing the total of the payments that have been processed and are waiting for settlement during the day',
    'XCHC': 'Balance representing the forecast of the total of all cash legs of transactions in exchanges, going through CCP functions',
    'XCHG': 'Balance representing the forecast of the total of all cash legs of transactions traded in exchanges',
    'XCHN': 'Balance representing the forecast of the total of all cash legs of transactions traded in exchanges not going through central counter party (CCP) functions',
    'XCRD': 'Balance, composed of booked entries and pending items known at the time of calculation, which projects the end of day credit balance if everything books to the account and no other credit entry is posted',
    'XDBT': 'Balance, composed of booked entries and pending items known at the time of calculation, which projects the end of day debit balance if everything books to the account and no other debit entry is posted',
    'XPCD': 'Balance, composed of booked entries and pending items known at the time of calculation, which projects the end of day balance if everything is booked on the account and no other entry is posted',
}

# ExternalSystemErrorHandling1Code
SYSTEM_ERROR_HANDLING = {
    'X020': 'Specifies the error code when the data requested are not yet available',
    'X030': 'Specifies the error code when the data requested generates a message size that exceed the processing capacity',
    'X050': 'Specifies the error code when the data requested have not been found',
}

# ExternalSystemEventType1Code
SYSTEM_EVENT_TYPE = {
    'CRCO': 'Event is the cutoff for the cash reservation window',
    'CUSC': 'Event is the cutoff for customer payments',
    'ESTF': 'Event is the cut off for the standing facilities',
    'EUCO': 'Event is the cutoff time for the Euro1 system, that is, the deadline for processing Euro1 transactions',
    'EUSU': 'Event is the opening of the Euro 1 system operation',
    'FIRE': 'Event is the report after all operations have ceased in the system',
    'IBKC': 'Event is the cutoff for interbank payments',
    'LTDC': 'Event is the cutoff for the settlement of the cash multilateral balances resulting from the daylight cycle of the securities settlement system',
    'LTGC': 'Event is the cutoff for the daytime cycle of the securities settlement system',
    'LTNC': 'Event is the cutoff for the settlement of the cash multilateral balances resulting from the overnight cycle of the securities settlement system',
    'LVCC': 'Event is the cutoff time after which low value payments can no longer be cancelled',
    'LVCO': 'Event is the cutoff time for low value payments processed by the system',
    'LVRT': 'Event is the time at which the members will be provided with the report corresponding to the processing of low value payments',
    'LWSU': 'Event is the start of the limit warning period',
    'NPCT': 'Event is the cutoff time for the receipt of new commercial payments',
    'PCOT': 'Event is the cutoff time for the processing of payments',
    'RECC': 'Event is the cutoff for the settlement of the multilateral balances stemming from the retail clearing system',
    'REOP': 'Event is the expected resume time for a TARGET component',
    'SSSC': 'Event is the cutoff for the securities settlement system cash reservation window',
    'STDY': 'Event is the start of the operating day',
    'STSU': 'Event is the start of the Step 1 system operation',
    'SYSC': 'Event is the cutoff for the system',
}

# ExternalSystemMemberType1Code
SYSTEM_MEMBER_TYPE = {
    'DRCT': 'Member has full rights in the system. In principle, this membership status entails financial responsibility for its own operations and sponsored members\' operations submitted to the system',
    'IDRT': 'Member has limited rights in the system specifications. In principle, this membership status entails no financial responsibility for its operations submitted to the system',
    'RMTE': 'Member has access to the system from a remote location or through remote technical means',
    'EURO': 'Member is entitled to access the Euro1 system of the Euro Banking Association (EBA)',
    'STEP': 'Member is entitled to access the Step1 system of the Euro Banking Association (EBA)',
}

# ExternalTaxAmountType1Code
TAX_AMOUNT_TYPE = {
    'CITY': 'Tax accessed by city jurisdications within a country',
    'CNTY': 'Tax accessed by county jurisdications within a country',
    'LOCL': 'Tax accessed by local jurisdications within a country',
    'PROV': 'Tax accessed by province jurisdications within a country',
    'STAT': 'Tax accessed by state jurisdications within a country',
}

# ExternalTechnicalInputChannel1Code
TECHNICAL_INPUT_CHANNEL = {
    'FAXI': 'Technical Input Channel is fax or facsimile',
    'PAPR': 'Technical Input Channel is paper',
    'TAPE': 'Technical Input Channel is tape',
    'WEBI': 'Technical Input Channel is internet',
}

# ExternalTradeMarket1Code
TRADE_MARKET = {
    'FDMS': 'Factoring service provider, Factoring client and third party in the same country',
    'FEXP': 'Factoring service provider, Factoring client in the same country, third party in another country',
    'FFDM': 'Factoring client and third party in the same country, Factoring service provider in another country',
    'FFDT': 'Factoring service provider, Factoring client and third party in the same country, but factoring client has an exceptional VAT ruling, for example if it’s overseas',
    'FIMP': 'Factoring service provider and third party in the same country, Factoring client in another country',
    'FREX': 'Factoring service provider, Factoring client and third party in three different countries',
}

# ExternalTradeTransactionCondition1Code
TRADE_TRANSACTION_CONDITION = {
    'BCBL': 'Board lots, not set for odd lots (UK specific)',
    'BCBN': 'Bad names, not set for good names (UK specific)',
    'BCFD': 'Form of delivery, not for foreign registration when unset (UK specific)',
    'BCPD': 'Place of delivery, in country of incorporation when unset (UK specific)',
    'BCRO': 'Result of option when set (UK specific)',
    'BCRP': 'Result of repo when set (UK specific)',
    'BLKO': 'The trade is a block trade or not, ie, whether allocation instruction will follow or not',
    'BTEX': 'Trade to be executed done at best execution',
    'BTMI': 'Bought minus indicator',
    'CALL': 'Trade to be executed following the exercise of a call option on the security',
    'CBNS': 'The trade is executed cum bonus',
    'CCPN': 'The trade is executed cum coupon',
    'CDIV': 'The trade is executed cum dividend',
    'CLBR': 'Trade to be executed for closure of a previous position before the rollover of a position (Deferred Settlement Service)',
    'CLEN': 'The trade is executed clean, ie government tax must not be paid on the accrued interest on the bond',
    'CRST': 'Cross trades are allowed whereby buy and sell orders are offset without recording the trade on the exchange',
    'CRTS': 'The trade is executed cum rights',
    'CWAR': 'The trade is executed cum warrant',
    'DIOR': 'A customer order where the customer gives specific instructions to the broker concerning the orders routing destination',
    'DIRT': 'The trade is executed dirty, ie government tax must be paid on the accrued interest on the bond',
    'DORD': 'The order is to be executed by a trading party other than the trading party to which the order is sent. In this case, the instructing party has traded with another broker which will subsequently send an advice of execution to the executing party who received the order and which is acting as clearing broker',
    'FORW': 'The order is based on a forward price',
    'FRAC': 'Fractional parts are allowed',
    'GTDL': 'The delivery of the financial instrument on settlement date is guaranteed',
    'HIST': 'The order is based on a historic price',
    'MAPR': 'Trade was executed at market price',
    'MONT': 'Trade to be executed for month-end settlement (Deferred Settlement Service)',
    'NBFR': 'Trade to be executed for a new trade position on the next month following the roll-over of a position (Deferred Settlement Service)',
    'NCRS': 'Cross trades, whereby buy and sell orders are offset without recording the trade on the exchange, are not allowed',
    'NEGO': 'Trade for which the price is not the one quoted but an improved one, that is, the negotiated price',
    'NMPR': 'Trade was executed outside of normal market conditions, for example, in the case of an iceberg order',
    'PETA': 'Allows trader to explicitly request anonymity or disclosure in pre-trade market data feeds. Anonymity is relevant in markets where counterparties are regularly disclosed in order depth feeds. Disclosure is relevant when counterparties are not normally visible',
    'PUTT': 'Trade to be executed following the exercise of a put option on the security',
    'SETI': 'Trade is exempt from short-sale rules',
    'SPCU': 'The trade is executed with a special cum dividend, ie, buying after the ex date and getting the dividend',
    'SPEX': 'The trade is executed with a special ex dividend, ie, selling before the ex date without the coupon',
    'SPSI': 'Sold plus indication',
    'SSTI': 'The trade is sold short. When the seller does not have the financial instrument, the delivery is effected by borrowing the financial instrument by or for the account of the seller',
    'TEFR': 'Trade executed this month following the rollover of positions',
    'TRFR': 'Trade to be executed on the next month following the roll-over of positions',
    'WIBC': 'Transaction is before the issue date after announcement of the auction',
    'WICD': 'Transaction is after the issue date after announcement of the auction',
    'XBNS': 'The trade is executed ex bonus',
    'XCPN': 'The trade is executed ex coupon',
    'XDIV': 'The trade is executed ex dividend',
    'XRTS': 'The trade is executed ex rights',
    'XWAR': 'The trade is executed ex warrant',
}

# ExternalTypeOfParty1Code
TYPE_OF_PARTY = {
    'ADVP': 'Party advising the undertaking',
    'ANYB': 'Any bank',
    'APPL': 'Party named in the undertaking as the “applicant”',
    'BENE': 'Party in whose favour the undertaking (or counter-undertaking) is issued',
    'CONF': 'Party that adds its undertaking to honour the undertaking',
    'CUB2': 'Beneficiary of the second counter-undertaking',
    'CUB3': 'Beneficiary of the third counter-undertaking',
    'ISSU': 'Party that issues the undertaking (or counter-undertaking)',
    'OBLG': 'Party obligated to reimburse the issuer',
    'ORDR': 'Party requested to issue an undertaking on behalf of the applicant. Also known as the ordering institution or applicant\'s bank',
    'PRES': 'Party nominated to receive presentation',
    'SADV': 'Second advising party',
    'SPEC': 'Party located at specified address',
}

# ExternalUnableToApplyIncorrectData1Code
UNABLE_TO_APPLY_INCORRECT_DATA = {
    'IN01': 'Related transaction reference is incorrect',
    'IN02': 'Payment type service level is incorrect (former IncorrectBankOperationCode)',
    'IN03': 'Payment type category purpose is incorrect (former IncorrectInstructionCode)',
    'IN04': 'RequestedExecutionDate is incorrect',
    'IN05': 'Interbank settlement date is incorrect (former IncorrectValueDate)',
    'IN06': 'Interbank settlement amount is incorrect (former IncorrectSettledAmount)',
    'IN07': 'Debtor is incorrect',
    'IN08': 'DebtorAccount is incorrect',
    'IN09': 'InstructedReimbursementAgent is incorrect (former IncorrectReceiverCorrespondent)',
    'IN10': 'ThirdReimbursementAgent is incorrect (former IncorrectThirdReimbursementInstitution)',
    'IN11': 'Payment type clearing channel is incorrect (former PaymentScheme)',
    'IN12': 'CreditorAgentAccount is incorrect (former IncorrectAccountOfBeneficiaryInstitution)',
    'IN13': 'Creditor is incorrect',
    'IN14': 'Creditor account is incorrect',
    'IN15': 'RemittanceInformation is incorrect',
    'IN16': 'Transaction payment purpose is incorrect',
    'IN17': 'ChargeBearer is incorrect (former IncorrectDetailsOfCharges)',
    'IN18': 'Instruction for next agent is incorrect (former IncorrectSenderToReceiverInformation)',
    'IN19': 'Instruction for creditor agent is incorrect (former IncorrectInstructionForFinalAgent)',
    'IN33': 'Amount in statement entry is incorrect',
    'IN36': 'SettlementAccount is incorrect',
    'IN37': 'Instructing reimbursement agent is incorrect',
    'IN38': 'Debtor\'s address is incorrect',
    'IN39': 'Creditor\'s address is incorrect',
    'IN40': 'RelatedRemittanceInformation is incorrect',
    'MM20': 'Name and account of creditor are not matching',
    'MM21': 'Name and account of debtor are not matching',
    'MM22': 'Name and account of creditor agent (former FinalAgent) are not matching',
    'MM23': 'Insufficient or incoherent details about the debtor with respect to regulatory requirements',
    'MM24': 'Insufficient or incoherent details about the creditor with respect to regulatory requirements',
    'MM25': 'Payment is pending execution. For reasons of regulatory requirements we request further information on the account number or unique identification of the debtor',
    'MM26': 'Payment is pending execution. For reasons of regulatory requirements we request further information on the name and/or address of the debtor',
    'MM27': 'Payment has been executed. For reasons of regulatory requirements we request further information on the account number or unique identification of the debtor',
    'MM28': 'Payment has been executed. For reasons of regulatory requirements we request further information on the name and/or address of the debtor',
    'MM29': 'Payment is pending execution. For reasons of regulatory requirements we request further information on the account number or unique identification of the creditor',
    'MM30': 'Payment is pending execution. For reasons of regulatory requirements we request further information on the name and/or address of the creditor',
    'MM31': 'Payment has been executed. For reasons of regulatory requirements we request further information on the account number or unique identification of the creditor',
    'MM32': 'Payment has been executed. For reasons of regulatory requirements we request further information on the name and/or address of the creditor',
    'MM34': 'Insufficient charges details provided',
    'MM35': 'Payment purpose needs to be further specified',
    'NARR': 'See narrative field for additional information',
}

# ExternalUnableToApplyMissingData1Code
UNABLE_TO_APPLY_MISSING_DATA = {
    'MS01': 'RemittanceInformation is missing',
    'MS02': 'Instruction for next agent is missing (former MissingSenderToReceiverInformation split into debtor, credit and next agent information)',
    'MS03': 'Debtor is missing',
    'MS04': 'DebtorAccount is missing',
    'MS05': 'DebtorAgent is missing (former MissingFirstAgent for credit transfers)',
    'MS06': 'Amount is missing',
    'MS07': 'SettlementAccount is missing. (former MissingNostroVostroAccount)',
    'MS08': 'Intermediary is missing',
    'MS09': 'InstructingReimbursementAgent is missing (former MissingReimbursementAgent1)',
    'MS10': 'InstructedReimbursementAgent is missing (former MissingReimbursementAgent2)',
    'MS11': 'Third reimbursement agent is missing (former MissingReimbursementAgent)',
    'MS12': 'Creditor is missing',
    'MS13': 'CreditorAccount is missing',
    'MS14': 'Payment instruction is missing',
    'MS15': 'Creditor agent is missing (former MissingFirstAgent for direct debits)',
    'MS16': 'Instruction for creditor agent is missing (former MissingSenderToReceiverInformation split into debtor, credit and next agent information)',
    'MS17': 'Instruction for debtor agent is missing (former MissingSenderToReceiverInformation split into debtor, credit and next agent information)',
    'MS18': 'RelatedRemittanceInformation is missing',
    'NARR': 'See narrative field for additional information',
}

# ExternalUnderlyingTradeTransactionType1Code
UNDERLYING_TRADE_TRANSACTION_TYPE = {
    'CONT': 'Underlying transaction is a contract',
    'DELV': 'Underlying transaction is a delivery order',
    'PROF': 'Underlying transaction is a proforma invoice',
    'PROJ': 'Underlying transaction is a project',
    'PUOR': 'Underlying transaction is a purchase order',
    'QUOT': 'Underlying transaction is a quotation',
    'TEND': 'Underlying transaction is a tender',
}

# ExternalUndertakingAmountType1Code
UNDERTAKING_AMOUNT_TYPE = {
    'INCR': 'Amount is an increase',
    'REDC': 'Amount is a reduction',
}

# ExternalUndertakingChargeType1Code
UNDERTAKING_CHARGE_TYPE = {
    'AMND': 'Charge related to the issuance of an amendment',
    'CLAM': 'Charge related to the processing of a claim',
    'COMM': 'Commission charge',
    'CONF': 'Charge for confirmation',
    'COUR': 'Courier charge',
    'ISSU': 'Charge related to the issuance of an undertaking',
    'MISC': 'Miscellaneous charge',
    'PAYM': 'Charge related to the payment processing',
    'POST': 'Postage charge',
    'TELE': 'Telecommunication charge',
}

# ExternalUndertakingDocumentType1Code
UNDERTAKING_DOCUMENT_TYPE = {
    'BENS': 'Document is a beneficiary statement',
    'CINV': 'Document is an invoice',
    'CLAF': 'Document is a claim form',
    'DEMD': 'Document is an undertaking demand',
    'TRAF': 'Document is a transfer form',
}

# ExternalUndertakingDocumentType2Code
UNDERTAKING_DOCUMENT_TYPE2_CODE = {
    'BENS': 'Document is a beneficiary statement',
    'CINV': 'Document is an invoice',
    'TRAF': 'Document is a transfer form',
}

# ExternalUndertakingStatusCategory1Code
UNDERTAKING_STATUS_CATEGORY = {
    'AMND': 'Status is related to an undertaking amendment',
    'AMTC': 'Status is related to a counter-undertaking amount',
    'AMTU': 'Status is related to an undertaking amount',
    'APPL': 'Status is related to an undertaking application',
    'BAMD': 'Status is related to an undertaking amendment requested by the beneficiary',
    'CONF': 'Status is related to an undertaking confirmation',
    'DEMD': 'Status is related to an undertaking demand',
    'NEXT': 'Status is related to an undertaking non-extension request',
    'TERM': 'Status is related to an undertaking termination',
}

# ExternalUndertakingType1Code
UNDERTAKING_TYPE = {
    'APAY': 'Undertaking in support of an advance payment obligation',
    'COMM': 'Undertaking in support of a commercial obligation',
    'CUST': 'Undertaking in support of a customs duty obligation',
    'DPAY': 'Undertaking representing the primary means of payment',
    'FINC': 'Undertaking in support of a financial obligation',
    'INSU': 'Undertaking in support of a insurance obligation',
    'IRBO': 'Undertaking in support of an Industrial Revenue Board (IRB) obligation',
    'MAIN': 'Undertaking in support of a maintenance obligation',
    'PAYM': 'Undertaking in support of a payment obligation',
    'PERF': 'Undertaking in support of a performance obligation',
    'RETN': 'Undertaking in support of a monetary retention obligation',
    'SHIP': 'Undertaking in support of a sea transportation obligation',
    'TEND': 'Undertaking in support of a tender or bid obligation',
    'WARR': 'Undertaking in support of a warranty obligation',
}

# ExternalUnitOfMeasure1Code
UNIT_OF_MEASURE = {
    'KILO': 'Basic unit of mass in the SI system, 1000 grams',
    'PIEC': 'Standard length of cloth, wallpaper, as an item for sale or amount of a substance',
    'TONS': 'Measure of weight, in Britain 2240lb (long ton)and in the US 2000lb (short ton)',
    'METR': 'Unit of length in the metric system, equal to 39.37 inches',
    'INCH': 'Measure of length equal to 2.54 cm',
    'YARD': 'Unit of length equal to 3 feet or 0.9144 metre',
    'GBGA': 'Unit of volume that is equal to 8 pints',
    'GRAM': 'Unit of measure that is equal to a 1, 000th of a kilo',
    'CMET': 'Unit of measure that is equal to one hundredth of a metre',
    'SMET': 'Measure of a surface, one metre by one metre',
    'FOOT': 'Unit of length equal to 1/3 yard',
    'MILE': 'Unit of length equal to 1, 760 yards',
    'SQIN': 'Measure of a surface, one inch by one inch',
    'SQFO': 'Measure of a surface, one foot by one foot',
    'SQMI': 'Measure of a surface, one mile by one mile',
    'GBOU': 'Unit of weight equal to a sixteenth of a pound',
    'USOU': 'Unit of weight equal to a sixteenth of a pound',
    'GBPI': 'Unit of volume that is equal to 568 cubic centimetres',
    'USPI': 'Unit of volume that is equal to 473 cubic centimetres',
    'GBQA': 'Unit of volume that is equal to 2 pints',
    'USQA': 'Unit of volume that is equal to 2 pints',
    'USGA': 'Unit of volume that is equal to 8 pints',
    'MMET': 'Unit of measure that is a thousandth of one metre',
    'KMET': 'Unit of measure that is equal to 1, 000 meters',
    'SQYA': 'Measure of a surface, one yard by one yard',
    'ACRE': 'Unit of measure equal to 4, 840 square yards',
    'ARES': 'Unit of measure equal to a 100 square meters',
    'SMIL': 'Measure of a surface, one millimetre by one millimetre',
    'SCMT': 'Measure of a surface, one centimetre by one centimetre',
    'HECT': 'Unit of measure that is equal to 10, 000 square meters',
    'SQKI': 'Measure of a surface, one kilometre by one kilometre',
    'MILI': 'Unit of volume that is equal to one thousandth of a litre',
    'CELI': 'Unit of volume that is equal to one hundredth of a litre',
    'LITR': 'Unit of volume that is equal to a thousand cubic centimetres',
    'PUND': 'Unit of weight equal to 0.454 kilograms',
    'ALOW': 'Amount of money deducted from a price or an amount due',
    'ACCY': 'Number of monetary units specified in a currency, where the unit of currency is explicit and compliant with ISO 4217',
    'BARL': 'Unit of volume that is equal to 42 US gallons',
    'BCUF': 'Unit of measure for large volumes of natural gas equivalent to 28316846 cubic meters',
    'BDFT': 'Measure of length equal to 144 cubic inches',
    'BUSL': 'Unit of weight that is equal to 8 gallons. Mostly used for agricultural products with a specification of weight defined for each commodity differently',
    'CEER': 'Unit of emissions type (or carbon credits) issued by the Clean Development Mechanism (CDM) Executive Board for emission reductions achieved by CDM projects and verified by a DOE (Designated Operational Entity) under the rules of the Kyoto Protocol',
    'CLRT': 'Unit of offset credits used by the Climate Action Reserve. One Climate Reserve Tonne is equal to one metric ton of Greenhouse Gas (GHG) reduced/sequestered',
    'CBME': 'Unit of volume that is equal to one meter in length, breadth and height or also equal to 1000 liters',
    'DAYS': 'Unit of time that is equal to 24 hours',
    'DMET': 'Unit of weight that is equal to the same mass value as a metric ton excluding moisture',
    'ENVC': 'Unit of measure for ownership of credit (or allowance) of carbon dioxide emission (in metric ton)',
    'ENVO': 'Unit of measure for reduction of carbon dioxide emission (in metric ton) that may result in Environmental Credit',
    'HUWG': 'Unit of weight or mass of various values in the Imperial Unit System also known as quintal, cental or centum',
    'KWDC': 'Unit of measure of the capacity of production of electric power equal to 1000 watt in one day',
    'KWHO': 'Unit of measure that is equal to the power consumption of one kilowatt during one hour',
    'KWHC': 'Unit of measure of the capacity of production of electric power equal to 1000 watt in one hour',
    'KMOC': 'Unit of measure of the capacity of production of electric power equal to 1000 watt in one minute',
    'KWMC': 'Unit of measure of the capacity of production of electric power equal to 1000 watt in one month',
    'KWYC': 'Unit of measure of the capacity of production of electric power equal to 1000 watt in one year',
    'MWDC': 'Unit of measure of the capacity of production of electric power equal to 1000000 watt in one day',
    'MWHO': 'Unit of measure that is equal to the power consumption of one megawatt during one hour',
    'MWHC': 'Unit of measure of the capacity of production of electric power equal to 1000000 watt in one hour',
    'MWMC': 'Unit of measure of the capacity of production of electric power equal to 1000000 watt in one minute',
    'MMOC': 'Unit of measure of the capacity of production of electric power equal to 1000000 watt in one month',
    'MWYC': 'Unit of measure of the capacity of production of electric power equal to 1000000 watt in one year',
    'TONE': 'Unit of mass equal to 1000 kilograms; equivalent to approximately 2,204.6 pounds, 1.102 short tons (US) or 0.984 long tons (imperial)',
    'MIBA': 'Unit of volume that is equal to 1 million barrels equivalent to 42.000.000 US gallons',
    'MBTU': 'Unit of measure of heat equal to one million British thermal unit (BTU)',
    'OZTR': 'Unit of weight equal to 31.1034768 grams. Used in precious metals',
    'UCWT': 'Unit of weight or mass of various values in the US Customary System also known as quintal, cental or centum. Equal to 100 lbs',
    'IPNT': 'Decimal number used to calculate an amount or a price',
    'PWRD': 'Amount of money borrowed, or part of that amount which remains unpaid (excluding interest)',
    'DGEU': 'Amount of fuel alternative equal to one gallon of diesel',
    'GGEU': 'Amount of fuel alternative equal to one gallon of gasoline',
    'TOCD': 'Tons of carbon dioxide',
    'SHAS': 'Financial instrument that gives the owner right to dividends paid by a company and the most junior claim on the companies assets in the event of a bankruptcy',
    'THMS': 'Unit of heat, often used a unit of measure for natural gas in the UK',
    'FUTU': 'Exchange traded contract that defines an agreement to buy specific quantities of a commodity or financial instrument at an agreed time in the future',
    'GWHO': 'Unit of measure that is equal to the power consumption of one Gigawatt during one hour',
    'BRTU': 'Unit of measure of heat required to raise the temperature of one pound of water by one degree Fahrenheit',
    'LOTS': 'Indication of the unit of measurement',
    'BAGG': 'Code for a bag',
    'BALE': 'Code for a bale',
    'BOTL': 'Code for a bottle',
    'BOXX': 'Code for a box',
    'CRTN': 'Code for a carton',
    'CNTR': 'Code for a container',
    'CRAT': 'Code for a crate',
    'CBIN': 'Measure of a volume, one inch by one inch by one inch',
    'CBML': 'Unit of volume that is equal to one thousandth of a litre',
    'GBFO': 'Unit of volume equal to 2, 841 306 centilitre',
    'GBTN': 'Measure of weight, in Britain 2240 lb (long ton)',
    'USBA': 'Unit of volume equal to 158, 9873 litre',
    'USFO': 'Unit of volume equal to 2, 957353 centilitre',
    'USTN': 'Measure of weight, in the US 2000 lb (short ton)',
    'CDDA': 'Cooling degree day',
    'HDDA': 'Heating degree day',
    'CPDA': 'Critical precipitation day',
}

# ExternalValidationRuleIdentification1Code
VALIDATION_RULE_IDENTIFICATION = {
    'CCTR': 'Identifies the validation rules related to the Russian Cross-border Transactions Currency Control Reporting',
    'ITRP': 'Identifies the validation rules related to the invoice tax reporting',
    'MMSR': 'Identifies the validation rule scheme related to the ECB Euro Money Market Statistical Reporting',
    'SMMD': 'Identifies the validation rules related to the Bank Of England Sterling Money Market Daily Reporting',
}

# ExternalVerificationReason1Code
VERIFICATION_REASON = {
    'AC01': 'Account number provided in the request is invalid or missing',
    'AGNT': 'Agent identification provided in the request is incorrect',
    'DUPL': 'Request is a duplicate of another request',
}
